<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: anpr.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.ANPRConfig</code>
 */
class ANPRConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * The Brand and Model of the ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.ANPRTypes ANPRType = 1;</code>
     */
    protected $ANPRType = 0;
    /**
     * Default: 1 second. Prevent spam of the same plate being read within a certain time frame
     *
     * Generated from protobuf field <code>uint32 SamePlateTimeout = 2;</code>
     */
    protected $SamePlateTimeout = 0;
    /**
     * Default: Enabled. Allow "noPlate" events from ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.Toggle NoPlateEvents = 4;</code>
     */
    protected $NoPlateEvents = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $ANPRType
     *           The Brand and Model of the ANPR Camera
     *     @type int $SamePlateTimeout
     *           Default: 1 second. Prevent spam of the same plate being read within a certain time frame
     *     @type int $NoPlateEvents
     *           Default: Enabled. Allow "noPlate" events from ANPR Camera
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Anpr::initOnce();
        parent::__construct($data);
    }

    /**
     * The Brand and Model of the ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.ANPRTypes ANPRType = 1;</code>
     * @return int
     */
    public function getANPRType()
    {
        return $this->ANPRType;
    }

    /**
     * The Brand and Model of the ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.ANPRTypes ANPRType = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setANPRType($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\ANPRTypes::class);
        $this->ANPRType = $var;

        return $this;
    }

    /**
     * Default: 1 second. Prevent spam of the same plate being read within a certain time frame
     *
     * Generated from protobuf field <code>uint32 SamePlateTimeout = 2;</code>
     * @return int
     */
    public function getSamePlateTimeout()
    {
        return $this->SamePlateTimeout;
    }

    /**
     * Default: 1 second. Prevent spam of the same plate being read within a certain time frame
     *
     * Generated from protobuf field <code>uint32 SamePlateTimeout = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setSamePlateTimeout($var)
    {
        GPBUtil::checkUint32($var);
        $this->SamePlateTimeout = $var;

        return $this;
    }

    /**
     * Default: Enabled. Allow "noPlate" events from ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.Toggle NoPlateEvents = 4;</code>
     * @return int
     */
    public function getNoPlateEvents()
    {
        return $this->NoPlateEvents;
    }

    /**
     * Default: Enabled. Allow "noPlate" events from ANPR Camera
     *
     * Generated from protobuf field <code>.OS.PB.Toggle NoPlateEvents = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setNoPlateEvents($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->NoPlateEvents = $var;

        return $this;
    }

}

