<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * TO BE DEPRECIATED IN FAVOUR OF DeviceAction from V1.1.0-Beta+53 firmware
 *
 * Generated from protobuf message <code>OS.PB.DeviceRestartAction</code>
 */
class DeviceRestartAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 1;</code>
     */
    protected $RestartMethod = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $RestartMethod
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 1;</code>
     * @return int
     */
    public function getRestartMethod()
    {
        return $this->RestartMethod;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setRestartMethod($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceRestartMethod::class);
        $this->RestartMethod = $var;

        return $this;
    }

}

