<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: relay.proto

namespace GPBMetadata;

class Relay
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\x80\x02\x0A\x0Brelay.proto\x12\x05OS.PB\"B\x0A\x0ARelayEvent\x12 \x0A\x0ARelayState\x18\x01 \x01(\x0E2\x0C.OS.PB.State\x12\x12\x0A\x0ADurationMs\x18\x02 \x01(\x0D\"S\x0A\x0BRelayConfig\x12)\x0A\x12EventOnStateChange\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x19\x0A\x11DefaultDurationMs\x18\x02 \x01(\x0D\"!\x0A\x0BRelayAction\x12\x12\x0A\x0ADurationMs\x18\x01 \x01(\x0D\"\"\x0A\x0BRelayMetric\x12\x13\x0A\x0BActivations\x18\x01 \x01(\x0DB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

