<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: log.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.LogMetric</code>
 */
class LogMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>uint32 InfoLogCount = 2;</code>
     */
    protected $InfoLogCount = 0;
    /**
     * Generated from protobuf field <code>uint32 WarningLogCount = 3;</code>
     */
    protected $WarningLogCount = 0;
    /**
     * Generated from protobuf field <code>uint32 ErrorLogCount = 4;</code>
     */
    protected $ErrorLogCount = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $InfoLogCount
     *     @type int $WarningLogCount
     *     @type int $ErrorLogCount
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Log::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>uint32 InfoLogCount = 2;</code>
     * @return int
     */
    public function getInfoLogCount()
    {
        return $this->InfoLogCount;
    }

    /**
     * Generated from protobuf field <code>uint32 InfoLogCount = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setInfoLogCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->InfoLogCount = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 WarningLogCount = 3;</code>
     * @return int
     */
    public function getWarningLogCount()
    {
        return $this->WarningLogCount;
    }

    /**
     * Generated from protobuf field <code>uint32 WarningLogCount = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setWarningLogCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->WarningLogCount = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 ErrorLogCount = 4;</code>
     * @return int
     */
    public function getErrorLogCount()
    {
        return $this->ErrorLogCount;
    }

    /**
     * Generated from protobuf field <code>uint32 ErrorLogCount = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setErrorLogCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->ErrorLogCount = $var;

        return $this;
    }

}

