<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wiegand.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.WiegandResponse</code>
 */
class WiegandResponse extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.WiegandConfig Config = 1;</code>
     */
    protected $Config = null;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type \OS\PB\WiegandConfig $Config
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Wiegand::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.WiegandConfig Config = 1;</code>
     * @return \OS\PB\WiegandConfig|null
     */
    public function getConfig()
    {
        return $this->Config;
    }

    public function hasConfig()
    {
        return isset($this->Config);
    }

    public function clearConfig()
    {
        unset($this->Config);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.WiegandConfig Config = 1;</code>
     * @param \OS\PB\WiegandConfig $var
     * @return $this
     */
    public function setConfig($var)
    {
        GPBUtil::checkMessage($var, \OS\PB\WiegandConfig::class);
        $this->Config = $var;

        return $this;
    }

}

