<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: configsync.proto

namespace GPBMetadata;

class Configsync
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xB5\x01\x0A\x10configsync.proto\x12\x05OS.PB\":\x0A\x10ConfigSyncAction\x12\x0F\x0A\x07Timeout\x18\x05 \x01(\x0D\x12\x15\x0A\x0DTotalExpected\x18\x08 \x01(\x0D\"R\x0A\x0FConfigSyncEvent\x12\x0F\x0A\x07Message\x18\x06 \x01(\x09\x12\x15\x0A\x0DTotalReceived\x18\x08 \x01(\x0D\x12\x17\x0A\x0FProgressPercent\x18\x09 \x01(\x0DB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

