<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ethernet.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.EthernetConfig</code>
 */
class EthernetConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>string MDNSHostName = 1;</code>
     */
    protected $MDNSHostName = '';
    /**
     * Generated from protobuf field <code>string MCastAddress = 2;</code>
     */
    protected $MCastAddress = '';
    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 6;</code>
     */
    protected $OneSpace_Protobuf = null;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type string $MDNSHostName
     *     @type string $MCastAddress
     *     @type \OS\PB\DeviceNetworkConfig $OneSpace_Protobuf
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Ethernet::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>string MDNSHostName = 1;</code>
     * @return string
     */
    public function getMDNSHostName()
    {
        return $this->MDNSHostName;
    }

    /**
     * Generated from protobuf field <code>string MDNSHostName = 1;</code>
     * @param string $var
     * @return $this
     */
    public function setMDNSHostName($var)
    {
        GPBUtil::checkString($var, True);
        $this->MDNSHostName = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>string MCastAddress = 2;</code>
     * @return string
     */
    public function getMCastAddress()
    {
        return $this->MCastAddress;
    }

    /**
     * Generated from protobuf field <code>string MCastAddress = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setMCastAddress($var)
    {
        GPBUtil::checkString($var, True);
        $this->MCastAddress = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 6;</code>
     * @return \OS\PB\DeviceNetworkConfig|null
     */
    public function getOneSpaceProtobuf()
    {
        return $this->OneSpace_Protobuf;
    }

    public function hasOneSpaceProtobuf()
    {
        return isset($this->OneSpace_Protobuf);
    }

    public function clearOneSpaceProtobuf()
    {
        unset($this->OneSpace_Protobuf);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 6;</code>
     * @param \OS\PB\DeviceNetworkConfig $var
     * @return $this
     */
    public function setOneSpaceProtobuf($var)
    {
        GPBUtil::checkMessage($var, \OS\PB\DeviceNetworkConfig::class);
        $this->OneSpace_Protobuf = $var;

        return $this;
    }

}

