<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceConnectRPC</code>
 */
class DeviceConnectRPC extends \Google\Protobuf\Internal\Message
{
    /**
     * 32 byte AES-256-CBC encrypted random 32 bit number using Site GUID as the secret key
     *
     * Generated from protobuf field <code>bytes Challenge = 1;</code>
     */
    protected $Challenge = '';
    /**
     * 32 byte sha-256 hash of decrypted random 32 bit number challenge.
     *
     * Generated from protobuf field <code>bytes Answer = 2;</code>
     */
    protected $Answer = '';
    /**
     * 16 byte Randomized initialization vector, only sent on connect request
     *
     * Generated from protobuf field <code>bytes SessionIV = 3;</code>
     */
    protected $SessionIV = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type string $Challenge
     *           32 byte AES-256-CBC encrypted random 32 bit number using Site GUID as the secret key
     *     @type string $Answer
     *           32 byte sha-256 hash of decrypted random 32 bit number challenge.
     *     @type string $SessionIV
     *           16 byte Randomized initialization vector, only sent on connect request
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * 32 byte AES-256-CBC encrypted random 32 bit number using Site GUID as the secret key
     *
     * Generated from protobuf field <code>bytes Challenge = 1;</code>
     * @return string
     */
    public function getChallenge()
    {
        return $this->Challenge;
    }

    /**
     * 32 byte AES-256-CBC encrypted random 32 bit number using Site GUID as the secret key
     *
     * Generated from protobuf field <code>bytes Challenge = 1;</code>
     * @param string $var
     * @return $this
     */
    public function setChallenge($var)
    {
        GPBUtil::checkString($var, False);
        $this->Challenge = $var;

        return $this;
    }

    /**
     * 32 byte sha-256 hash of decrypted random 32 bit number challenge.
     *
     * Generated from protobuf field <code>bytes Answer = 2;</code>
     * @return string
     */
    public function getAnswer()
    {
        return $this->Answer;
    }

    /**
     * 32 byte sha-256 hash of decrypted random 32 bit number challenge.
     *
     * Generated from protobuf field <code>bytes Answer = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setAnswer($var)
    {
        GPBUtil::checkString($var, False);
        $this->Answer = $var;

        return $this;
    }

    /**
     * 16 byte Randomized initialization vector, only sent on connect request
     *
     * Generated from protobuf field <code>bytes SessionIV = 3;</code>
     * @return string
     */
    public function getSessionIV()
    {
        return $this->SessionIV;
    }

    /**
     * 16 byte Randomized initialization vector, only sent on connect request
     *
     * Generated from protobuf field <code>bytes SessionIV = 3;</code>
     * @param string $var
     * @return $this
     */
    public function setSessionIV($var)
    {
        GPBUtil::checkString($var, False);
        $this->SessionIV = $var;

        return $this;
    }

}

