<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: access.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.AccessEraseAction</code>
 */
class AccessEraseAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Reset Gateway back to defaults
     *
     * Generated from protobuf field <code>bool Gateway = 1;</code>
     */
    protected $Gateway = false;
    /**
     * Erase all Access Method configs
     *
     * Generated from protobuf field <code>bool AllMethods = 2;</code>
     */
    protected $AllMethods = false;
    /**
     * Erase all Access User configs
     *
     * Generated from protobuf field <code>bool AllUsers = 3;</code>
     */
    protected $AllUsers = false;
    /**
     * Erase all Access Right configs
     *
     * Generated from protobuf field <code>bool AllRights = 4;</code>
     */
    protected $AllRights = false;
    /**
     * Reset all entries and exits redeemed
     *
     * Generated from protobuf field <code>bool Redemptions = 5;</code>
     */
    protected $Redemptions = false;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type bool $Gateway
     *           Reset Gateway back to defaults
     *     @type bool $AllMethods
     *           Erase all Access Method configs
     *     @type bool $AllUsers
     *           Erase all Access User configs
     *     @type bool $AllRights
     *           Erase all Access Right configs
     *     @type bool $Redemptions
     *           Reset all entries and exits redeemed
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Access::initOnce();
        parent::__construct($data);
    }

    /**
     * Reset Gateway back to defaults
     *
     * Generated from protobuf field <code>bool Gateway = 1;</code>
     * @return bool
     */
    public function getGateway()
    {
        return $this->Gateway;
    }

    /**
     * Reset Gateway back to defaults
     *
     * Generated from protobuf field <code>bool Gateway = 1;</code>
     * @param bool $var
     * @return $this
     */
    public function setGateway($var)
    {
        GPBUtil::checkBool($var);
        $this->Gateway = $var;

        return $this;
    }

    /**
     * Erase all Access Method configs
     *
     * Generated from protobuf field <code>bool AllMethods = 2;</code>
     * @return bool
     */
    public function getAllMethods()
    {
        return $this->AllMethods;
    }

    /**
     * Erase all Access Method configs
     *
     * Generated from protobuf field <code>bool AllMethods = 2;</code>
     * @param bool $var
     * @return $this
     */
    public function setAllMethods($var)
    {
        GPBUtil::checkBool($var);
        $this->AllMethods = $var;

        return $this;
    }

    /**
     * Erase all Access User configs
     *
     * Generated from protobuf field <code>bool AllUsers = 3;</code>
     * @return bool
     */
    public function getAllUsers()
    {
        return $this->AllUsers;
    }

    /**
     * Erase all Access User configs
     *
     * Generated from protobuf field <code>bool AllUsers = 3;</code>
     * @param bool $var
     * @return $this
     */
    public function setAllUsers($var)
    {
        GPBUtil::checkBool($var);
        $this->AllUsers = $var;

        return $this;
    }

    /**
     * Erase all Access Right configs
     *
     * Generated from protobuf field <code>bool AllRights = 4;</code>
     * @return bool
     */
    public function getAllRights()
    {
        return $this->AllRights;
    }

    /**
     * Erase all Access Right configs
     *
     * Generated from protobuf field <code>bool AllRights = 4;</code>
     * @param bool $var
     * @return $this
     */
    public function setAllRights($var)
    {
        GPBUtil::checkBool($var);
        $this->AllRights = $var;

        return $this;
    }

    /**
     * Reset all entries and exits redeemed
     *
     * Generated from protobuf field <code>bool Redemptions = 5;</code>
     * @return bool
     */
    public function getRedemptions()
    {
        return $this->Redemptions;
    }

    /**
     * Reset all entries and exits redeemed
     *
     * Generated from protobuf field <code>bool Redemptions = 5;</code>
     * @param bool $var
     * @return $this
     */
    public function setRedemptions($var)
    {
        GPBUtil::checkBool($var);
        $this->Redemptions = $var;

        return $this;
    }

}

