<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: access.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.AccessConfirmationInput</code>
 */
class AccessConfirmationInput extends \Google\Protobuf\Internal\Message
{
    /**
     * The Interface type which the Reader is on
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     */
    protected $Interface = 0;
    /**
     * The index of the Interface the Reader is on    
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 3;</code>
     */
    protected $InterfaceIndex = 0;
    protected $InterfaceFiltering;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Interface
     *           The Interface type which the Reader is on
     *     @type int $InterfaceIndex
     *           The index of the Interface the Reader is on    
     *     @type int $LogicalAddress
     *           Default: 0. How the Reader is identified. Eg: For OSDP, this is the RS485 address.
     *     @type string $ANPRCameraId
     *           If the Reader, like an ANPR camera or BlueTooth reader, has a MACAddress, then it will be identified as a reader by its MAC
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Access::initOnce();
        parent::__construct($data);
    }

    /**
     * The Interface type which the Reader is on
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     * @return int
     */
    public function getInterface()
    {
        return $this->Interface;
    }

    /**
     * The Interface type which the Reader is on
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setInterface($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceInterface::class);
        $this->Interface = $var;

        return $this;
    }

    /**
     * The index of the Interface the Reader is on    
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 3;</code>
     * @return int
     */
    public function getInterfaceIndex()
    {
        return $this->InterfaceIndex;
    }

    /**
     * The index of the Interface the Reader is on    
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setInterfaceIndex($var)
    {
        GPBUtil::checkUint32($var);
        $this->InterfaceIndex = $var;

        return $this;
    }

    /**
     * Default: 0. How the Reader is identified. Eg: For OSDP, this is the RS485 address.
     *
     * Generated from protobuf field <code>uint32 LogicalAddress = 10;</code>
     * @return int
     */
    public function getLogicalAddress()
    {
        return $this->readOneof(10);
    }

    public function hasLogicalAddress()
    {
        return $this->hasOneof(10);
    }

    /**
     * Default: 0. How the Reader is identified. Eg: For OSDP, this is the RS485 address.
     *
     * Generated from protobuf field <code>uint32 LogicalAddress = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setLogicalAddress($var)
    {
        GPBUtil::checkUint32($var);
        $this->writeOneof(10, $var);

        return $this;
    }

    /**
     * If the Reader, like an ANPR camera or BlueTooth reader, has a MACAddress, then it will be identified as a reader by its MAC
     *
     * Generated from protobuf field <code>bytes ANPRCameraId = 11;</code>
     * @return string
     */
    public function getANPRCameraId()
    {
        return $this->readOneof(11);
    }

    public function hasANPRCameraId()
    {
        return $this->hasOneof(11);
    }

    /**
     * If the Reader, like an ANPR camera or BlueTooth reader, has a MACAddress, then it will be identified as a reader by its MAC
     *
     * Generated from protobuf field <code>bytes ANPRCameraId = 11;</code>
     * @param string $var
     * @return $this
     */
    public function setANPRCameraId($var)
    {
        GPBUtil::checkString($var, False);
        $this->writeOneof(11, $var);

        return $this;
    }

    /**
     * @return string
     */
    public function getInterfaceFiltering()
    {
        return $this->whichOneof("InterfaceFiltering");
    }

}

