<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.CodeHopConfig</code>
 */
class CodeHopConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Default: Disabled; Change to something else except disabled to enable the remote interface
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopConfig.CodeHopModes Mode = 1;</code>
     */
    protected $Mode = 0;
    /**
     * Default: Disabled; If Enabled, send CodeHop Events to cloud. 
     *
     * Generated from protobuf field <code>.OS.PB.Toggle SendEvents = 2;</code>
     */
    protected $SendEvents = 0;
    /**
     * WARNING: Enabling this will report on ALL CodeHop serials received that meet the minimum rssi threshold, 
     *          which can be a lot
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     */
    protected $RSSIMinimum = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Mode
     *           Default: Disabled; Change to something else except disabled to enable the remote interface
     *     @type int $SendEvents
     *           Default: Disabled; If Enabled, send CodeHop Events to cloud. 
     *     @type int $RSSIMinimum
     *           WARNING: Enabling this will report on ALL CodeHop serials received that meet the minimum rssi threshold, 
     *                    which can be a lot
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Codehop::initOnce();
        parent::__construct($data);
    }

    /**
     * Default: Disabled; Change to something else except disabled to enable the remote interface
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopConfig.CodeHopModes Mode = 1;</code>
     * @return int
     */
    public function getMode()
    {
        return $this->Mode;
    }

    /**
     * Default: Disabled; Change to something else except disabled to enable the remote interface
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopConfig.CodeHopModes Mode = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setMode($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\CodeHopConfig\CodeHopModes::class);
        $this->Mode = $var;

        return $this;
    }

    /**
     * Default: Disabled; If Enabled, send CodeHop Events to cloud. 
     *
     * Generated from protobuf field <code>.OS.PB.Toggle SendEvents = 2;</code>
     * @return int
     */
    public function getSendEvents()
    {
        return $this->SendEvents;
    }

    /**
     * Default: Disabled; If Enabled, send CodeHop Events to cloud. 
     *
     * Generated from protobuf field <code>.OS.PB.Toggle SendEvents = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setSendEvents($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->SendEvents = $var;

        return $this;
    }

    /**
     * WARNING: Enabling this will report on ALL CodeHop serials received that meet the minimum rssi threshold, 
     *          which can be a lot
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     * @return int
     */
    public function getRSSIMinimum()
    {
        return $this->RSSIMinimum;
    }

    /**
     * WARNING: Enabling this will report on ALL CodeHop serials received that meet the minimum rssi threshold, 
     *          which can be a lot
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setRSSIMinimum($var)
    {
        GPBUtil::checkInt32($var);
        $this->RSSIMinimum = $var;

        return $this;
    }

}

