<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.BLEConfig</code>
 */
class BLEConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Default: Hexadecimal representation of serial number. This can be changed by the server.
     *
     * Generated from protobuf field <code>string AdvertisingName = 1;</code>
     */
    protected $AdvertisingName = '';
    /**
     * Default: Admin12345 . This allows for a technician to use nRFToolBox, read the BLE Logs and send various commands.
     *
     * Generated from protobuf field <code>string TechnicianCode = 2;</code>
     */
    protected $TechnicianCode = '';
    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 5;</code>
     */
    protected $OneSpace_Protobuf = null;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type string $AdvertisingName
     *           Default: Hexadecimal representation of serial number. This can be changed by the server.
     *     @type string $TechnicianCode
     *           Default: Admin12345 . This allows for a technician to use nRFToolBox, read the BLE Logs and send various commands.
     *     @type \OS\PB\DeviceNetworkConfig $OneSpace_Protobuf
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Ble::initOnce();
        parent::__construct($data);
    }

    /**
     * Default: Hexadecimal representation of serial number. This can be changed by the server.
     *
     * Generated from protobuf field <code>string AdvertisingName = 1;</code>
     * @return string
     */
    public function getAdvertisingName()
    {
        return $this->AdvertisingName;
    }

    /**
     * Default: Hexadecimal representation of serial number. This can be changed by the server.
     *
     * Generated from protobuf field <code>string AdvertisingName = 1;</code>
     * @param string $var
     * @return $this
     */
    public function setAdvertisingName($var)
    {
        GPBUtil::checkString($var, True);
        $this->AdvertisingName = $var;

        return $this;
    }

    /**
     * Default: Admin12345 . This allows for a technician to use nRFToolBox, read the BLE Logs and send various commands.
     *
     * Generated from protobuf field <code>string TechnicianCode = 2;</code>
     * @return string
     */
    public function getTechnicianCode()
    {
        return $this->TechnicianCode;
    }

    /**
     * Default: Admin12345 . This allows for a technician to use nRFToolBox, read the BLE Logs and send various commands.
     *
     * Generated from protobuf field <code>string TechnicianCode = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setTechnicianCode($var)
    {
        GPBUtil::checkString($var, True);
        $this->TechnicianCode = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 5;</code>
     * @return \OS\PB\DeviceNetworkConfig|null
     */
    public function getOneSpaceProtobuf()
    {
        return $this->OneSpace_Protobuf;
    }

    public function hasOneSpaceProtobuf()
    {
        return isset($this->OneSpace_Protobuf);
    }

    public function clearOneSpaceProtobuf()
    {
        unset($this->OneSpace_Protobuf);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceNetworkConfig OneSpace_Protobuf = 5;</code>
     * @param \OS\PB\DeviceNetworkConfig $var
     * @return $this
     */
    public function setOneSpaceProtobuf($var)
    {
        GPBUtil::checkMessage($var, \OS\PB\DeviceNetworkConfig::class);
        $this->OneSpace_Protobuf = $var;

        return $this;
    }

}

