<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: action.proto

namespace GPBMetadata;

class Action
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Wiegand::initOnce();
        \GPBMetadata\Relay::initOnce();
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Osdp::initOnce();
        \GPBMetadata\Codehop::initOnce();
        \GPBMetadata\Dfu::initOnce();
        \GPBMetadata\Configsync::initOnce();
        \GPBMetadata\Access::initOnce();
        \GPBMetadata\Health::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xAF\x0D\x0A\x0Caction.proto\x12\x05OS.PB\x1A\x0Brelay.proto\x1A\x0Cdevice.proto\x1A\x0Aosdp.proto\x1A\x0Dcodehop.proto\x1A\x09dfu.proto\x1A\x10configsync.proto\x1A\x0Caccess.proto\x1A\x0Chealth.proto\"\x1F\x0A\x0ATestAction\x12\x11\x0A\x09TestValue\x18\x01 \x01(\x0D\"\xFB\x0B\x0A\x0DActionMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x12+\x0A\x0DRelayActivate\x18\x02 \x01(\x0B2\x12.OS.PB.RelayActionH\x00\x121\x0A\x11WiegandOkActivate\x18\x03 \x01(\x0B2\x14.OS.PB.WiegandActionH\x00\x124\x0A\x14WiegandErrorActivate\x18\x04 \x01(\x0B2\x14.OS.PB.WiegandActionH\x00\x125\x0A\x15WiegandBuzzerActivate\x18\x05 \x01(\x0B2\x14.OS.PB.WiegandActionH\x00\x121\x0A\x11CodeHopSetCounter\x18\x08 \x01(\x0B2\x14.OS.PB.CodeHopActionH\x00\x12,\x0A\x10DFUTransferBlock\x18\x0E \x01(\x0B2\x10.OS.PB.DFUActionH\x00\x12/\x0A\x10AccessUserAdjust\x18\x14 \x01(\x0B2\x13.OS.PB.AccessActionH\x00\x12/\x0A\x0BAccessErase\x18\x1E \x01(\x0B2\x18.OS.PB.AccessEraseActionH\x00\x12-\x0A\x0EAccessOverride\x18\x1F \x01(\x0B2\x13.OS.PB.AccessActionH\x00\x122\x0A\x0FAccessSyncBegin\x18( \x01(\x0B2\x17.OS.PB.ConfigSyncActionH\x00\x120\x0A\x0DAccessSyncEnd\x18) \x01(\x0B2\x17.OS.PB.ConfigSyncActionH\x00\x126\x0A\x17HealthButtonAcknowledge\x18d \x01(\x0B2\x13.OS.PB.HealthActionH\x00\x126\x0A\x17HealthLinkActivateAlert\x18n \x01(\x0B2\x13.OS.PB.HealthActionH\x00\x128\x0A\x19HealthLinkDeactivateAlert\x18o \x01(\x0B2\x13.OS.PB.HealthActionH\x00\x12?\x0A\x18DeviceRestartDEPRECIATED\x18\xAC\x02 \x01(\x0B2\x1A.OS.PB.DeviceRestartActionH\x00\x12-\x0A\x0DDeviceRestart\x18\xAD\x02 \x01(\x0B2\x13.OS.PB.DeviceActionH\x00\x12=\x0A\x17DeviceFormatDEPRECIATED\x18\xAE\x02 \x01(\x0B2\x19.OS.PB.DeviceFormatActionH\x00\x12,\x0A\x0CDeviceFormat\x18\xB1\x02 \x01(\x0B2\x13.OS.PB.DeviceActionH\x00\x12+\x0A\x0BDeviceErase\x18\xAF\x02 \x01(\x0B2\x13.OS.PB.DeviceActionH\x00\x12-\x0A\x0DDeviceExecute\x18\xB0\x02 \x01(\x0B2\x13.OS.PB.DeviceActionH\x00\x12=\x0A\x16DeviceDiscoveryRefresh\x18\xB6\x02 \x01(\x0B2\x1A.OS.PB.DeviceNetworkActionH\x00\x127\x0A\x10DeviceQueuePurge\x18\xBB\x02 \x01(\x0B2\x1A.OS.PB.DeviceNetworkActionH\x00\x127\x0A\x10DeviceRouteForce\x18\xC0\x02 \x01(\x0B2\x1A.OS.PB.DeviceNetworkActionH\x00\x120\x0A\x12RS485OSDPDiscovery\x18\xE8\x02 \x01(\x0B2\x11.OS.PB.OSDPActionH\x00\x12*\x0A\x0CRS485OSDPLED\x18\xE9\x02 \x01(\x0B2\x11.OS.PB.OSDPActionH\x00\x12-\x0A\x0FRS485OSDPBuzzer\x18\xEA\x02 \x01(\x0B2\x11.OS.PB.OSDPActionH\x00\x12+\x0A\x0DRS485OSDPText\x18\xEB\x02 \x01(\x0B2\x11.OS.PB.OSDPActionH\x00\x12-\x0A\x0FRS485OSDPOutput\x18\xEC\x02 \x01(\x0B2\x11.OS.PB.OSDPActionH\x00\x12\"\x0A\x04Test\x18\x90N \x01(\x0B2\x11.OS.PB.TestActionH\x00B\x0C\x0A\x0AActionTypeB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

