<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: bleassettrack.proto

namespace GPBMetadata;

class Bleassettrack
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\x87\x02\x0A\x13bleassettrack.proto\x12\x05OS.PB\"\xDC\x01\x0A\x12BleAssetTrackEvent\x12\x0E\x0A\x06New_id\x18\x01 \x03(\x0D\x12\x16\x0A\x0ENew_macAddress\x18\x02 \x03(\x04\x12\x13\x0A\x0BNew_rawData\x18\x03 \x03(\x0C\x12\x10\x0A\x08New_rssi\x18\x04 \x03(\x11\x12\x13\x0A\x0BNew_tsMinus\x18\x05 \x03(\x0D\x12\x0F\x0A\x07Lost_id\x18\x08 \x03(\x0D\x12\x11\x0A\x09Lost_rssi\x18\x09 \x03(\x11\x12\x14\x0A\x0CLost_tsMinus\x18\x0A \x03(\x0D\x12\x12\x0A\x0ACurrent_id\x18\x0C \x03(\x0D\x12\x14\x0A\x0CCurrent_rssi\x18\x0D \x03(\x11B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

