<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: input.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.InputEvent</code>
 */
class InputEvent extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.State InputState = 1;</code>
     */
    protected $InputState = 0;
    /**
     * Generated from protobuf field <code>.OS.PB.InputEvent.EOLStates EOLState = 2;</code>
     */
    protected $EOLState = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $InputState
     *     @type int $EOLState
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Input::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.State InputState = 1;</code>
     * @return int
     */
    public function getInputState()
    {
        return $this->InputState;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.State InputState = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setInputState($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\State::class);
        $this->InputState = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.InputEvent.EOLStates EOLState = 2;</code>
     * @return int
     */
    public function getEOLState()
    {
        return $this->EOLState;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.InputEvent.EOLStates EOLState = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setEOLState($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\InputEvent\EOLStates::class);
        $this->EOLState = $var;

        return $this;
    }

}

