<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: event.proto

namespace GPBMetadata;

class Event
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Wiegand::initOnce();
        \GPBMetadata\Relay::initOnce();
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Osdp::initOnce();
        \GPBMetadata\Ble::initOnce();
        \GPBMetadata\Input::initOnce();
        \GPBMetadata\Modem::initOnce();
        \GPBMetadata\Codehop::initOnce();
        \GPBMetadata\Dfu::initOnce();
        \GPBMetadata\Anpr::initOnce();
        \GPBMetadata\Configsync::initOnce();
        \GPBMetadata\Access::initOnce();
        \GPBMetadata\Health::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\x85*\x0A\x0Bevent.proto\x12\x05OS.PB\x1A\x0Brelay.proto\x1A\x0Cdevice.proto\x1A\x0Aosdp.proto\x1A\x09ble.proto\x1A\x0Binput.proto\x1A\x0Bmodem.proto\x1A\x0Dcodehop.proto\x1A\x09dfu.proto\x1A\x0Aanpr.proto\x1A\x10configsync.proto\x1A\x0Caccess.proto\x1A\x0Chealth.proto\"\xC2(\x0A\x0CEventMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x12-\x0A\x0EWiegandRawCode\x18\x02 \x01(\x0B2\x13.OS.PB.WiegandEventH\x00\x12-\x0A\x0EWiegandPinCode\x18\x03 \x01(\x0B2\x13.OS.PB.WiegandEventH\x00\x129\x0A\x16BLEBeSecureDEPRECIATED\x18\x04 \x01(\x0B2\x17.OS.PB.BLEBeSecureEventH\x00\x12&\x0A\x0BBLEBeSecure\x18\x05 \x01(\x0B2\x0F.OS.PB.BLEEventH\x00\x12,\x0A\x10RS485OSDPRawCode\x18\x06 \x01(\x0B2\x10.OS.PB.OSDPEventH\x00\x12,\x0A\x10RS485OSDPPinCode\x18\x07 \x01(\x0B2\x10.OS.PB.OSDPEventH\x00\x12,\x0A\x0DCodeHopKeeloq\x18\x08 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x124\x0A\x15CodeHopKeeloqReplayed\x18\x09 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x124\x0A\x15CodeHopKeeloqDeSynced\x18\x10 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x124\x0A\x15CodeHopKeeloqReSynced\x18\x11 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x12-\x0A\x10RelayStateChange\x18\x0A \x01(\x0B2\x11.OS.PB.RelayEventH\x00\x12-\x0A\x10InputStateChange\x18\x0B \x01(\x0B2\x11.OS.PB.InputEventH\x00\x120\x0A\x14RS485ANPRNumberPlate\x18\x0C \x01(\x0B2\x10.OS.PB.ANPREventH\x00\x12'\x0A\x0CBLEAdvHealth\x18\x0D \x01(\x0B2\x0F.OS.PB.BLEEventH\x00\x12+\x0A\x0DAccessAllowed\x18\x14 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12-\x0A\x0FAccessConfirmed\x18\x15 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12/\x0A\x11AccessUnconfirmed\x18\x16 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x126\x0A\x18AccessNoTouchDEPRECIATED\x18\x17 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x129\x0A\x1BAccessPushButtonDEPRECIATED\x18\x18 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12>\x0A AccessEmergencyButtonDEPRECIATED\x18\x19 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12;\x0A\x1DAccessLoopDetectorDEPRECIATED\x18\x1A \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12.\x0A\x10AccessOverridden\x18\x1B \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x127\x0A\x19AccessMethodDeniedUnknown\x18\x1E \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12<\x0A\x1EAccessMethodDeniedZeroUIDEvent\x18\x1F \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12:\x0A\x1CAccessMethodDeniedDaysOfWeek\x18  \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x128\x0A\x1AAccessMethodDeniedNoRights\x18! \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12<\x0A\x1EAccessMethodDeniedUserNotFound\x18\" \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12?\x0A!AccessMethodDeniedGatewayDisabled\x18# \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12=\x0A\x1FAccessMethodDeniedReaderUnknown\x18\$ \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12@\x0A\"AccessMethodDeniedReaderDaysOfWeek\x18% \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12@\x0A\"AccessMethodDeniedReaderTimesOfDay\x18& \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12;\x0A\x1DAccessMethodDeniedInvalidData\x18' \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x126\x0A\x18AccessRightsDeniedReader\x18( \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12:\x0A\x1CAccessRightsDeniedDaysOfWeek\x18) \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x129\x0A\x1BAccessRightsDeniedTimeOfDay\x18* \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x126\x0A\x18AccessUserDeniedNoRights\x182 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12;\x0A\x1DAccessUserDeniedNoEntriesLeft\x183 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x129\x0A\x1BAccessUserDeniedNoExitsLeft\x184 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x129\x0A\x1BAccessUserDeniedFutureDated\x185 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x125\x0A\x17AccessUserDeniedExpired\x186 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12C\x0A%AccessUserDeniedEntryAllExitsRedeemed\x187 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x12D\x0A&AccessUserDeniedExitAllEntriesRedeemed\x188 \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x121\x0A\x13AccessEnrolProgress\x18P \x01(\x0B2\x12.OS.PB.AccessEventH\x00\x121\x0A\x0FAccessSyncReady\x18Z \x01(\x0B2\x16.OS.PB.ConfigSyncEventH\x00\x124\x0A\x12AccessSyncProgress\x18[ \x01(\x0B2\x16.OS.PB.ConfigSyncEventH\x00\x120\x0A\x0EAccessSyncDone\x18_ \x01(\x0B2\x16.OS.PB.ConfigSyncEventH\x00\x122\x0A\x10AccessSyncFailed\x18` \x01(\x0B2\x16.OS.PB.ConfigSyncEventH\x00\x125\x0A\x0FAccessCompacted\x18b \x01(\x0B2\x1A.OS.PB.AccessDatabaseEventH\x00\x126\x0A\x10AccessCorruption\x18c \x01(\x0B2\x1A.OS.PB.AccessDatabaseEventH\x00\x124\x0A\x15HealthButtonHeartBeat\x18\xC8\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x125\x0A\x16HealthButtonPressAlert\x18\xC9\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x124\x0A\x15HealthButtonFallAlert\x18\xCA\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x124\x0A\x15HealthButtonEnrolment\x18\xCB\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x125\x0A\x16HealthLinkExpiredAlert\x18\xD2\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x127\x0A\x18HealthLinkMonitoredAlert\x18\xD3\x01 \x01(\x0B2\x12.OS.PB.HealthEventH\x00\x12>\x0A\x18DeviceRestartDEPRECIATED\x18\xAC\x02 \x01(\x0B2\x19.OS.PB.DeviceRestartEventH\x00\x12<\x0A\x17DeviceFormatDEPRECIATED\x18\xAD\x02 \x01(\x0B2\x18.OS.PB.DeviceFormatEventH\x00\x12,\x0A\x0DDeviceRestart\x18\xAE\x02 \x01(\x0B2\x12.OS.PB.DeviceEventH\x00\x12+\x0A\x0CDeviceFormat\x18\xAF\x02 \x01(\x0B2\x12.OS.PB.DeviceEventH\x00\x125\x0A\x0FDeviceConnected\x18\xB6\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12<\x0A\x16DeviceConnectionDenied\x18\xB7\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12>\x0A\x18DeviceConnectionMismatch\x18\xB8\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x128\x0A\x12DeviceUnconfigured\x18\xBB\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x128\x0A\x12DeviceDisconnected\x18\xC0\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12@\x0A\x1ADeviceDisconnectedTimedOut\x18\xC1\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12=\x0A\x17DeviceDisconnectedError\x18\xC2\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12?\x0A\x19DeviceDisconnectedRemoved\x18\xC4\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12D\x0A\x1EDeviceDisconnectedChangingSims\x18\xC5\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12C\x0A\x1DDeviceDisconnectedLostNetwork\x18\xC6\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x126\x0A\x10DeviceDiscovered\x18\xC7\x02 \x01(\x0B2\x19.OS.PB.DeviceNetworkEventH\x00\x12(\x0A\x0CDFUInitiated\x18\xDE\x02 \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x12)\x0A\x0EDFUDownloading\x18\x0F \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x12(\x0A\x0CDFUVerifying\x18\xE0\x02 \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x12)\x0A\x0DDFUValidating\x18\xE1\x02 \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x12(\x0A\x0CDFUCompleted\x18\xE2\x02 \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x12%\x0A\x09DFUFailed\x18\xE3\x02 \x01(\x0B2\x0F.OS.PB.DFUEventH\x00\x123\x0A\x16RS485OSDPDeviceOffline\x18\xE8\x02 \x01(\x0B2\x10.OS.PB.OSDPEventH\x00\x122\x0A\x15RS485OSDPDeviceOnline\x18\xE9\x02 \x01(\x0B2\x10.OS.PB.OSDPEventH\x00\x127\x0A\x1ARS485OSDPPinCodeIncomplete\x18\xED\x02 \x01(\x0B2\x10.OS.PB.OSDPEventH\x00\x128\x0A\x18WiegandPinCodeIncomplete\x18\xF2\x02 \x01(\x0B2\x13.OS.PB.WiegandEventH\x00\x121\x0A\x11WiegandAntiTamper\x18\xF3\x02 \x01(\x0B2\x13.OS.PB.WiegandEventH\x00\x12-\x0A\x10RS485ANPRNoPlate\x18\xF7\x02 \x01(\x0B2\x10.OS.PB.ANPREventH\x00\x12-\x0A\x0DCodeHopEnroll\x18\xFC\x02 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x125\x0A\x15CodeHopModuleDetected\x18\xFD\x02 \x01(\x0B2\x13.OS.PB.CodeHopEventH\x00\x120\x0A\x12ModemSIMRegistered\x18\x86\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x128\x0A\x1AModemSIMRegistrationFailed\x18\x87\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x128\x0A\x1AModemSIMRegistrationDenied\x18\x88\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x12/\x0A\x11ModemSIMOutOfData\x18\x89\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x126\x0A\x18ModemSIMNoInternetOrData\x18\x8A\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x12:\x0A\x1CModemSIMNotInsertedOrEjected\x18\x8B\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x121\x0A\x13ModemSIMPinRequired\x18\x8C\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x121\x0A\x13ModemSIMPUKRequired\x18\x8D\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x12-\x0A\x0FModemSIMFailure\x18\x8E\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00\x122\x0A\x14ModemSIMUnrecognised\x18\x8F\x03 \x01(\x0B2\x11.OS.PB.ModemEventH\x00B\x0B\x0A\x09EventTypeB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

