<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wiegand.proto

namespace GPBMetadata;

class Wiegand
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xFA\x07\x0A\x0Dwiegand.proto\x12\x05OS.PB\"B\x0A\x0CWiegandEvent\x12\x0F\x0A\x07RawCode\x18\x01 \x01(\x0C\x12\x0C\x0A\x04Code\x18\x02 \x01(\x04\x12\x13\x0A\x0BRawBitCount\x18\x05 \x01(\x0D\"H\x0A\x0DWiegandAction\x12\x12\x0A\x0ADurationMs\x18\x01 \x01(\x0D\x12\x0F\x0A\x07BlinkMs\x18\x02 \x01(\x0D\x12\x12\x0A\x0ABlinkOffMs\x18\x03 \x01(\x0D\"\xFB\x01\x0A\x0DWiegandMetric\x12\x14\x0A\x0CParityErrors\x18\x01 \x01(\x0D\x12\x15\x0A\x0DNoiseReceived\x18\x02 \x01(\x0D\x12\x15\x0A\x0DMalformedData\x18\x03 \x01(\x0D\x12\x17\x0A\x0FIncorrectDigits\x18\x04 \x01(\x0D\x12\x14\x0A\x0CBitsReceived\x18\x0A \x01(\x0D\x12\x13\x0A\x0BKeysPressed\x18\x0B \x01(\x0D\x12\x15\x0A\x0DOkActivations\x18\x0C \x01(\x0D\x12\x18\x0A\x10ErrorActivations\x18\x0D \x01(\x0D\x12\x19\x0A\x11BuzzerActivations\x18\x0E \x01(\x0D\x12\x16\x0A\x0ETamperTriggers\x18\x0F \x01(\x0D\"\xEE\x03\x0A\x0DWiegandConfig\x12\x1C\x0A\x05State\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x14\x0A\x0CWaitPeriodMs\x18\x02 \x01(\x0D\x12\$\x0A\x0DSwapDataLines\x18\x03 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x1A\x0A\x12SameRawCodeTimeout\x18\x04 \x01(\x0D\x124\x0A\x0AKeypadMode\x18\x08 \x01(\x0E2 .OS.PB.WiegandConfig.KeypadModes\x12\x14\x0A\x0CKeypadDigits\x18\x09 \x01(\x0D\x12\x1A\x0A\x12KeypadResetTimeout\x18\x0A \x01(\x0D\x120\x0A\x08LineMode\x18\x0D \x01(\x0E2\x1E.OS.PB.WiegandConfig.LineModes\"}\x0A\x0BKeypadModes\x12\x15\x0A\x11KeypadMode_NotSet\x10\x00\x12\x17\x0A\x13KeypadMode_Disabled\x10\x01\x12\x1A\x0A\x16KeypadMode_KeyBitBurst\x10\x02\x12\"\x0A\x1EKeypadMode_KeyBitBurst_AutoEnd\x10\x03\"N\x0A\x09LineModes\x12\x13\x0A\x0FLineMode_NotSet\x10\x00\x12\x17\x0A\x13LineMode_Controlled\x10\x01\x12\x13\x0A\x0FLineMode_Pulsed\x10\x02\" \x0A\x0EWiegandRequest\x12\x0E\x0A\x06Config\x18\x01 \x01(\x08\"7\x0A\x0FWiegandResponse\x12\$\x0A\x06Config\x18\x01 \x01(\x0B2\x14.OS.PB.WiegandConfigB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

