<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace GPBMetadata;

class Health
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xCC\x07\x0A\x0Chealth.proto\x12\x05OS.PB\x1A\x0Btypes.proto\"\x86\x02\x0A\x0BHealthEvent\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x0F\x0A\x07AlertId\x18\x02 \x01(\x0D\x12%\x0A\x04Role\x18\x04 \x01(\x0E2\x17.OS.PB.HealthButtonRole\x12\x0C\x0A\x04RSSI\x18\x05 \x01(\x11\x12\x0F\x0A\x07TxPower\x18\x06 \x01(\x11\x12\x16\x0A\x0EBatteryVoltage\x18\x07 \x01(\x0D\x12\x17\x0A\x0FBatteryBrownout\x18\x08 \x01(\x08\x12.\x0A\x09Distances\x18\x0A \x03(\x0B2\x1B.OS.PB.HealthEvent.Distance\x1A/\x0A\x08Distance\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x13\x0A\x0BMeasurement\x18\x02 \x01(\x0D\"\$\x0A\x12HealthButtonConfig\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\"A\x0A\x0CHealthAction\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x0F\x0A\x07AlertId\x18\x02 \x01(\x0D\x12\x10\x0A\x08Duration\x18\x03 \x01(\x0D\"\xF7\x01\x0A\x10HealthLinkConfig\x12\x1C\x0A\x05State\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x12#\x0A\x04Role\x18\x02 \x01(\x0E2\x15.OS.PB.HealthLinkRole\x12\x19\x0A\x11WardStationLinkId\x18\x04 \x01(\x04\x12.\x0A\x0EAlertInterface\x18\x05 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x1B\x0A\x13AlertInterfaceIndex\x18\x06 \x01(\x0D\x12\x1A\x0A\x12AlertRSSIThreshold\x18\x0A \x01(\x11\x12\x1C\x0A\x14MonitorRSSIThreshold\x18\x0B \x01(\x11*\x9C\x01\x0A\x10HealthButtonRole\x12\x1B\x0A\x17HealthButtonRole_NotSet\x10\x00\x12\x19\x0A\x15Health_Patient_Button\x10\x01\x12\x1B\x0A\x17Health_Monitored_Button\x10\x02\x12\x17\x0A\x13Health_Staff_Button\x10\x03\x12\x1A\x0A\x16Health_Personal_Button\x10\x04*\x90\x01\x0A\x0EHealthLinkRole\x12\x19\x0A\x15HealthLinkRole_NotSet\x10\x00\x12\x14\x0A\x10Health_Care_Link\x10\x10\x12\x1E\x0A\x1AHealth_Monitored_Care_Link\x10 \x12\x14\x0A\x10Health_Home_Link\x100\x12\x17\x0A\x13Health_Village_Link\x10@B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

