<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.HealthAction</code>
 */
class HealthAction extends \Google\Protobuf\Internal\Message
{
    /**
     * The serial to clear
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     */
    protected $Serial = 0;
    /**
     * Used to clear alert event on Button by its Id
     *
     * Generated from protobuf field <code>uint32 AlertId = 2;</code>
     */
    protected $AlertId = 0;
    /**
     * The duration to activate the alert for before automatically timing out
     *
     * Generated from protobuf field <code>uint32 Duration = 3;</code>
     */
    protected $Duration = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Serial
     *           The serial to clear
     *     @type int $AlertId
     *           Used to clear alert event on Button by its Id
     *     @type int $Duration
     *           The duration to activate the alert for before automatically timing out
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * The serial to clear
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @return int
     */
    public function getSerial()
    {
        return $this->Serial;
    }

    /**
     * The serial to clear
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setSerial($var)
    {
        GPBUtil::checkUint32($var);
        $this->Serial = $var;

        return $this;
    }

    /**
     * Used to clear alert event on Button by its Id
     *
     * Generated from protobuf field <code>uint32 AlertId = 2;</code>
     * @return int
     */
    public function getAlertId()
    {
        return $this->AlertId;
    }

    /**
     * Used to clear alert event on Button by its Id
     *
     * Generated from protobuf field <code>uint32 AlertId = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setAlertId($var)
    {
        GPBUtil::checkUint32($var);
        $this->AlertId = $var;

        return $this;
    }

    /**
     * The duration to activate the alert for before automatically timing out
     *
     * Generated from protobuf field <code>uint32 Duration = 3;</code>
     * @return int
     */
    public function getDuration()
    {
        return $this->Duration;
    }

    /**
     * The duration to activate the alert for before automatically timing out
     *
     * Generated from protobuf field <code>uint32 Duration = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setDuration($var)
    {
        GPBUtil::checkUint32($var);
        $this->Duration = $var;

        return $this;
    }

}

