<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: input.proto

namespace GPBMetadata;

class Input
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xA5\x03\x0A\x0Binput.proto\x12\x05OS.PB\"\x9B\x01\x0A\x0AInputEvent\x12 \x0A\x0AInputState\x18\x01 \x01(\x0E2\x0C.OS.PB.State\x12-\x0A\x08EOLState\x18\x02 \x01(\x0E2\x1B.OS.PB.InputEvent.EOLStates\"<\x0A\x09EOLStates\x12\x0E\x0A\x0AEOL_NotSet\x10\x00\x12\x0F\x0A\x0BEOL_Shorted\x10\x01\x12\x0E\x0A\x0AEOL_Opened\x10\x02\"g\x0A\x0BInputConfig\x12\x1D\x0A\x06Invert\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x12!\x0A\x0AEOLSensing\x18\x02 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x16\x0A\x0EDebouncePeriod\x18\x05 \x01(\x0D\"'\x0A\x0BInputMetric\x12\x18\x0A\x10TotalActivations\x18\x01 \x01(\x0D\"\x1E\x0A\x0CInputRequest\x12\x0E\x0A\x06Config\x18\x01 \x01(\x08\"3\x0A\x0DInputResponse\x12\"\x0A\x06Config\x18\x01 \x01(\x0B2\x12.OS.PB.InputConfigB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

