<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wiegand.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 ** \@brief Activate the a Wiegand Line Output
 *
 * Generated from protobuf message <code>OS.PB.WiegandAction</code>
 */
class WiegandAction extends \Google\Protobuf\Internal\Message
{
    /**
     * How long the line should be enabled for
     *
     * Generated from protobuf field <code>uint32 DurationMs = 1;</code>
     */
    protected $DurationMs = 0;
    /**
     * Blink feature 
     *
     * Generated from protobuf field <code>uint32 BlinkMs = 2;</code>
     */
    protected $BlinkMs = 0;
    /**
     * if 0, then assumes the same value as BlinkMs. Determines how long the line is held high (inactive) for during blinking
     *
     * Generated from protobuf field <code>uint32 BlinkOffMs = 3;</code>
     */
    protected $BlinkOffMs = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $DurationMs
     *           How long the line should be enabled for
     *     @type int $BlinkMs
     *           Blink feature 
     *     @type int $BlinkOffMs
     *           if 0, then assumes the same value as BlinkMs. Determines how long the line is held high (inactive) for during blinking
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Wiegand::initOnce();
        parent::__construct($data);
    }

    /**
     * How long the line should be enabled for
     *
     * Generated from protobuf field <code>uint32 DurationMs = 1;</code>
     * @return int
     */
    public function getDurationMs()
    {
        return $this->DurationMs;
    }

    /**
     * How long the line should be enabled for
     *
     * Generated from protobuf field <code>uint32 DurationMs = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setDurationMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->DurationMs = $var;

        return $this;
    }

    /**
     * Blink feature 
     *
     * Generated from protobuf field <code>uint32 BlinkMs = 2;</code>
     * @return int
     */
    public function getBlinkMs()
    {
        return $this->BlinkMs;
    }

    /**
     * Blink feature 
     *
     * Generated from protobuf field <code>uint32 BlinkMs = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setBlinkMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->BlinkMs = $var;

        return $this;
    }

    /**
     * if 0, then assumes the same value as BlinkMs. Determines how long the line is held high (inactive) for during blinking
     *
     * Generated from protobuf field <code>uint32 BlinkOffMs = 3;</code>
     * @return int
     */
    public function getBlinkOffMs()
    {
        return $this->BlinkOffMs;
    }

    /**
     * if 0, then assumes the same value as BlinkMs. Determines how long the line is held high (inactive) for during blinking
     *
     * Generated from protobuf field <code>uint32 BlinkOffMs = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setBlinkOffMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->BlinkOffMs = $var;

        return $this;
    }

}

