<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eventrules.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.EventRulesEraseConfig</code>
 */
class EventRulesEraseConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * must be set to true to erase the entire config
     *
     * Generated from protobuf field <code>bool AllRules = 1;</code>
     */
    protected $AllRules = false;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type bool $AllRules
     *           must be set to true to erase the entire config
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Eventrules::initOnce();
        parent::__construct($data);
    }

    /**
     * must be set to true to erase the entire config
     *
     * Generated from protobuf field <code>bool AllRules = 1;</code>
     * @return bool
     */
    public function getAllRules()
    {
        return $this->AllRules;
    }

    /**
     * must be set to true to erase the entire config
     *
     * Generated from protobuf field <code>bool AllRules = 1;</code>
     * @param bool $var
     * @return $this
     */
    public function setAllRules($var)
    {
        GPBUtil::checkBool($var);
        $this->AllRules = $var;

        return $this;
    }

}

