<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.CodeHopMetric</code>
 */
class CodeHopMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * How many remotes were received, regardless of ignoring based on RSSI or Counter
     *
     * Generated from protobuf field <code>uint32 ReceivedCount = 1;</code>
     */
    protected $ReceivedCount = 0;
    /**
     * How many remotes were ignored due not meeting minimum RSSI
     *
     * Generated from protobuf field <code>uint32 RSSIIgnored = 2;</code>
     */
    protected $RSSIIgnored = 0;
    /**
     * How many remotes were blocked because their counter was less than or equal to current stored codehop counter
     *
     * Generated from protobuf field <code>uint32 CounterBlocked = 3;</code>
     */
    protected $CounterBlocked = 0;
    /**
     * How many remotes were ignored because they failed to decrypt
     *
     * Generated from protobuf field <code>uint32 DecryptFails = 4;</code>
     */
    protected $DecryptFails = 0;
    /**
     * How many remotes were desycned because their counter was 16 counts above the stored value
     *
     * Generated from protobuf field <code>uint32 CounterDeSynced = 5;</code>
     */
    protected $CounterDeSynced = 0;
    /**
     * How many remotes were resynced because their counter after the button being pushed again within 16
     *
     * Generated from protobuf field <code>uint32 CounterReSynced = 6;</code>
     */
    protected $CounterReSynced = 0;
    /**
     * How many remotes where the counter was considered valid
     *
     * Generated from protobuf field <code>uint32 CounterValid = 7;</code>
     */
    protected $CounterValid = 0;
    /**
     * How many remotes where the counter wasn't found in our database
     *
     * Generated from protobuf field <code>uint32 CounterNotFound = 8;</code>
     */
    protected $CounterNotFound = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $ReceivedCount
     *           How many remotes were received, regardless of ignoring based on RSSI or Counter
     *     @type int $RSSIIgnored
     *           How many remotes were ignored due not meeting minimum RSSI
     *     @type int $CounterBlocked
     *           How many remotes were blocked because their counter was less than or equal to current stored codehop counter
     *     @type int $DecryptFails
     *           How many remotes were ignored because they failed to decrypt
     *     @type int $CounterDeSynced
     *           How many remotes were desycned because their counter was 16 counts above the stored value
     *     @type int $CounterReSynced
     *           How many remotes were resynced because their counter after the button being pushed again within 16
     *     @type int $CounterValid
     *           How many remotes where the counter was considered valid
     *     @type int $CounterNotFound
     *           How many remotes where the counter wasn't found in our database
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Codehop::initOnce();
        parent::__construct($data);
    }

    /**
     * How many remotes were received, regardless of ignoring based on RSSI or Counter
     *
     * Generated from protobuf field <code>uint32 ReceivedCount = 1;</code>
     * @return int
     */
    public function getReceivedCount()
    {
        return $this->ReceivedCount;
    }

    /**
     * How many remotes were received, regardless of ignoring based on RSSI or Counter
     *
     * Generated from protobuf field <code>uint32 ReceivedCount = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setReceivedCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->ReceivedCount = $var;

        return $this;
    }

    /**
     * How many remotes were ignored due not meeting minimum RSSI
     *
     * Generated from protobuf field <code>uint32 RSSIIgnored = 2;</code>
     * @return int
     */
    public function getRSSIIgnored()
    {
        return $this->RSSIIgnored;
    }

    /**
     * How many remotes were ignored due not meeting minimum RSSI
     *
     * Generated from protobuf field <code>uint32 RSSIIgnored = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setRSSIIgnored($var)
    {
        GPBUtil::checkUint32($var);
        $this->RSSIIgnored = $var;

        return $this;
    }

    /**
     * How many remotes were blocked because their counter was less than or equal to current stored codehop counter
     *
     * Generated from protobuf field <code>uint32 CounterBlocked = 3;</code>
     * @return int
     */
    public function getCounterBlocked()
    {
        return $this->CounterBlocked;
    }

    /**
     * How many remotes were blocked because their counter was less than or equal to current stored codehop counter
     *
     * Generated from protobuf field <code>uint32 CounterBlocked = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setCounterBlocked($var)
    {
        GPBUtil::checkUint32($var);
        $this->CounterBlocked = $var;

        return $this;
    }

    /**
     * How many remotes were ignored because they failed to decrypt
     *
     * Generated from protobuf field <code>uint32 DecryptFails = 4;</code>
     * @return int
     */
    public function getDecryptFails()
    {
        return $this->DecryptFails;
    }

    /**
     * How many remotes were ignored because they failed to decrypt
     *
     * Generated from protobuf field <code>uint32 DecryptFails = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setDecryptFails($var)
    {
        GPBUtil::checkUint32($var);
        $this->DecryptFails = $var;

        return $this;
    }

    /**
     * How many remotes were desycned because their counter was 16 counts above the stored value
     *
     * Generated from protobuf field <code>uint32 CounterDeSynced = 5;</code>
     * @return int
     */
    public function getCounterDeSynced()
    {
        return $this->CounterDeSynced;
    }

    /**
     * How many remotes were desycned because their counter was 16 counts above the stored value
     *
     * Generated from protobuf field <code>uint32 CounterDeSynced = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setCounterDeSynced($var)
    {
        GPBUtil::checkUint32($var);
        $this->CounterDeSynced = $var;

        return $this;
    }

    /**
     * How many remotes were resynced because their counter after the button being pushed again within 16
     *
     * Generated from protobuf field <code>uint32 CounterReSynced = 6;</code>
     * @return int
     */
    public function getCounterReSynced()
    {
        return $this->CounterReSynced;
    }

    /**
     * How many remotes were resynced because their counter after the button being pushed again within 16
     *
     * Generated from protobuf field <code>uint32 CounterReSynced = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setCounterReSynced($var)
    {
        GPBUtil::checkUint32($var);
        $this->CounterReSynced = $var;

        return $this;
    }

    /**
     * How many remotes where the counter was considered valid
     *
     * Generated from protobuf field <code>uint32 CounterValid = 7;</code>
     * @return int
     */
    public function getCounterValid()
    {
        return $this->CounterValid;
    }

    /**
     * How many remotes where the counter was considered valid
     *
     * Generated from protobuf field <code>uint32 CounterValid = 7;</code>
     * @param int $var
     * @return $this
     */
    public function setCounterValid($var)
    {
        GPBUtil::checkUint32($var);
        $this->CounterValid = $var;

        return $this;
    }

    /**
     * How many remotes where the counter wasn't found in our database
     *
     * Generated from protobuf field <code>uint32 CounterNotFound = 8;</code>
     * @return int
     */
    public function getCounterNotFound()
    {
        return $this->CounterNotFound;
    }

    /**
     * How many remotes where the counter wasn't found in our database
     *
     * Generated from protobuf field <code>uint32 CounterNotFound = 8;</code>
     * @param int $var
     * @return $this
     */
    public function setCounterNotFound($var)
    {
        GPBUtil::checkUint32($var);
        $this->CounterNotFound = $var;

        return $this;
    }

}

