<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rs485.proto

namespace GPBMetadata;

class Rs485
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Osdp::initOnce();
        \GPBMetadata\Anpr::initOnce();
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xE3\x09\x0A\x0Brs485.proto\x12\x05OS.PB\x1A\x0Aosdp.proto\x1A\x0Aanpr.proto\x1A\x0Btypes.proto\"\x89\x03\x0A\x0BRS485Metric\x12\x18\x0A\x10BytesTransmitted\x18\x01 \x01(\x0D\x12\x15\x0A\x0DBytesReceived\x18\x02 \x01(\x0D\x12\x1E\x0A\x16BytesReceivedExclusive\x18\x03 \x01(\x0D\x12\x1C\x0A\x14ReceiveOverrunErrors\x18\x04 \x01(\x0D\x12\x1C\x0A\x14ReceiveFramingErrors\x18\x05 \x01(\x0D\x12\x1A\x0A\x12ReceiveBreakErrors\x18\x06 \x01(\x0D\x12\x1A\x0A\x12PacketsTransmitted\x18\x07 \x01(\x0D\x12\x17\x0A\x0FPacketsReceived\x18\x08 \x01(\x0D\x12 \x0A\x18PacketsReceivedExclusive\x18\x09 \x01(\x0D\x12\x14\x0A\x0CPacketsACKed\x18\x0A \x01(\x0D\x12\x15\x0A\x0DPacketsNACKed\x18\x0B \x01(\x0D\x12\x18\x0A\x10PacketsCorrupted\x18\x0C \x01(\x0D\x12\x17\x0A\x0FPacketsTimedout\x18\x0D \x01(\x0D\x12\x1A\x0A\x12PacketsIgnoredSpam\x18\x0E \x01(\x0D\"+\x0A\x13RS485LoopbackConfig\x12\x14\x0A\x0CWaitPeriodMs\x18\x01 \x01(\x0D\"\x9D\x02\x0A\x0BRS485Config\x12*\x0A\x08BaudRate\x18\x01 \x01(\x0E2\x18.OS.PB.RS485BaudRateType\x12\x1C\x0A\x05State\x18\x02 \x01(\x0E2\x0D.OS.PB.Toggle\x12.\x0A\x08Loopback\x18\x05 \x01(\x0B2\x1A.OS.PB.RS485LoopbackConfigH\x00\x127\x0A\x11OneSpace_Protobuf\x18\x06 \x01(\x0B2\x1A.OS.PB.DeviceNetworkConfigH\x00\x12%\x0A\x08SIA_OSDP\x18\x08 \x01(\x0B2\x11.OS.PB.OSDPConfigH\x00\x12(\x0A\x0BANPR_Camera\x18\x09 \x01(\x0B2\x11.OS.PB.ANPRConfigH\x00B\x0A\x0A\x08Protocol\"\x1E\x0A\x0CRS485Request\x12\x0E\x0A\x06Config\x18\x01 \x01(\x08\"3\x0A\x0DRS485Response\x12\"\x0A\x06Config\x18\x01 \x01(\x0B2\x12.OS.PB.RS485Config*\xED\x02\x0A\x11RS485BaudRateType\x12\x13\x0A\x0FBaudRate_NotSet\x10\x00\x12\x12\x0A\x0DBaudRate_1200\x10\xB0\x09\x12\x12\x0A\x0DBaudRate_2400\x10\xE0\x12\x12\x12\x0A\x0DBaudRate_4800\x10\xC0%\x12\x12\x0A\x0DBaudRate_9600\x10\x80K\x12\x13\x0A\x0EBaudRate_14400\x10\xC0p\x12\x14\x0A\x0EBaudRate_19200\x10\x80\x96\x01\x12\x14\x0A\x0EBaudRate_28800\x10\x80\xE1\x01\x12\x14\x0A\x0EBaudRate_31250\x10\x92\xF4\x01\x12\x14\x0A\x0EBaudRate_38400\x10\x80\xAC\x02\x12\x14\x0A\x0EBaudRate_56000\x10\xC0\xB5\x03\x12\x14\x0A\x0EBaudRate_57600\x10\x80\xC2\x03\x12\x14\x0A\x0EBaudRate_76800\x10\x80\xD8\x04\x12\x15\x0A\x0FBaudRate_115200\x10\x80\x84\x07\x12\x15\x0A\x0FBaudRate_250000\x10\x90\xA1\x0F\x12\x16\x0A\x10BaudRate_1000000\x10\xC0\x84=B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

