<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace GPBMetadata;

class Ble
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xC5\x06\x0A\x09ble.proto\x12\x05OS.PB\"s\x0A\x09BLEConfig\x12\x17\x0A\x0FAdvertisingName\x18\x01 \x01(\x09\x12\x16\x0A\x0ETechnicianCode\x18\x02 \x01(\x09\x125\x0A\x11OneSpace_Protobuf\x18\x05 \x01(\x0B2\x1A.OS.PB.DeviceNetworkConfig\"\xA9\x01\x0A\x10BLEBeSecureEvent\x12)\x0A\x09Interface\x18\x01 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceIndex\x18\x02 \x01(\x0D\x12\x15\x0A\x0DDeviceAddress\x18\x06 \x01(\x0C\x12\x14\x0A\x0CSerialNumber\x18\x0A \x01(\x0D\x12\x14\x0A\x0CFunctionCode\x18\x0B \x01(\x0D\x12\x0F\x0A\x07Payload\x18\x0C \x01(\x0C\"\xAC\x01\x0A\x08BLEEvent\x12#\x0A\x07BLERole\x18\x05 \x01(\x0E2\x12.OS.PB.BLERoleType\x12\x11\x0A\x09BTAddress\x18\x06 \x01(\x0C\x12+\x0A\x0DBTAddressType\x18\x07 \x01(\x0E2\x14.OS.PB.BTAddressType\x12\x14\x0A\x0CSerialNumber\x18\x0A \x01(\x0D\x12\x14\x0A\x0CFunctionCode\x18\x0B \x01(\x0D\x12\x0F\x0A\x07Payload\x18\x0C \x01(\x0C\"\x0B\x0A\x09BLEMetric\"#\x0A\x0ABLERequest\x12\x15\x0A\x0DIncludeConfig\x18\x01 \x01(\x08\"B\x0A\x0BBLEResponse\x12 \x0A\x06Config\x18\x01 \x01(\x0B2\x10.OS.PB.BLEConfig\x12\x11\x0A\x09BTAddress\x18\x02 \x01(\x0C*\xA2\x01\x0A\x0DBTAddressType\x12\x14\x0A\x10BTAddress_Public\x10\x00\x12\x14\x0A\x10BTAddress_Random\x10\x01\x12\x17\x0A\x13BTAddress_Public_Id\x10\x02\x12\x17\x0A\x13BTAddress_Random_Id\x10\x03\x12\x19\x0A\x14BTAddress_Unresolved\x10\xFE\x01\x12\x18\x0A\x13BTAddress_Anonymous\x10\xFF\x01*:\x0A\x0BBLERoleType\x12\x16\x0A\x12BLERole_Peripheral\x10\x00\x12\x13\x0A\x0FBLERole_Central\x10\x01B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

