<?php

return [
    'allowCron' => true,
    'serviceUrls' => [
        'userApi' => getenv('SERVICE_URL_USER_API') ?: 'https://dev.id.1s.co.za/api/v1/user/',
        'serviceApi' => getenv('SERVICE_URL_SERVICE_API') ?: 'https://dev.id.1s.co.za/api/v1/service/',
        'userUi' => getenv('SERVICE_URL_USER_UI') ?: 'https://dev.id.1s.co.za/',
    ],
    'baseImagePath' => (getenv('IMAGE_SERVICE_BASE_PATH') ?: 'dev.app.1s.co.za/'),
];