<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: modem.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.ModemEvent</code>
 */
class ModemEvent extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.ModemSIMSlot SIMSlot = 5;</code>
     */
    protected $SIMSlot = 0;
    /**
     * Integrated Circuit Card Id - SIM Card Serial
     *
     * Generated from protobuf field <code>string ICCID = 6;</code>
     */
    protected $ICCID = '';
    /**
     * International Mobile Subscriber Number
     *
     * Generated from protobuf field <code>string IMSI = 7;</code>
     */
    protected $IMSI = '';
    /**
     * Mobile Country Code and Mobile Network Code (65501 for Vodacom, 65510 for MTN) from Operator
     *
     * Generated from protobuf field <code>uint32 MCCMNC = 8;</code>
     */
    protected $MCCMNC = 0;
    /**
     * location area code reported by tower
     *
     * Generated from protobuf field <code>uint32 LAC = 9;</code>
     */
    protected $LAC = 0;
    /**
     * Cell Id reported by tower
     *
     * Generated from protobuf field <code>uint32 CellId = 10;</code>
     */
    protected $CellId = 0;
    /**
     * Network Operator Name (eg: Vodacom-SA or MTN-SA)
     *
     * Generated from protobuf field <code>string Operator = 11;</code>
     */
    protected $Operator = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $SIMSlot
     *     @type string $ICCID
     *           Integrated Circuit Card Id - SIM Card Serial
     *     @type string $IMSI
     *           International Mobile Subscriber Number
     *     @type int $MCCMNC
     *           Mobile Country Code and Mobile Network Code (65501 for Vodacom, 65510 for MTN) from Operator
     *     @type int $LAC
     *           location area code reported by tower
     *     @type int $CellId
     *           Cell Id reported by tower
     *     @type string $Operator
     *           Network Operator Name (eg: Vodacom-SA or MTN-SA)
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Modem::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.ModemSIMSlot SIMSlot = 5;</code>
     * @return int
     */
    public function getSIMSlot()
    {
        return $this->SIMSlot;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.ModemSIMSlot SIMSlot = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setSIMSlot($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\ModemSIMSlot::class);
        $this->SIMSlot = $var;

        return $this;
    }

    /**
     * Integrated Circuit Card Id - SIM Card Serial
     *
     * Generated from protobuf field <code>string ICCID = 6;</code>
     * @return string
     */
    public function getICCID()
    {
        return $this->ICCID;
    }

    /**
     * Integrated Circuit Card Id - SIM Card Serial
     *
     * Generated from protobuf field <code>string ICCID = 6;</code>
     * @param string $var
     * @return $this
     */
    public function setICCID($var)
    {
        GPBUtil::checkString($var, True);
        $this->ICCID = $var;

        return $this;
    }

    /**
     * International Mobile Subscriber Number
     *
     * Generated from protobuf field <code>string IMSI = 7;</code>
     * @return string
     */
    public function getIMSI()
    {
        return $this->IMSI;
    }

    /**
     * International Mobile Subscriber Number
     *
     * Generated from protobuf field <code>string IMSI = 7;</code>
     * @param string $var
     * @return $this
     */
    public function setIMSI($var)
    {
        GPBUtil::checkString($var, True);
        $this->IMSI = $var;

        return $this;
    }

    /**
     * Mobile Country Code and Mobile Network Code (65501 for Vodacom, 65510 for MTN) from Operator
     *
     * Generated from protobuf field <code>uint32 MCCMNC = 8;</code>
     * @return int
     */
    public function getMCCMNC()
    {
        return $this->MCCMNC;
    }

    /**
     * Mobile Country Code and Mobile Network Code (65501 for Vodacom, 65510 for MTN) from Operator
     *
     * Generated from protobuf field <code>uint32 MCCMNC = 8;</code>
     * @param int $var
     * @return $this
     */
    public function setMCCMNC($var)
    {
        GPBUtil::checkUint32($var);
        $this->MCCMNC = $var;

        return $this;
    }

    /**
     * location area code reported by tower
     *
     * Generated from protobuf field <code>uint32 LAC = 9;</code>
     * @return int
     */
    public function getLAC()
    {
        return $this->LAC;
    }

    /**
     * location area code reported by tower
     *
     * Generated from protobuf field <code>uint32 LAC = 9;</code>
     * @param int $var
     * @return $this
     */
    public function setLAC($var)
    {
        GPBUtil::checkUint32($var);
        $this->LAC = $var;

        return $this;
    }

    /**
     * Cell Id reported by tower
     *
     * Generated from protobuf field <code>uint32 CellId = 10;</code>
     * @return int
     */
    public function getCellId()
    {
        return $this->CellId;
    }

    /**
     * Cell Id reported by tower
     *
     * Generated from protobuf field <code>uint32 CellId = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setCellId($var)
    {
        GPBUtil::checkUint32($var);
        $this->CellId = $var;

        return $this;
    }

    /**
     * Network Operator Name (eg: Vodacom-SA or MTN-SA)
     *
     * Generated from protobuf field <code>string Operator = 11;</code>
     * @return string
     */
    public function getOperator()
    {
        return $this->Operator;
    }

    /**
     * Network Operator Name (eg: Vodacom-SA or MTN-SA)
     *
     * Generated from protobuf field <code>string Operator = 11;</code>
     * @param string $var
     * @return $this
     */
    public function setOperator($var)
    {
        GPBUtil::checkString($var, True);
        $this->Operator = $var;

        return $this;
    }

}

