<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceNetworkAction</code>
 */
class DeviceNetworkAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>uint64 DeviceId = 1;</code>
     */
    protected $DeviceId = 0;
    /**
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     */
    protected $Interface = 0;
    /**
     * Generated from protobuf field <code>uint32 SerialAddress = 3;</code>
     */
    protected $SerialAddress = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $DeviceId
     *     @type int $Interface
     *     @type int $SerialAddress
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>uint64 DeviceId = 1;</code>
     * @return int|string
     */
    public function getDeviceId()
    {
        return $this->DeviceId;
    }

    /**
     * Generated from protobuf field <code>uint64 DeviceId = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setDeviceId($var)
    {
        GPBUtil::checkUint64($var);
        $this->DeviceId = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     * @return int
     */
    public function getInterface()
    {
        return $this->Interface;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setInterface($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceInterface::class);
        $this->Interface = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 SerialAddress = 3;</code>
     * @return int
     */
    public function getSerialAddress()
    {
        return $this->SerialAddress;
    }

    /**
     * Generated from protobuf field <code>uint32 SerialAddress = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setSerialAddress($var)
    {
        GPBUtil::checkUint32($var);
        $this->SerialAddress = $var;

        return $this;
    }

}

