<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace GPBMetadata;

class Device
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xA93\x0A\x0Cdevice.proto\x12\x05OS.PB\"\x8B\x01\x0A\x11DeviceQueueMetric\x12\x1B\x0A\x13DestinationDeviceId\x18\x01 \x01(\x04\x12\x10\x0A\x08Priority\x18\x02 \x01(\x0D\x12\x0F\x0A\x07Waiting\x18\x05 \x01(\x0D\x12\x0F\x0A\x07Unacked\x18\x06 \x01(\x0D\x12\x10\x0A\x08FileSize\x18\x0A \x01(\x0D\x12\x13\x0A\x0BAckedOffset\x18\x0B \x01(\x0D\"\xF8\x01\x0A\x13DeviceNetworkMetric\x12\x1B\x0A\x13RoutingConfigsTotal\x18\x01 \x01(\x0D\x12\x1E\x0A\x16OfflineConnectionTotal\x18\x02 \x01(\x0D\x12!\x0A\x19DroppedPropagatedMessages\x18\x05 \x01(\x0D\x12!\x0A\x19IgnoredRedeliveredPackets\x18\x06 \x01(\x0D\x12\x1D\x0A\x15BadACKSequenceNumbers\x18\x07 \x01(\x0D\x12\x15\x0A\x0DNACKedPackets\x18\x08 \x01(\x0D\x12(\x0A\x06Queues\x18\x0F \x03(\x0B2\x18.OS.PB.DeviceQueueMetric\"\x9D\x01\x0A\x0CDeviceMetric\x12\x0E\x0A\x06UpTime\x18\x01 \x01(\x0D\x12\x19\x0A\x11InternalFreeSpace\x18\x02 \x01(\x0D\x12#\x0A\x06Status\x18\x03 \x01(\x0E2\x13.OS.PB.DeviceStatus\x12\x13\x0A\x0BErrorsCount\x18\x0C \x01(\x0D\x12\x15\x0A\x0DWarningsCount\x18\x0D \x01(\x0D\x12\x11\x0A\x09InfoCount\x18\x0E \x01(\x0D\"H\x0A\x13DeviceRestartAction\x121\x0A\x0DRestartMethod\x18\x01 \x01(\x0E2\x1A.OS.PB.DeviceRestartMethod\"\xD6\x01\x0A\x0CDeviceAction\x12/\x0A\x0CFormatMethod\x18\x01 \x01(\x0E2\x19.OS.PB.DeviceFormatMethod\x121\x0A\x0DRestartMethod\x18\x02 \x01(\x0E2\x1A.OS.PB.DeviceRestartMethod\x12-\x0A\x0BEraseMethod\x18\x03 \x01(\x0E2\x18.OS.PB.DeviceEraseMethod\x123\x0A\x0EExecuteProcess\x18\x04 \x01(\x0E2\x1B.OS.PB.DeviceExecuteProcess\"\xB1\x04\x0A\x12DeviceRestartEvent\x12B\x0A\x0DRestartReason\x18\x01 \x01(\x0E2+.OS.PB.DeviceRestartEvent.RestartReasonType\"\xD6\x03\x0A\x11RestartReasonType\x12\x18\x0A\x14RestartReason_NotSet\x10\x00\x12\x18\x0A\x14RestartReason_Action\x10\x01\x12\x15\x0A\x11RestartReason_DFU\x10\x02\x12\x1D\x0A\x19RestartReason_DFURollBack\x10\x03\x12\x1A\x0A\x16RestartReason_Debugger\x10\x04\x12\x1C\x0A\x18RestartReason_FlashErase\x10\x05\x12\x18\x0A\x14RestartReason_Format\x10\x06\x12\x19\x0A\x15RestartReason_PowerOn\x10\x0A\x12\x1A\x0A\x16RestartReason_Software\x10\x14\x12\x1A\x0A\x16RestartReason_Watchdog\x10\x15\x12\x1B\x0A\x17RestartReason_CPUFreeze\x10\x16\x12#\x0A\x1FRestartReason_Fatal_KernalPanic\x10\x1E\x12'\x0A#RestartReason_Fatal_PacketFromCloud\x10\x1F\x12 \x0A\x1CRestartReason_Fatal_Recovery\x10 \x12#\x0A\x1FRestartReason_Fatal_NoFreeSpace\x10!\"\xFF\x01\x0A\x12DeviceFormatAction\x12@\x0A\x0CFormatMethod\x18\x01 \x01(\x0E2*.OS.PB.DeviceFormatAction.FormatMethodType\"\xA6\x01\x0A\x10FormatMethodType\x12\x17\x0A\x13FormatMethod_NotSet\x10\x00\x12\x1B\x0A\x17FormatMethod_FileSystem\x10\x01\x12 \x0A\x1CFormatMethod_FileSystemQuick\x10\x02\x12\x19\x0A\x15FormatMethod_Settings\x10\x03\x12\x1F\x0A\x1BFormatMethod_FactoryDefault\x10\x04\"\xD9\x01\x0A\x11DeviceFormatEvent\x12C\x0A\x10FormattingReason\x18\x01 \x01(\x0E2).OS.PB.DeviceFormatEvent.FormatReasonType\"\x7F\x0A\x10FormatReasonType\x12\x17\x0A\x13FormatReason_NotSet\x10\x00\x12\x1D\x0A\x19FormatReason_NoFileSystem\x10\x01\x12\x17\x0A\x13FormatReason_Action\x10\x02\x12\x1A\x0A\x16FormatReason_Corrupted\x10\x03\"\xEF\x01\x0A\x0BDeviceEvent\x121\x0A\x0DRestartReason\x18\x01 \x01(\x0E2\x1A.OS.PB.DeviceRestartReason\x12/\x0A\x0CFormatReason\x18\x02 \x01(\x0E2\x19.OS.PB.DeviceFormatReason\x12\x10\x0A\x08Panic_A1\x18\x08 \x01(\x0D\x12\x10\x0A\x08Panic_A2\x18\x09 \x01(\x0D\x12\x10\x0A\x08Panic_A3\x18\x0A \x01(\x0D\x12\x10\x0A\x08Panic_A4\x18\x0B \x01(\x0D\x12\x10\x0A\x08Panic_IP\x18\x0C \x01(\x0D\x12\x10\x0A\x08Panic_LR\x18\x0D \x01(\x0D\x12\x10\x0A\x08Panic_PC\x18\x0E \x01(\x0D\"H\x0A\x10DeviceConnectRPC\x12\x11\x0A\x09Challenge\x18\x01 \x01(\x0C\x12\x0E\x0A\x06Answer\x18\x02 \x01(\x0C\x12\x11\x0A\x09SessionIV\x18\x03 \x01(\x0C\"i\x0A\x13DeviceNetworkAction\x12\x10\x0A\x08DeviceId\x18\x01 \x01(\x04\x12)\x0A\x09Interface\x18\x02 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x15\x0A\x0DSerialAddress\x18\x03 \x01(\x0D\"\xD0\x01\x0A\x12DeviceNetworkEvent\x12\x10\x0A\x08DeviceId\x18\x01 \x01(\x04\x12)\x0A\x09Interface\x18\x02 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x18\x0A\x10ExpectedDeviceId\x18\x03 \x01(\x04\x12\x15\x0A\x0DSerialAddress\x18\x08 \x01(\x0D\x12\x0C\x0A\x04RSSI\x18\x0B \x01(\x11\x12\x1A\x0A\x12AppFirmwareVersion\x18\x0F \x01(\x09\x12\x13\x0A\x09BTAddress\x18\x0D \x01(\x0CH\x00B\x0D\x0A\x0BAddressType\"r\x0A\x11DeviceMQTTAddress\x12\x11\x0A\x09BrokerURL\x18\x01 \x01(\x09\x12\x10\x0A\x08Username\x18\x02 \x01(\x09\x12\x10\x0A\x08Password\x18\x03 \x01(\x09\x12\x14\x0A\x0CExcludeVHost\x18\x04 \x01(\x08\x12\x10\x0A\x08EndPoint\x18\x05 \x01(\x09\"\xE1\x01\x0A\x0BDeviceRoute\x12\x10\x0A\x08DeviceId\x18\x01 \x01(\x04\x12)\x0A\x09Interface\x18\x02 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceIndex\x18\x03 \x01(\x0D\x12\x11\x0A\x09NoConnect\x18\x05 \x01(\x08\x12\x15\x0A\x0DSerialAddress\x18\x0A \x01(\x0D\x12/\x0A\x0BMQTTAddress\x18\x0C \x01(\x0B2\x18.OS.PB.DeviceMQTTAddressH\x00\x12\x13\x0A\x09BTAddress\x18\x0D \x01(\x0CH\x00B\x0D\x0A\x0BAddressType\"V\x0A\x13DeviceRoutingConfig\x12\x1B\x0A\x13DestinationDeviceId\x18\x01 \x01(\x04\x12\"\x0A\x06Routes\x18\x02 \x03(\x0B2\x12.OS.PB.DeviceRoute\"\xAD\x01\x0A\x13DeviceNetworkConfig\x12\x14\x0A\x0CObserverRole\x18\x01 \x01(\x08\x12\x1F\x0A\x17DiscoveryIgnoreDuration\x18\x02 \x01(\x0D\x12\x11\x0A\x09KeepAlive\x18\x03 \x01(\x0D\x12\x16\x0A\x0EOfflineTimeout\x18\x04 \x01(\x0D\x12\x19\x0A\x11ReconnectHoldOffs\x18\x05 \x03(\x0D\x12\x19\x0A\x11ResponseTimeoutMs\x18\x06 \x01(\x0D\"\x92\x03\x0A\x0CDeviceConfig\x12,\x0A\x04Mode\x18\x01 \x01(\x0E2\x1E.OS.PB.DeviceConfig.DeviceMode\x12\x10\x0A\x08DeviceId\x18\x02 \x01(\x04\x12\x0E\x0A\x06SiteId\x18\x06 \x01(\x0D\x12\x10\x0A\x08TimeZone\x18\x04 \x01(\x09\x12\x16\x0A\x0ERoutedCountMax\x18\x05 \x01(\x0D\x12\x1F\x0A\x17DiscoveryRefreshSeconds\x18\x0A \x01(\x0D\x12\x19\x0A\x11DefaultTimeToLive\x18\x0B \x01(\x0D\x12\x1D\x0A\x15DeviceIdToSendMetrics\x18\x0D \x01(\x04\x12\x1C\x0A\x14DeviceIdToSendEvents\x18\x0E \x01(\x04\x12\x1A\x0A\x12DeviceIdToSendLogs\x18\x0F \x01(\x04\"m\x0A\x0ADeviceMode\x12\x15\x0A\x11DeviceMode_NotSet\x10\x00\x12\x19\x0A\x15DeviceMode_Production\x10\x01\x12\x18\x0A\x14DeviceMode_Developer\x10\x02\x12\x13\x0A\x0FDeviceMode_Beta\x10\x03J\x04\x08\x03\x10\x04\"X\x0A\x0DDeviceRequest\x12\x18\x0A\x10DeviceParameters\x18\x01 \x01(\x08\x12\x15\x0A\x0DInterfaceInfo\x18\x02 \x01(\x08\x12\x16\x0A\x0ERoutingConfigs\x18\x05 \x01(\x08\"k\x0A\x0DInterfaceInfo\x12)\x0A\x09Interface\x18\x01 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceCount\x18\x02 \x01(\x0D\x12\x17\x0A\x0FInterfaceLabels\x18\x03 \x03(\x09\"\xFA\x02\x0A\x0EDeviceResponse\x12-\x0A\x10DeviceParameters\x18\x01 \x01(\x0B2\x13.OS.PB.DeviceConfig\x12+\x0A\x0DInterfaceInfo\x18\x02 \x03(\x0B2\x14.OS.PB.InterfaceInfo\x12+\x0A\x07Routing\x18\x03 \x03(\x0B2\x1A.OS.PB.DeviceRoutingConfig\x12\x14\x0A\x0CSerialNumber\x18\x05 \x01(\x0D\x12\x1A\x0A\x12AppFirmwareVersion\x18\x07 \x01(\x09\x12\x18\x0A\x10AppBuildDateTime\x18\x08 \x01(\x09\x12\x18\x0A\x10HardwarePlatform\x18\x0A \x01(\x09\x12\x1E\x0A\x16InternalFileSystemSize\x18\x0C \x01(\x0D\x12\x1E\x0A\x16ExternalFileSystemSize\x18\x0D \x01(\x0D\x12\x0E\x0A\x06MCUUID\x18\x10 \x01(\x04\x12\x16\x0A\x0EMCUSocRevision\x18\x11 \x01(\x04\x12\x11\x0A\x09MCUPartId\x18\x12 \x01(\x04*3\x0A\x08DeviceId\x12\x13\x0A\x0FDeviceId_NotSet\x10\x00\x12\x12\x0A\x0EDeviceId_Cloud\x10\x01*?\x0A\x0CDeviceSerial\x12\x17\x0A\x13DeviceSerial_NotSet\x10\x00\x12\x16\x0A\x12DeviceSerial_Cloud\x10\x01*\xAE\x03\x0A\x0FDeviceInterface\x12\x1A\x0A\x16DeviceInterface_NotSet\x10\x00\x12\x19\x0A\x15DeviceInterface_Relay\x10\x01\x12\x1B\x0A\x17DeviceInterface_Wiegand\x10\x02\x12\x19\x0A\x15DeviceInterface_Input\x10\x03\x12\x1B\x0A\x17DeviceInterface_CodeHop\x10\x04\x12\x1D\x0A\x19DeviceInterface_Expansion\x10\x05\x12\x17\x0A\x13DeviceInterface_LED\x10\x06\x12\x19\x0A\x15DeviceInterface_Power\x10\x07\x12\x19\x0A\x15DeviceInterface_RS485\x10\x08\x12\x17\x0A\x13DeviceInterface_BLE\x10\x09\x12\x1A\x0A\x16DeviceInterface_Output\x10\x0A\x12\x19\x0A\x15DeviceInterface_Modem\x10\x0B\x12\x1C\x0A\x18DeviceInterface_Ethernet\x10\x0C\x12\x18\x0A\x14DeviceInterface_WiFi\x10\x0D\x12\x19\x0A\x15DeviceInterface_RF868\x10\x0F*\xC4\x03\x0A\x0CDeviceStatus\x12\x11\x0A\x0DDevice_Normal\x10\x00\x12\x0E\x0A\x0ADevice_DFU\x10\x01\x12\x17\x0A\x13Device_Unconfigured\x10\x02\x12\x12\x0A\x0EDevice_Offline\x10\x04\x12\x13\x0A\x0FDevice_SIMError\x10\x08\x12\x1B\x0A\x17Device_DFU_Unconfigured\x10\x03\x12\x16\x0A\x12Device_DFU_Offline\x10\x05\x12\x1F\x0A\x1BDevice_Unconfigured_Offline\x10\x06\x12#\x0A\x1FDevice_DFU_Unconfigured_Offline\x10\x07\x12\x17\x0A\x13Device_DFU_SIMError\x10\x09\x12 \x0A\x1CDevice_Unconfigured_SIMError\x10\x0A\x12\$\x0A Device_DFU_Unconfigured_SIMError\x10\x0B\x12\x1B\x0A\x17Device_Offline_SIMError\x10\x0C\x12(\x0A\$Device_Unconfigured_Offline_SIMError\x10\x0E\x12,\x0A(Device_DFU_Unconfigured_Offline_SIMError\x10\x0F*\xA8\x01\x0A\x12DeviceFormatMethod\x12\x17\x0A\x13FormatMethod_NotSet\x10\x00\x12\x1B\x0A\x17FormatMethod_FileSystem\x10\x01\x12 \x0A\x1CFormatMethod_FileSystemQuick\x10\x02\x12\x19\x0A\x15FormatMethod_Settings\x10\x03\x12\x1F\x0A\x1BFormatMethod_FactoryDefault\x10\x04*g\x0A\x13DeviceRestartMethod\x12\x18\x0A\x14RestartMethod_NotSet\x10\x00\x12\x1A\x0A\x16RestartMethod_Graceful\x10\x01\x12\x1A\x0A\x16RestartMethod_Forceful\x10\x02*\xDD\x01\x0A\x11DeviceEraseMethod\x12\x16\x0A\x12EraseMethod_NotSet\x10\x00\x12\x1A\x0A\x16EraseMethod_Parameters\x10\x01\x12\x1A\x0A\x16EraseMethod_Interfaces\x10\x0A\x12\x17\x0A\x13EraseMethod_Routing\x10\x14\x12\"\x0A\x1EEraseMethod_RoutingExceptCloud\x10\x15\x12\x17\x0A\x13EraseMethod_Queuing\x10\x1E\x12\"\x0A\x1EEraseMethod_QueuingExceptCloud\x10\x1F*\xC2\x01\x0A\x14DeviceExecuteProcess\x12\x12\x0A\x0EExecute_NotSet\x10\x00\x12\x1C\x0A\x18Execute_Database_Compact\x10\x0A\x12\x1E\x0A\x1AExecute_Database_Integrity\x10\x0B\x12\x1B\x0A\x17Execute_Queuing_Compact\x10\x14\x12\x1D\x0A\x19Execute_Queuing_Integrity\x10\x15\x12\x1C\x0A\x18Execute_Metrics_Generate\x10\x1E*\xDF\x03\x0A\x13DeviceRestartReason\x12\x18\x0A\x14RestartReason_NotSet\x10\x00\x12\x18\x0A\x14RestartReason_Action\x10\x01\x12\x15\x0A\x11RestartReason_DFU\x10\x02\x12\x1D\x0A\x19RestartReason_DFURollBack\x10\x03\x12\x1A\x0A\x16RestartReason_Debugger\x10\x04\x12\x1C\x0A\x18RestartReason_FlashErase\x10\x05\x12\x1D\x0A\x19RestartReason_ModeChanged\x10\x07\x12\x19\x0A\x15RestartReason_PowerOn\x10\x0A\x12\x1A\x0A\x16RestartReason_Software\x10\x14\x12\x1A\x0A\x16RestartReason_Watchdog\x10\x15\x12\x1B\x0A\x17RestartReason_CPUFreeze\x10\x16\x12#\x0A\x1FRestartReason_Fatal_KernalPanic\x10\x1E\x12 \x0A\x1CRestartReason_Fatal_Recovery\x10 \x12#\x0A\x1FRestartReason_Fatal_NoFreeSpace\x10!\x12)\x0A%RestartReason_Fatal_PanicLoopRecovery\x10\"*\xEB\x01\x0A\x12DeviceFormatReason\x12\x17\x0A\x13FormatReason_NotSet\x10\x00\x12\x1D\x0A\x19FormatReason_NoFileSystem\x10\x01\x12\x17\x0A\x13FormatReason_Action\x10\x02\x12\x1A\x0A\x16FormatReason_Corrupted\x10\x03\x12\x1A\x0A\x16FormatReason_Reflashed\x10\x04\x12\x19\x0A\x15FormatReason_Recovery\x10\x05\x12\x1B\x0A\x17FormatReason_ModeChange\x10\x06\x12\x14\x0A\x10FormatReason_Pin\x10\x07B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

