<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: log.proto

namespace GPBMetadata;

class Log
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xA2\x04\x0A\x09log.proto\x12\x05OS.PB\"\xD9\x01\x0A\x0ALogMessage\x12\x0F\x0A\x05Error\x18\x01 \x01(\x09H\x00\x12\x11\x0A\x07Warning\x18\x02 \x01(\x09H\x00\x12\x0E\x0A\x04Info\x18\x03 \x01(\x09H\x00\x12\x0F\x0A\x05Debug\x18\x04 \x01(\x09H\x00\x12\x11\x0A\x07Dropped\x18\x05 \x01(\x0DH\x00\x12\x0C\x0A\x04Data\x18\x06 \x01(\x0C\x12\x0E\x0A\x06Thread\x18\x0A \x01(\x09\x12\x0E\x0A\x06Module\x18\x0B \x01(\x09\x12\x10\x0A\x08FuncName\x18\x0C \x01(\x09\x12\x13\x0A\x0BCoreDumpBin\x18\x0E \x01(\x0C\x12\x13\x0A\x0BCoreDumpLog\x18\x0F \x01(\x0CB\x09\x0A\x07LogType\"\xD2\x01\x0A\x09LogConfig\x12/\x0A\x08LogLevel\x18\x01 \x01(\x0E2\x1D.OS.PB.LogConfig.LogLevelType\x12\x1C\x0A\x14RevertTimeoutMinutes\x18\x02 \x01(\x0D\"v\x0A\x0CLogLevelType\x12\x15\x0A\x11LogLevel_NoChange\x10\x00\x12\x12\x0A\x0ELogLevel_Error\x10\x01\x12\x14\x0A\x10LogLevel_Warning\x10\x02\x12\x11\x0A\x0DLogLevel_Info\x10\x03\x12\x12\x0A\x0ELogLevel_Debug\x10\x04\"Q\x0A\x09LogMetric\x12\x14\x0A\x0CInfoLogCount\x18\x02 \x01(\x0D\x12\x17\x0A\x0FWarningLogCount\x18\x03 \x01(\x0D\x12\x15\x0A\x0DErrorLogCount\x18\x04 \x01(\x0DB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

