<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 ** 
 * \@brief   When requested, information of hardware is sent to the server.
 *
 * Generated from protobuf message <code>OS.PB.DeviceRequest</code>
 */
class DeviceRequest extends \Google\Protobuf\Internal\Message
{
    /**
     * Return DeviceParameters
     *
     * Generated from protobuf field <code>bool DeviceParameters = 1;</code>
     */
    protected $DeviceParameters = false;
    /**
     * Return InterfaceInfo
     *
     * Generated from protobuf field <code>bool InterfaceInfo = 2;</code>
     */
    protected $InterfaceInfo = false;
    /**
     * Return DeviceRoutingConfig
     *
     * Generated from protobuf field <code>bool RoutingConfigs = 5;</code>
     */
    protected $RoutingConfigs = false;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type bool $DeviceParameters
     *           Return DeviceParameters
     *     @type bool $InterfaceInfo
     *           Return InterfaceInfo
     *     @type bool $RoutingConfigs
     *           Return DeviceRoutingConfig
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * Return DeviceParameters
     *
     * Generated from protobuf field <code>bool DeviceParameters = 1;</code>
     * @return bool
     */
    public function getDeviceParameters()
    {
        return $this->DeviceParameters;
    }

    /**
     * Return DeviceParameters
     *
     * Generated from protobuf field <code>bool DeviceParameters = 1;</code>
     * @param bool $var
     * @return $this
     */
    public function setDeviceParameters($var)
    {
        GPBUtil::checkBool($var);
        $this->DeviceParameters = $var;

        return $this;
    }

    /**
     * Return InterfaceInfo
     *
     * Generated from protobuf field <code>bool InterfaceInfo = 2;</code>
     * @return bool
     */
    public function getInterfaceInfo()
    {
        return $this->InterfaceInfo;
    }

    /**
     * Return InterfaceInfo
     *
     * Generated from protobuf field <code>bool InterfaceInfo = 2;</code>
     * @param bool $var
     * @return $this
     */
    public function setInterfaceInfo($var)
    {
        GPBUtil::checkBool($var);
        $this->InterfaceInfo = $var;

        return $this;
    }

    /**
     * Return DeviceRoutingConfig
     *
     * Generated from protobuf field <code>bool RoutingConfigs = 5;</code>
     * @return bool
     */
    public function getRoutingConfigs()
    {
        return $this->RoutingConfigs;
    }

    /**
     * Return DeviceRoutingConfig
     *
     * Generated from protobuf field <code>bool RoutingConfigs = 5;</code>
     * @param bool $var
     * @return $this
     */
    public function setRoutingConfigs($var)
    {
        GPBUtil::checkBool($var);
        $this->RoutingConfigs = $var;

        return $this;
    }

}

