<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: config.proto

namespace GPBMetadata;

class Config
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Input::initOnce();
        \GPBMetadata\Codehop::initOnce();
        \GPBMetadata\Ethernet::initOnce();
        \GPBMetadata\Modem::initOnce();
        \GPBMetadata\Rs485::initOnce();
        \GPBMetadata\Ble::initOnce();
        \GPBMetadata\Relay::initOnce();
        \GPBMetadata\Wiegand::initOnce();
        \GPBMetadata\Access::initOnce();
        \GPBMetadata\Health::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\x88\x0A\x0A\x0Cconfig.proto\x12\x05OS.PB\x1A\x0Binput.proto\x1A\x0Dcodehop.proto\x1A\x0Eethernet.proto\x1A\x0Bmodem.proto\x1A\x0Brs485.proto\x1A\x09ble.proto\x1A\x0Brelay.proto\x1A\x0Dwiegand.proto\x1A\x0Caccess.proto\x1A\x0Chealth.proto\"\xDB\x08\x0A\x0DConfigMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x127\x0A\x12AccessMethodUpdate\x18\x05 \x01(\x0B2\x19.OS.PB.AccessMethodConfigH\x00\x127\x0A\x12AccessMethodDelete\x18\x06 \x01(\x0B2\x19.OS.PB.AccessMethodConfigH\x00\x123\x0A\x10AccessUserUpdate\x18\x07 \x01(\x0B2\x17.OS.PB.AccessUserConfigH\x00\x123\x0A\x10AccessUserDelete\x18\x08 \x01(\x0B2\x17.OS.PB.AccessUserConfigH\x00\x127\x0A\x12AccessRightsUpdate\x18\x09 \x01(\x0B2\x19.OS.PB.AccessRightsConfigH\x00\x127\x0A\x12AccessRightsDelete\x18\x0A \x01(\x0B2\x19.OS.PB.AccessRightsConfigH\x00\x12,\x0A\x0DAccessGateway\x18\x14 \x01(\x0B2\x13.OS.PB.AccessConfigH\x00\x12-\x0A\x0AHealthLink\x18( \x01(\x0B2\x17.OS.PB.HealthLinkConfigH\x00\x127\x0A\x12HealthButtonUpdate\x182 \x01(\x0B2\x19.OS.PB.HealthButtonConfigH\x00\x127\x0A\x12HealthButtonDelete\x183 \x01(\x0B2\x19.OS.PB.HealthButtonConfigH\x00\x12#\x0A\x05Relay\x18n \x01(\x0B2\x12.OS.PB.RelayConfigH\x00\x12'\x0A\x07Wiegand\x18x \x01(\x0B2\x14.OS.PB.WiegandConfigH\x00\x12\$\x0A\x05Input\x18\x82\x01 \x01(\x0B2\x12.OS.PB.InputConfigH\x00\x12(\x0A\x07CodeHop\x18\x8C\x01 \x01(\x0B2\x14.OS.PB.CodeHopConfigH\x00\x12\$\x0A\x05RS485\x18\xB4\x01 \x01(\x0B2\x12.OS.PB.RS485ConfigH\x00\x12 \x0A\x03BLE\x18\xBE\x01 \x01(\x0B2\x10.OS.PB.BLEConfigH\x00\x12)\x0A\x0CBLELongRange\x18\xC8\x01 \x01(\x0B2\x10.OS.PB.BLEConfigH\x00\x12\$\x0A\x05Modem\x18\xD2\x01 \x01(\x0B2\x12.OS.PB.ModemConfigH\x00\x12*\x0A\x08Ethernet\x18\xDC\x01 \x01(\x0B2\x15.OS.PB.EthernetConfigH\x00\x120\x0A\x10DeviceParameters\x18\x90\x03 \x01(\x0B2\x13.OS.PB.DeviceConfigH\x00\x128\x0A\x11DeviceRouteUpdate\x18\x9A\x03 \x01(\x0B2\x1A.OS.PB.DeviceRoutingConfigH\x00\x128\x0A\x11DeviceRouteDelete\x18\x9B\x03 \x01(\x0B2\x1A.OS.PB.DeviceRoutingConfigH\x00B\x0C\x0A\x0AConfigTypeB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

