<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rpc.proto

namespace GPBMetadata;

class Rpc
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Access::initOnce();
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Input::initOnce();
        \GPBMetadata\Wiegand::initOnce();
        \GPBMetadata\Rs485::initOnce();
        \GPBMetadata\Ble::initOnce();
        \GPBMetadata\Modem::initOnce();
        \GPBMetadata\Ethernet::initOnce();
        \GPBMetadata\Filesystem::initOnce();
        \GPBMetadata\Dfu::initOnce();
        \GPBMetadata\Codehop::initOnce();
        \GPBMetadata\Health::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xFC.\x0A\x09rpc.proto\x12\x05OS.PB\x1A\x0Cdevice.proto\x1A\x0Binput.proto\x1A\x0Dwiegand.proto\x1A\x0Brs485.proto\x1A\x09ble.proto\x1A\x0Bmodem.proto\x1A\x0Eethernet.proto\x1A\x10filesystem.proto\x1A\x09dfu.proto\x1A\x0Dcodehop.proto\x1A\x0Chealth.proto\"\x91\x01\x0A\x0BHTTPRequest\x12\x0B\x0A\x03URL\x18\x01 \x01(\x09\x12%\x0A\x06Method\x18\x02 \x01(\x0E2\x15.OS.PB.HTTPMethodType\x12\x0F\x0A\x07Headers\x18\x03 \x03(\x09\x12\x10\x0A\x08Protocol\x18\x04 \x01(\x09\x12\x0D\x0A\x03Raw\x18\x0A \x01(\x09H\x00\x12\x10\x0A\x06Binary\x18\x0F \x01(\x0CH\x00B\x0A\x0A\x08BodyType\"s\x0A\x0CHTTPResponse\x12%\x0A\x06Status\x18\x01 \x01(\x0E2\x15.OS.PB.HTTPStatusType\x12\x0F\x0A\x07Headers\x18\x02 \x03(\x09\x12\x0D\x0A\x03Raw\x18\x0A \x01(\x09H\x00\x12\x10\x0A\x06Binary\x18\x0F \x01(\x0CH\x00B\x0A\x0A\x08BodyType\"\x91\x09\x0A\x0ERequestMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x12\x14\x0A\x0CSegmentIndex\x18\x02 \x01(\x0D\x12\x14\x0A\x0CSegmentTotal\x18\x03 \x01(\x0D\x12,\x0A\x0BWiegandInfo\x18\x05 \x01(\x0B2\x15.OS.PB.WiegandRequestH\x00\x12(\x0A\x09InputInfo\x18\x06 \x01(\x0B2\x13.OS.PB.InputRequestH\x00\x12(\x0A\x09RS485Info\x18\x08 \x01(\x0B2\x13.OS.PB.RS485RequestH\x00\x12\$\x0A\x07BLEInfo\x18\x09 \x01(\x0B2\x11.OS.PB.BLERequestH\x00\x12(\x0A\x09ModemInfo\x18\x0B \x01(\x0B2\x13.OS.PB.ModemRequestH\x00\x12.\x0A\x0CEthernetInfo\x18\x0C \x01(\x0B2\x16.OS.PB.EthernetRequestH\x00\x125\x0A\x15AccessControlSimulate\x18\x14 \x01(\x0B2\x14.OS.PB.AccessRequestH\x00\x12+\x0A\x0BAccessEnrol\x18\x15 \x01(\x0B2\x14.OS.PB.AccessRequestH\x00\x12+\x0A\x0ADeviceInfo\x18\xAC\x02 \x01(\x0B2\x14.OS.PB.DeviceRequestH\x00\x124\x0A\x0FDirectoryCreate\x18\xB6\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x124\x0A\x0FDirectoryDelete\x18\xB7\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x124\x0A\x0FDirectorySearch\x18\xB8\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x12-\x0A\x08FileRead\x18\xB9\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x12.\x0A\x09FileWrite\x18\xBA\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x12/\x0A\x0AFileDelete\x18\xBB\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x12-\x0A\x08FileCopy\x18\xBC\x02 \x01(\x0B2\x18.OS.PB.FileSystemRequestH\x00\x122\x0A\x0EConnectRequest\x18\xC0\x02 \x01(\x0B2\x17.OS.PB.DeviceConnectRPCH\x00\x122\x0A\x0EConnectCorrect\x18\xC2\x02 \x01(\x0B2\x17.OS.PB.DeviceConnectRPCH\x00\x12/\x0A\x0DCodeHopEnroll\x18\xCA\x02 \x01(\x0B2\x15.OS.PB.CodeHopRequestH\x00\x12)\x0A\x0BDFUInitiate\x18\xDE\x02 \x01(\x0B2\x11.OS.PB.DFURequestH\x00\x12'\x0A\x09DFUStatus\x18\xDF\x02 \x01(\x0B2\x11.OS.PB.DFURequestH\x00\x12'\x0A\x09DFUCancel\x18\xE0\x02 \x01(\x0B2\x11.OS.PB.DFURequestH\x00\x12\"\x0A\x04HTTP\x18P \x01(\x0B2\x12.OS.PB.HTTPRequestH\x00B\x0D\x0A\x0BRequestType\"\x82\x0A\x0A\x0FResponseMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x12\x14\x0A\x0CSegmentIndex\x18\x02 \x01(\x0D\x12\x14\x0A\x0CSegmentTotal\x18\x03 \x01(\x0D\x12-\x0A\x0BWiegandInfo\x18\x05 \x01(\x0B2\x16.OS.PB.WiegandResponseH\x00\x12)\x0A\x09InputInfo\x18\x06 \x01(\x0B2\x14.OS.PB.InputResponseH\x00\x12)\x0A\x09RS485Info\x18\x08 \x01(\x0B2\x14.OS.PB.RS485ResponseH\x00\x12%\x0A\x07BLEInfo\x18\x09 \x01(\x0B2\x12.OS.PB.BLEResponseH\x00\x12.\x0A\x10BLELongRangeInfo\x18\x0A \x01(\x0B2\x12.OS.PB.BLEResponseH\x00\x12)\x0A\x09ModemInfo\x18\x0B \x01(\x0B2\x14.OS.PB.ModemResponseH\x00\x12/\x0A\x0CEthernetInfo\x18\x0C \x01(\x0B2\x17.OS.PB.EthernetResponseH\x00\x120\x0A\x0DDeviceConnect\x18\x0F \x01(\x0B2\x17.OS.PB.DeviceConnectRPCH\x00\x12/\x0A\x0EAccessSimulate\x18\x14 \x01(\x0B2\x15.OS.PB.AccessResponseH\x00\x12,\x0A\x0BAccessEnrol\x18\x15 \x01(\x0B2\x15.OS.PB.AccessResponseH\x00\x12,\x0A\x0ADeviceInfo\x18\xAC\x02 \x01(\x0B2\x15.OS.PB.DeviceResponseH\x00\x125\x0A\x0FDirectoryCreate\x18\xB6\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x125\x0A\x0FDirectoryDelete\x18\xB7\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x125\x0A\x0FDirectorySearch\x18\xB8\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x12.\x0A\x08FileRead\x18\xB9\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x12/\x0A\x09FileWrite\x18\xBA\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x120\x0A\x0AFileDelete\x18\xBB\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x12.\x0A\x08FileCopy\x18\xBC\x02 \x01(\x0B2\x19.OS.PB.FileSystemResponseH\x00\x121\x0A\x0DConnectAnswer\x18\xC0\x02 \x01(\x0B2\x17.OS.PB.DeviceConnectRPCH\x00\x122\x0A\x0EConnectSuccess\x18\xC1\x02 \x01(\x0B2\x17.OS.PB.DeviceConnectRPCH\x00\x120\x0A\x0DCodeHopEnroll\x18\xCA\x02 \x01(\x0B2\x16.OS.PB.CodeHopResponseH\x00\x12*\x0A\x0BDFUInitiate\x18\xDE\x02 \x01(\x0B2\x12.OS.PB.DFUResponseH\x00\x12(\x0A\x09DFUStatus\x18\xDF\x02 \x01(\x0B2\x12.OS.PB.DFUResponseH\x00\x12(\x0A\x09DFUCancel\x18\xE0\x02 \x01(\x0B2\x12.OS.PB.DFUResponseH\x00\x12#\x0A\x04HTTP\x18P \x01(\x0B2\x13.OS.PB.HTTPResponseH\x00B\x0E\x0A\x0CResponseType*\x9C\x06\x0A\x0EHTTPMethodType\x12\x15\x0A\x11HTTPMethod_NotSet\x10\x00\x12\x15\x0A\x11HTTPMethod_Delete\x10\x01\x12\x12\x0A\x0EHTTPMethod_Get\x10\x02\x12\x13\x0A\x0FHTTPMethod_Head\x10\x03\x12\x13\x0A\x0FHTTPMethod_Post\x10\x04\x12\x12\x0A\x0EHTTPMethod_Put\x10\x05\x12\x16\x0A\x12HTTPMethod_Connect\x10\x06\x12\x16\x0A\x12HTTPMethod_Options\x10\x07\x12\x14\x0A\x10HTTPMethod_Trace\x10\x08\x12\x13\x0A\x0FHTTPMethod_Copy\x10\x09\x12\x13\x0A\x0FHTTPMethod_Lock\x10\x0A\x12\x14\x0A\x10HTTPMethod_MkCol\x10\x0B\x12\x13\x0A\x0FHTTPMethod_Move\x10\x0C\x12\x17\x0A\x13HTTPMethod_PropFind\x10\x0D\x12\x18\x0A\x14HTTPMethod_PropPatch\x10\x0E\x12\x15\x0A\x11HTTPMethod_Search\x10\x0F\x12\x15\x0A\x11HTTPMethod_Unlock\x10\x10\x12\x13\x0A\x0FHTTPMethod_Bind\x10\x11\x12\x15\x0A\x11HTTPMethod_Rebind\x10\x12\x12\x15\x0A\x11HTTPMethod_Unbind\x10\x13\x12\x12\x0A\x0EHTTPMethod_Acl\x10\x14\x12\x15\x0A\x11HTTPMethod_Report\x10\x15\x12\x19\x0A\x15HTTPMethod_MkActivity\x10\x16\x12\x17\x0A\x13HTTPMethod_Checkout\x10\x17\x12\x14\x0A\x10HTTPMethod_Merge\x10\x18\x12\x16\x0A\x12HTTPMethod_MSearch\x10\x19\x12\x15\x0A\x11HTTPMethod_Notify\x10\x1A\x12\x18\x0A\x14HTTPMethod_Subscribe\x10\x1B\x12\x1A\x0A\x16HTTPMethod_Unsubscribe\x10\x1C\x12\x14\x0A\x10HTTPMethod_Patch\x10\x1D\x12\x14\x0A\x10HTTPMethod_Purge\x10\x1E\x12\x19\x0A\x15HTTPMethod_MkCalendar\x10\x1F\x12\x13\x0A\x0FHTTPMethod_Link\x10 \x12\x15\x0A\x11HTTPMethod_Unlink\x10!*\x81\x12\x0A\x0EHTTPStatusType\x12\x15\x0A\x11HTTPStatus_Notset\x10\x00\x12\x1B\x0A\x17HTTPStatus_100_Continue\x10d\x12%\x0A!HTTPStatus_101_SwitchingProtocols\x10e\x12\x1D\x0A\x19HTTPStatus_102_Processing\x10f\x12\x1D\x0A\x19HTTPStatus_103_EarlyHints\x10g\x12\x16\x0A\x11HTTPStatus_200_Ok\x10\xC8\x01\x12\x1B\x0A\x16HTTPStatus_201_Created\x10\xC9\x01\x12\x1C\x0A\x17HTTPStatus_202_Accepted\x10\xCA\x01\x12/\x0A*HTTPStatus_203_NonAuthoritativeInformation\x10\xCB\x01\x12\x1D\x0A\x18HTTPStatus_204_NoContent\x10\xCC\x01\x12 \x0A\x1BHTTPStatus_205_ResetContent\x10\xCD\x01\x12\"\x0A\x1DHTTPStatus_206_PartialContent\x10\xCE\x01\x12\x1F\x0A\x1AHTTPStatus_207_MultiStatus\x10\xCF\x01\x12#\x0A\x1EHTTPStatus_208_AlreadyReported\x10\xD0\x01\x12\x1A\x0A\x15HTTPStatus_226_ImUsed\x10\xE2\x01\x12#\x0A\x1EHTTPStatus_300_MultipleChoices\x10\xAC\x02\x12\$\x0A\x1FHTTPStatus_301_MovedPermanently\x10\xAD\x02\x12\x19\x0A\x14HTTPStatus_302_Found\x10\xAE\x02\x12\x1C\x0A\x17HTTPStatus_303_SeeOther\x10\xAF\x02\x12\x1F\x0A\x1AHTTPStatus_304_NotModified\x10\xB0\x02\x12\x1C\x0A\x17HTTPStatus_305_UseProxy\x10\xB1\x02\x12\x1A\x0A\x15HTTPStatus_306_Unused\x10\xB2\x02\x12%\x0A HTTPStatus_307_TemporaryRedirect\x10\xB3\x02\x12%\x0A HTTPStatus_308_PermanentRedirect\x10\xB4\x02\x12\x1E\x0A\x19HTTPStatus_400_BadRequest\x10\x90\x03\x12 \x0A\x1BHTTPStatus_401_Unauthorized\x10\x91\x03\x12#\x0A\x1EHTTPStatus_402_PaymentRequired\x10\x92\x03\x12\x1D\x0A\x18HTTPStatus_403_Forbidden\x10\x93\x03\x12\x1C\x0A\x17HTTPStatus_404_NotFound\x10\x94\x03\x12\$\x0A\x1FHTTPStatus_405_MethodNotAllowed\x10\x95\x03\x12!\x0A\x1CHTTPStatus_406_NotAcceptable\x10\x96\x03\x12/\x0A*HTTPStatus_407_ProxyAuthenticationRequired\x10\x97\x03\x12\"\x0A\x1DHTTPStatus_408_RequestTimeout\x10\x98\x03\x12\x1C\x0A\x17HTTPStatus_409_Conflict\x10\x99\x03\x12\x18\x0A\x13HTTPStatus_410_Gone\x10\x9A\x03\x12\"\x0A\x1DHTTPStatus_411_LengthRequired\x10\x9B\x03\x12&\x0A!HTTPStatus_412_PreconditionFailed\x10\x9C\x03\x12#\x0A\x1EHTTPStatus_413_PayloadTooLarge\x10\x9D\x03\x12\x1E\x0A\x19HTTPStatus_414_UriTooLong\x10\x9E\x03\x12(\x0A#HTTPStatus_415_UnsupportedMediaType\x10\x9F\x03\x12'\x0A\"HTTPStatus_416_RangeNotSatisfiable\x10\xA0\x03\x12%\x0A HTTPStatus_417_ExpectationFailed\x10\xA1\x03\x12\x1D\x0A\x18HTTPStatus_418_ImATeapot\x10\xA2\x03\x12&\x0A!HTTPStatus_421_MisdirectedRequest\x10\xA5\x03\x12'\x0A\"HTTPStatus_422_UnprocessableEntity\x10\xA6\x03\x12\x1A\x0A\x15HTTPStatus_423_Locked\x10\xA7\x03\x12\$\x0A\x1FHTTPStatus_424_FailedDependency\x10\xA8\x03\x12\x1C\x0A\x17HTTPStatus_425_TooEarly\x10\xA9\x03\x12#\x0A\x1EHTTPStatus_426_UpgradeRequired\x10\xAA\x03\x12(\x0A#HTTPStatus_428_PreconditionRequired\x10\xAC\x03\x12#\x0A\x1EHTTPStatus_429_TooManyRequests\x10\xAD\x03\x12/\x0A*HTTPStatus_431_RequestHeaderFieldsTooLarge\x10\xAF\x03\x12.\x0A)HTTPStatus_451_UnavailableForLegalReasons\x10\xC3\x03\x12'\x0A\"HTTPStatus_500_InternalServerError\x10\xF4\x03\x12\"\x0A\x1DHTTPStatus_501_NotImplemented\x10\xF5\x03\x12\x1E\x0A\x19HTTPStatus_502_BadGateway\x10\xF6\x03\x12&\x0A!HTTPStatus_503_ServiceUnavailable\x10\xF7\x03\x12\"\x0A\x1DHTTPStatus_504_GatewayTimeout\x10\xF8\x03\x121\x0A,HTTPStatus_505_HTTPStatusVersionNotSupported\x10\xF9\x03\x12)\x0A\$HTTPStatus_506_VariantAlsoNegotiates\x10\xFA\x03\x12'\x0A\"HTTPStatus_507_InsufficientStorage\x10\xFB\x03\x12 \x0A\x1BHTTPStatus_508_LoopDetected\x10\xFC\x03\x12\x1F\x0A\x1AHTTPStatus_510_NotExtended\x10\xFE\x03\x121\x0A,HTTPStatus_511_NetworkAuthenticationRequired\x10\xFF\x03B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

