<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.BLEResponse</code>
 */
class BLEResponse extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.BLEConfig Config = 1;</code>
     */
    protected $Config = null;
    /**
     * on nRF52: decoded from FICR.DEVICEID | 0xC00000000000, set two msb bits. If 0, then no BLE feature available
     *
     * Generated from protobuf field <code>bytes BTAddress = 2;</code>
     */
    protected $BTAddress = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type \OS\PB\BLEConfig $Config
     *     @type string $BTAddress
     *           on nRF52: decoded from FICR.DEVICEID | 0xC00000000000, set two msb bits. If 0, then no BLE feature available
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Ble::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.BLEConfig Config = 1;</code>
     * @return \OS\PB\BLEConfig|null
     */
    public function getConfig()
    {
        return $this->Config;
    }

    public function hasConfig()
    {
        return isset($this->Config);
    }

    public function clearConfig()
    {
        unset($this->Config);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.BLEConfig Config = 1;</code>
     * @param \OS\PB\BLEConfig $var
     * @return $this
     */
    public function setConfig($var)
    {
        GPBUtil::checkMessage($var, \OS\PB\BLEConfig::class);
        $this->Config = $var;

        return $this;
    }

    /**
     * on nRF52: decoded from FICR.DEVICEID | 0xC00000000000, set two msb bits. If 0, then no BLE feature available
     *
     * Generated from protobuf field <code>bytes BTAddress = 2;</code>
     * @return string
     */
    public function getBTAddress()
    {
        return $this->BTAddress;
    }

    /**
     * on nRF52: decoded from FICR.DEVICEID | 0xC00000000000, set two msb bits. If 0, then no BLE feature available
     *
     * Generated from protobuf field <code>bytes BTAddress = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setBTAddress($var)
    {
        GPBUtil::checkString($var, False);
        $this->BTAddress = $var;

        return $this;
    }

}

