<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceQueueMetric</code>
 */
class DeviceQueueMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * The DeviceId of where the messages in the queue are destined for
     *
     * Generated from protobuf field <code>uint64 DestinationDeviceId = 1;</code>
     */
    protected $DestinationDeviceId = 0;
    /**
     * States
     *
     * Generated from protobuf field <code>uint32 Priority = 2;</code>
     */
    protected $Priority = 0;
    /**
     * Message Metrics
     *
     * Generated from protobuf field <code>uint32 Waiting = 5;</code>
     */
    protected $Waiting = 0;
    /**
     * How many messages are sent right now, but haven't been acked yet
     *
     * Generated from protobuf field <code>uint32 Unacked = 6;</code>
     */
    protected $Unacked = 0;
    /**
     * File Metrics
     *
     * Generated from protobuf field <code>uint32 FileSize = 10;</code>
     */
    protected $FileSize = 0;
    /**
     * Where the last acked offset is in the file
     *
     * Generated from protobuf field <code>uint32 AckedOffset = 11;</code>
     */
    protected $AckedOffset = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $DestinationDeviceId
     *           The DeviceId of where the messages in the queue are destined for
     *     @type int $Priority
     *           States
     *     @type int $Waiting
     *           Message Metrics
     *     @type int $Unacked
     *           How many messages are sent right now, but haven't been acked yet
     *     @type int $FileSize
     *           File Metrics
     *     @type int $AckedOffset
     *           Where the last acked offset is in the file
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * The DeviceId of where the messages in the queue are destined for
     *
     * Generated from protobuf field <code>uint64 DestinationDeviceId = 1;</code>
     * @return int|string
     */
    public function getDestinationDeviceId()
    {
        return $this->DestinationDeviceId;
    }

    /**
     * The DeviceId of where the messages in the queue are destined for
     *
     * Generated from protobuf field <code>uint64 DestinationDeviceId = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setDestinationDeviceId($var)
    {
        GPBUtil::checkUint64($var);
        $this->DestinationDeviceId = $var;

        return $this;
    }

    /**
     * States
     *
     * Generated from protobuf field <code>uint32 Priority = 2;</code>
     * @return int
     */
    public function getPriority()
    {
        return $this->Priority;
    }

    /**
     * States
     *
     * Generated from protobuf field <code>uint32 Priority = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setPriority($var)
    {
        GPBUtil::checkUint32($var);
        $this->Priority = $var;

        return $this;
    }

    /**
     * Message Metrics
     *
     * Generated from protobuf field <code>uint32 Waiting = 5;</code>
     * @return int
     */
    public function getWaiting()
    {
        return $this->Waiting;
    }

    /**
     * Message Metrics
     *
     * Generated from protobuf field <code>uint32 Waiting = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setWaiting($var)
    {
        GPBUtil::checkUint32($var);
        $this->Waiting = $var;

        return $this;
    }

    /**
     * How many messages are sent right now, but haven't been acked yet
     *
     * Generated from protobuf field <code>uint32 Unacked = 6;</code>
     * @return int
     */
    public function getUnacked()
    {
        return $this->Unacked;
    }

    /**
     * How many messages are sent right now, but haven't been acked yet
     *
     * Generated from protobuf field <code>uint32 Unacked = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setUnacked($var)
    {
        GPBUtil::checkUint32($var);
        $this->Unacked = $var;

        return $this;
    }

    /**
     * File Metrics
     *
     * Generated from protobuf field <code>uint32 FileSize = 10;</code>
     * @return int
     */
    public function getFileSize()
    {
        return $this->FileSize;
    }

    /**
     * File Metrics
     *
     * Generated from protobuf field <code>uint32 FileSize = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setFileSize($var)
    {
        GPBUtil::checkUint32($var);
        $this->FileSize = $var;

        return $this;
    }

    /**
     * Where the last acked offset is in the file
     *
     * Generated from protobuf field <code>uint32 AckedOffset = 11;</code>
     * @return int
     */
    public function getAckedOffset()
    {
        return $this->AckedOffset;
    }

    /**
     * Where the last acked offset is in the file
     *
     * Generated from protobuf field <code>uint32 AckedOffset = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setAckedOffset($var)
    {
        GPBUtil::checkUint32($var);
        $this->AckedOffset = $var;

        return $this;
    }

}

