<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wiegand.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 ** \@brief   Sends Wiegand Interface metrics to server for system monitoring
 *
 * Generated from protobuf message <code>OS.PB.WiegandMetric</code>
 */
class WiegandMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * Errors
     *
     * Generated from protobuf field <code>uint32 ParityErrors = 1;</code>
     */
    protected $ParityErrors = 0;
    /**
     * how much noisy data was discarded in last hour (less than 8 bits)
     *
     * Generated from protobuf field <code>uint32 NoiseReceived = 2;</code>
     */
    protected $NoiseReceived = 0;
    /**
     * malformed wiegand data is when the number of bits is odd (eg: 25 bits)
     *
     * Generated from protobuf field <code>uint32 MalformedData = 3;</code>
     */
    protected $MalformedData = 0;
    /**
     * how many pin codes from key bit burst were ignored because they weren't the exact amount of digits expected
     *
     * Generated from protobuf field <code>uint32 IncorrectDigits = 4;</code>
     */
    protected $IncorrectDigits = 0;
    /**
     * Stats
     *
     * Generated from protobuf field <code>uint32 BitsReceived = 10;</code>
     */
    protected $BitsReceived = 0;
    /**
     * number of keys pressed from key bit burst mode
     *
     * Generated from protobuf field <code>uint32 KeysPressed = 11;</code>
     */
    protected $KeysPressed = 0;
    /**
     * number of times the Ok output was activated
     *
     * Generated from protobuf field <code>uint32 OkActivations = 12;</code>
     */
    protected $OkActivations = 0;
    /**
     * number of times the Error output was activated
     *
     * Generated from protobuf field <code>uint32 ErrorActivations = 13;</code>
     */
    protected $ErrorActivations = 0;
    /**
     * number of times the buzzer output was activated
     *
     * Generated from protobuf field <code>uint32 BuzzerActivations = 14;</code>
     */
    protected $BuzzerActivations = 0;
    /**
     * number of times a tamper code was received (0xF on Impro Keypads)
     *
     * Generated from protobuf field <code>uint32 TamperTriggers = 15;</code>
     */
    protected $TamperTriggers = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $ParityErrors
     *           Errors
     *     @type int $NoiseReceived
     *           how much noisy data was discarded in last hour (less than 8 bits)
     *     @type int $MalformedData
     *           malformed wiegand data is when the number of bits is odd (eg: 25 bits)
     *     @type int $IncorrectDigits
     *           how many pin codes from key bit burst were ignored because they weren't the exact amount of digits expected
     *     @type int $BitsReceived
     *           Stats
     *     @type int $KeysPressed
     *           number of keys pressed from key bit burst mode
     *     @type int $OkActivations
     *           number of times the Ok output was activated
     *     @type int $ErrorActivations
     *           number of times the Error output was activated
     *     @type int $BuzzerActivations
     *           number of times the buzzer output was activated
     *     @type int $TamperTriggers
     *           number of times a tamper code was received (0xF on Impro Keypads)
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Wiegand::initOnce();
        parent::__construct($data);
    }

    /**
     * Errors
     *
     * Generated from protobuf field <code>uint32 ParityErrors = 1;</code>
     * @return int
     */
    public function getParityErrors()
    {
        return $this->ParityErrors;
    }

    /**
     * Errors
     *
     * Generated from protobuf field <code>uint32 ParityErrors = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setParityErrors($var)
    {
        GPBUtil::checkUint32($var);
        $this->ParityErrors = $var;

        return $this;
    }

    /**
     * how much noisy data was discarded in last hour (less than 8 bits)
     *
     * Generated from protobuf field <code>uint32 NoiseReceived = 2;</code>
     * @return int
     */
    public function getNoiseReceived()
    {
        return $this->NoiseReceived;
    }

    /**
     * how much noisy data was discarded in last hour (less than 8 bits)
     *
     * Generated from protobuf field <code>uint32 NoiseReceived = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setNoiseReceived($var)
    {
        GPBUtil::checkUint32($var);
        $this->NoiseReceived = $var;

        return $this;
    }

    /**
     * malformed wiegand data is when the number of bits is odd (eg: 25 bits)
     *
     * Generated from protobuf field <code>uint32 MalformedData = 3;</code>
     * @return int
     */
    public function getMalformedData()
    {
        return $this->MalformedData;
    }

    /**
     * malformed wiegand data is when the number of bits is odd (eg: 25 bits)
     *
     * Generated from protobuf field <code>uint32 MalformedData = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setMalformedData($var)
    {
        GPBUtil::checkUint32($var);
        $this->MalformedData = $var;

        return $this;
    }

    /**
     * how many pin codes from key bit burst were ignored because they weren't the exact amount of digits expected
     *
     * Generated from protobuf field <code>uint32 IncorrectDigits = 4;</code>
     * @return int
     */
    public function getIncorrectDigits()
    {
        return $this->IncorrectDigits;
    }

    /**
     * how many pin codes from key bit burst were ignored because they weren't the exact amount of digits expected
     *
     * Generated from protobuf field <code>uint32 IncorrectDigits = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setIncorrectDigits($var)
    {
        GPBUtil::checkUint32($var);
        $this->IncorrectDigits = $var;

        return $this;
    }

    /**
     * Stats
     *
     * Generated from protobuf field <code>uint32 BitsReceived = 10;</code>
     * @return int
     */
    public function getBitsReceived()
    {
        return $this->BitsReceived;
    }

    /**
     * Stats
     *
     * Generated from protobuf field <code>uint32 BitsReceived = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setBitsReceived($var)
    {
        GPBUtil::checkUint32($var);
        $this->BitsReceived = $var;

        return $this;
    }

    /**
     * number of keys pressed from key bit burst mode
     *
     * Generated from protobuf field <code>uint32 KeysPressed = 11;</code>
     * @return int
     */
    public function getKeysPressed()
    {
        return $this->KeysPressed;
    }

    /**
     * number of keys pressed from key bit burst mode
     *
     * Generated from protobuf field <code>uint32 KeysPressed = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setKeysPressed($var)
    {
        GPBUtil::checkUint32($var);
        $this->KeysPressed = $var;

        return $this;
    }

    /**
     * number of times the Ok output was activated
     *
     * Generated from protobuf field <code>uint32 OkActivations = 12;</code>
     * @return int
     */
    public function getOkActivations()
    {
        return $this->OkActivations;
    }

    /**
     * number of times the Ok output was activated
     *
     * Generated from protobuf field <code>uint32 OkActivations = 12;</code>
     * @param int $var
     * @return $this
     */
    public function setOkActivations($var)
    {
        GPBUtil::checkUint32($var);
        $this->OkActivations = $var;

        return $this;
    }

    /**
     * number of times the Error output was activated
     *
     * Generated from protobuf field <code>uint32 ErrorActivations = 13;</code>
     * @return int
     */
    public function getErrorActivations()
    {
        return $this->ErrorActivations;
    }

    /**
     * number of times the Error output was activated
     *
     * Generated from protobuf field <code>uint32 ErrorActivations = 13;</code>
     * @param int $var
     * @return $this
     */
    public function setErrorActivations($var)
    {
        GPBUtil::checkUint32($var);
        $this->ErrorActivations = $var;

        return $this;
    }

    /**
     * number of times the buzzer output was activated
     *
     * Generated from protobuf field <code>uint32 BuzzerActivations = 14;</code>
     * @return int
     */
    public function getBuzzerActivations()
    {
        return $this->BuzzerActivations;
    }

    /**
     * number of times the buzzer output was activated
     *
     * Generated from protobuf field <code>uint32 BuzzerActivations = 14;</code>
     * @param int $var
     * @return $this
     */
    public function setBuzzerActivations($var)
    {
        GPBUtil::checkUint32($var);
        $this->BuzzerActivations = $var;

        return $this;
    }

    /**
     * number of times a tamper code was received (0xF on Impro Keypads)
     *
     * Generated from protobuf field <code>uint32 TamperTriggers = 15;</code>
     * @return int
     */
    public function getTamperTriggers()
    {
        return $this->TamperTriggers;
    }

    /**
     * number of times a tamper code was received (0xF on Impro Keypads)
     *
     * Generated from protobuf field <code>uint32 TamperTriggers = 15;</code>
     * @param int $var
     * @return $this
     */
    public function setTamperTriggers($var)
    {
        GPBUtil::checkUint32($var);
        $this->TamperTriggers = $var;

        return $this;
    }

}

