<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 **
 * \@brief: Configuration for OneHealth Link Devices
 *
 * Generated from protobuf message <code>OS.PB.HealthLinkConfig</code>
 */
class HealthLinkConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     */
    protected $State = 0;
    /**
     * Default: Depends on BOARD_NAME
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     */
    protected $Role = 0;
    /**
     * Which Ward Station Link device to send events to.
     *
     * Generated from protobuf field <code>uint64 WardStationLinkId = 4;</code>
     */
    protected $WardStationLinkId = 0;
    /**
     * Which interface to activate (Relay or Output) when an alert event is detected
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface AlertInterface = 5;</code>
     */
    protected $AlertInterface = 0;
    /**
     * Which interface index of the above
     *
     * Generated from protobuf field <code>uint32 AlertInterfaceIndex = 6;</code>
     */
    protected $AlertInterfaceIndex = 0;
    /**
     * Automatically activate the interface if the button is configured on this link device
     *
     * Generated from protobuf field <code>sint32 AlertRSSIThreshold = 10;</code>
     */
    protected $AlertRSSIThreshold = 0;
    /**
     * Automatically send a Monitoring alert when RSSI met
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 11;</code>
     */
    protected $MonitorRSSIThreshold = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $State
     *           Default: Enabled. Whether OneHealth application is enabled or not on this device
     *     @type int $Role
     *           Default: Depends on BOARD_NAME
     *     @type int|string $WardStationLinkId
     *           Which Ward Station Link device to send events to.
     *     @type int $AlertInterface
     *           Which interface to activate (Relay or Output) when an alert event is detected
     *     @type int $AlertInterfaceIndex
     *           Which interface index of the above
     *     @type int $AlertRSSIThreshold
     *           Automatically activate the interface if the button is configured on this link device
     *     @type int $MonitorRSSIThreshold
     *           Automatically send a Monitoring alert when RSSI met
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     * @return int
     */
    public function getState()
    {
        return $this->State;
    }

    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setState($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->State = $var;

        return $this;
    }

    /**
     * Default: Depends on BOARD_NAME
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     * @return int
     */
    public function getRole()
    {
        return $this->Role;
    }

    /**
     * Default: Depends on BOARD_NAME
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setRole($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\HealthLinkRole::class);
        $this->Role = $var;

        return $this;
    }

    /**
     * Which Ward Station Link device to send events to.
     *
     * Generated from protobuf field <code>uint64 WardStationLinkId = 4;</code>
     * @return int|string
     */
    public function getWardStationLinkId()
    {
        return $this->WardStationLinkId;
    }

    /**
     * Which Ward Station Link device to send events to.
     *
     * Generated from protobuf field <code>uint64 WardStationLinkId = 4;</code>
     * @param int|string $var
     * @return $this
     */
    public function setWardStationLinkId($var)
    {
        GPBUtil::checkUint64($var);
        $this->WardStationLinkId = $var;

        return $this;
    }

    /**
     * Which interface to activate (Relay or Output) when an alert event is detected
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface AlertInterface = 5;</code>
     * @return int
     */
    public function getAlertInterface()
    {
        return $this->AlertInterface;
    }

    /**
     * Which interface to activate (Relay or Output) when an alert event is detected
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface AlertInterface = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setAlertInterface($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceInterface::class);
        $this->AlertInterface = $var;

        return $this;
    }

    /**
     * Which interface index of the above
     *
     * Generated from protobuf field <code>uint32 AlertInterfaceIndex = 6;</code>
     * @return int
     */
    public function getAlertInterfaceIndex()
    {
        return $this->AlertInterfaceIndex;
    }

    /**
     * Which interface index of the above
     *
     * Generated from protobuf field <code>uint32 AlertInterfaceIndex = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setAlertInterfaceIndex($var)
    {
        GPBUtil::checkUint32($var);
        $this->AlertInterfaceIndex = $var;

        return $this;
    }

    /**
     * Automatically activate the interface if the button is configured on this link device
     *
     * Generated from protobuf field <code>sint32 AlertRSSIThreshold = 10;</code>
     * @return int
     */
    public function getAlertRSSIThreshold()
    {
        return $this->AlertRSSIThreshold;
    }

    /**
     * Automatically activate the interface if the button is configured on this link device
     *
     * Generated from protobuf field <code>sint32 AlertRSSIThreshold = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setAlertRSSIThreshold($var)
    {
        GPBUtil::checkInt32($var);
        $this->AlertRSSIThreshold = $var;

        return $this;
    }

    /**
     * Automatically send a Monitoring alert when RSSI met
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 11;</code>
     * @return int
     */
    public function getMonitorRSSIThreshold()
    {
        return $this->MonitorRSSIThreshold;
    }

    /**
     * Automatically send a Monitoring alert when RSSI met
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setMonitorRSSIThreshold($var)
    {
        GPBUtil::checkInt32($var);
        $this->MonitorRSSIThreshold = $var;

        return $this;
    }

}

