<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: filesystem.proto

namespace GPBMetadata;

class Filesystem
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xF5\x05\x0A\x10filesystem.proto\x12\x05OS.PB\"A\x0A\x0AListResult\x12\x0C\x0A\x04Path\x18\x01 \x01(\x09\x12\x13\x0A\x0BIsDirectory\x18\x02 \x01(\x08\x12\x10\x0A\x08FileSize\x18\x03 \x01(\x0D\"k\x0A\x11FileSystemRequest\x12\x0C\x0A\x04Path\x18\x02 \x01(\x09\x12\x12\x0A\x0ASourcePath\x18\x03 \x01(\x09\x12\x16\x0A\x0ESourceDeviceId\x18\x04 \x01(\x04\x12\x0C\x0A\x04Data\x18\x05 \x01(\x0C\x12\x0E\x0A\x06Offset\x18\x06 \x01(\x0D\"\x8C\x01\x0A\x12FileSystemResponse\x12&\x0A\x06Result\x18\x01 \x01(\x0E2\x16.OS.PB.FileResultTypes\x12\x0C\x0A\x04Path\x18\x02 \x01(\x09\x12\$\x0A\x05Paths\x18\x03 \x03(\x0B2\x11.OS.PB.ListResultB\x02\x10\x00\x12\x0C\x0A\x04Data\x18\x05 \x01(\x0C\x12\x0C\x0A\x04Size\x18\x06 \x01(\x0D*\x8E\x03\x0A\x0FFileResultTypes\x12\x11\x0A\x0DFileResult_Ok\x10\x00\x12\x16\x0A\x12FileResult_ErrorIO\x10\x05\x12\x1D\x0A\x19FileResult_ErrorCorrupted\x10T\x12\x1C\x0A\x18FileResult_ErrorNotFound\x10\x02\x12!\x0A\x1DFileResult_ErrorAlreadyExists\x10\x11\x12\x1F\x0A\x1BFileResult_ErrorDirNotEmpty\x10'\x12!\x0A\x1DFileResult_ErrorBadFileNumber\x10\x09\x12\x1E\x0A\x1AFileResult_ErrorFileTooBig\x10\x1B\x12\$\x0A FileResult_ErrorInvalidParameter\x10\x16\x12\$\x0A FileResult_ErrorNoSpaceAvailable\x10\x1C\x12\x1F\x0A\x1BFileResult_ErrorOutOfMemory\x10\x0C\x12\x1F\x0A\x1BFileResult_ErrorPathTooLong\x10\$B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

