<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.BLERequest</code>
 */
class BLERequest extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>bool IncludeConfig = 1;</code>
     */
    protected $IncludeConfig = false;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type bool $IncludeConfig
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Ble::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>bool IncludeConfig = 1;</code>
     * @return bool
     */
    public function getIncludeConfig()
    {
        return $this->IncludeConfig;
    }

    /**
     * Generated from protobuf field <code>bool IncludeConfig = 1;</code>
     * @param bool $var
     * @return $this
     */
    public function setIncludeConfig($var)
    {
        GPBUtil::checkBool($var);
        $this->IncludeConfig = $var;

        return $this;
    }

}

