<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: anpr.proto

namespace GPBMetadata;

class Anpr
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xBF\x03\x0A\x0Aanpr.proto\x12\x05OS.PB\"\x80\x01\x0A\x09ANPREvent\x12\x10\x0A\x08CameraId\x18\x01 \x01(\x0C\x12\x10\x0A\x08Sequence\x18\x02 \x01(\x0D\x12\x11\x0A\x09TimeStamp\x18\x03 \x01(\x0D\x12'\x0A\x09Direction\x18\x04 \x01(\x0E2\x14.OS.PB.ANPRDirection\x12\x13\x0A\x0BNumberPlate\x18\x05 \x01(\x09\"v\x0A\x0AANPRConfig\x12\"\x0A\x08ANPRType\x18\x01 \x01(\x0E2\x10.OS.PB.ANPRTypes\x12\x18\x0A\x10SamePlateTimeout\x18\x02 \x01(\x0D\x12\$\x0A\x0DNoPlateEvents\x18\x04 \x01(\x0E2\x0D.OS.PB.ToggleJ\x04\x08\x03\x10\x04*_\x0A\x0DANPRDirection\x12\x18\x0A\x14ANPRDirection_NotSet\x10\x00\x12\x19\x0A\x15ANPRDirection_Forward\x10\x01\x12\x19\x0A\x15ANPRDirection_Reverse\x10\x02*B\x0A\x09ANPRTypes\x12\x0F\x0A\x0BANPR_NotSet\x10\x00\x12\x12\x0A\x0EANPR_HIKVision\x10\x01\x12\x10\x0A\x0CANPR_Tattile\x10\x0AB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

