<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: packet.proto

namespace GPBMetadata;

class Packet
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Event::initOnce();
        \GPBMetadata\Action::initOnce();
        \GPBMetadata\Config::initOnce();
        \GPBMetadata\Rpc::initOnce();
        \GPBMetadata\Log::initOnce();
        \GPBMetadata\Metric::initOnce();
        \GPBMetadata\Device::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xF4\x0A\x0A\x0Cpacket.proto\x12\x05OS.PB\x1A\x0Caction.proto\x1A\x0Cconfig.proto\x1A\x09rpc.proto\x1A\x09log.proto\x1A\x0Cmetric.proto\x1A\x0Cdevice.proto\"\xAB\x03\x0A\x07Message\x12\x13\x0A\x0BTimeStampMs\x18\x01 \x01(\x03\x12\x12\x0A\x0ATimeToLive\x18\x02 \x01(\x03\x12\x15\x0A\x0DCorrelationId\x18\x03 \x01(\x04\x12\x10\x0A\x08Priority\x18\x04 \x01(\x0D\x12\x11\x0A\x09Propagate\x18\x05 \x01(\x08\x12\$\x0A\x05Event\x18\x06 \x01(\x0B2\x13.OS.PB.EventMessageH\x00\x12&\x0A\x06Action\x18\x07 \x01(\x0B2\x14.OS.PB.ActionMessageH\x00\x12&\x0A\x06Config\x18\x08 \x01(\x0B2\x14.OS.PB.ConfigMessageH\x00\x12 \x0A\x03Log\x18\x09 \x01(\x0B2\x11.OS.PB.LogMessageH\x00\x12&\x0A\x06Metric\x18\x0A \x01(\x0B2\x14.OS.PB.MetricMessageH\x00\x12(\x0A\x07Request\x18\x0B \x01(\x0B2\x15.OS.PB.RequestMessageH\x00\x12*\x0A\x08Response\x18\x0C \x01(\x0B2\x16.OS.PB.ResponseMessageH\x00\x12\x16\x0A\x0CRoutedPacket\x18\x0F \x01(\x0CH\x00B\x0D\x0A\x0BMessageType\"\xA1\x05\x0A\x06Packet\x12-\x0A\x0APacketType\x18\x01 \x01(\x0E2\x19.OS.PB.Packet.PacketTypes\x12\x19\x0A\x11DestinationSerial\x18\x02 \x01(\x0D\x12\x14\x0A\x0CSourceSerial\x18\x03 \x01(\x0D\x12\x1B\x0A\x13DestinationDeviceId\x18\x06 \x01(\x04\x12\x16\x0A\x0ESourceDeviceId\x18\x07 \x01(\x04\x12/\x0A\x0FSourceInterface\x18\x08 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x1C\x0A\x14SourceInterfaceIndex\x18\x09 \x01(\x0D\x12\x12\x0A\x0ASourceRSSI\x18\x0A \x01(\x11\x12\x16\x0A\x0ESequenceNumber\x18\x0B \x01(\x0D\x12\x19\x0A\x11RedeliveryCounter\x18\x0C \x01(\x0D\x12\x13\x0A\x0BTimeStampMs\x18\x0D \x01(\x03\x12\x13\x0A\x0BRoutedCount\x18\x0E \x01(\x0D\x12\$\x0A\x08Messages\x18\x0F \x03(\x0B2\x0E.OS.PB.MessageB\x02\x10\x00\"\x9B\x02\x0A\x0BPacketTypes\x12\x15\x0A\x11PacketType_NotSet\x10\x00\x12\x18\x0A\x14PacketType_Data_QoS1\x10\x00\x12\x18\x0A\x14PacketType_Data_QoS0\x10\x01\x12\x1D\x0A\x19PacketType_Encrypted_QoS1\x10\x02\x12\x1C\x0A\x18PacketType_Advertisement\x10\x04\x12\x12\x0A\x0EPacketType_ACK\x10\x10\x12\x13\x0A\x0FPacketType_NACK\x10 \x12\x18\x0A\x14PacketType_NACK_Busy\x100\x12\x1B\x0A\x17PacketType_NACK_NoRoute\x10@\x12 \x0A\x1CPacketType_NACK_NotConnected\x10P\x1A\x02\x10\x01*&\x0A\x0FMessagePriority\x12\x13\x0A\x0FPriority_NotSet\x10\x00*\x88\x01\x0A\x14PacketSequenceNumber\x12\x19\x0A\x15SequenceNumber_NotSet\x10\x00\x12\x18\x0A\x14SequenceNumber_Reset\x10\x01\x12\x1C\x0A\x18SequenceNumber_WrapStart\x10\x02\x12\x1D\x0A\x19SequenceNumber_WrapAround\x10\x7FB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

