<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.CodeHopResponse</code>
 */
class CodeHopResponse extends \Google\Protobuf\Internal\Message
{
    /**
     * Refer above
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopResponse.CodeHopResponseTypes Response = 1;</code>
     */
    protected $Response = 0;
    /**
     * Serial that is returned on enrollment
     *
     * Generated from protobuf field <code>uint64 Serial = 2;</code>
     */
    protected $Serial = 0;
    /**
     * The number of times the remote button was pressed one after the other
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 3;</code>
     */
    protected $ButtonPresses = 0;
    /**
     * The best RSSI in dBm reported over all button presses
     *
     * Generated from protobuf field <code>sint32 RSSI = 5;</code>
     */
    protected $RSSI = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Response
     *           Refer above
     *     @type int|string $Serial
     *           Serial that is returned on enrollment
     *     @type int $ButtonPresses
     *           The number of times the remote button was pressed one after the other
     *     @type int $RSSI
     *           The best RSSI in dBm reported over all button presses
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Codehop::initOnce();
        parent::__construct($data);
    }

    /**
     * Refer above
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopResponse.CodeHopResponseTypes Response = 1;</code>
     * @return int
     */
    public function getResponse()
    {
        return $this->Response;
    }

    /**
     * Refer above
     *
     * Generated from protobuf field <code>.OS.PB.CodeHopResponse.CodeHopResponseTypes Response = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setResponse($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\CodeHopResponse\CodeHopResponseTypes::class);
        $this->Response = $var;

        return $this;
    }

    /**
     * Serial that is returned on enrollment
     *
     * Generated from protobuf field <code>uint64 Serial = 2;</code>
     * @return int|string
     */
    public function getSerial()
    {
        return $this->Serial;
    }

    /**
     * Serial that is returned on enrollment
     *
     * Generated from protobuf field <code>uint64 Serial = 2;</code>
     * @param int|string $var
     * @return $this
     */
    public function setSerial($var)
    {
        GPBUtil::checkUint64($var);
        $this->Serial = $var;

        return $this;
    }

    /**
     * The number of times the remote button was pressed one after the other
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 3;</code>
     * @return int
     */
    public function getButtonPresses()
    {
        return $this->ButtonPresses;
    }

    /**
     * The number of times the remote button was pressed one after the other
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setButtonPresses($var)
    {
        GPBUtil::checkUint32($var);
        $this->ButtonPresses = $var;

        return $this;
    }

    /**
     * The best RSSI in dBm reported over all button presses
     *
     * Generated from protobuf field <code>sint32 RSSI = 5;</code>
     * @return int
     */
    public function getRSSI()
    {
        return $this->RSSI;
    }

    /**
     * The best RSSI in dBm reported over all button presses
     *
     * Generated from protobuf field <code>sint32 RSSI = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setRSSI($var)
    {
        GPBUtil::checkInt32($var);
        $this->RSSI = $var;

        return $this;
    }

}

