<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceResponse</code>
 */
class DeviceResponse extends \Google\Protobuf\Internal\Message
{
    /**
     * Device Settings
     *
     * Generated from protobuf field <code>.OS.PB.DeviceConfig DeviceParameters = 1;</code>
     */
    protected $DeviceParameters = null;
    /**
     * Generated from protobuf field <code>repeated .OS.PB.InterfaceInfo InterfaceInfo = 2;</code>
     */
    private $InterfaceInfo;
    /**
     * Generated from protobuf field <code>repeated .OS.PB.DeviceRoutingConfig Routing = 3;</code>
     */
    private $Routing;
    /**
     * Factory programmed information
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 5;</code>
     */
    protected $SerialNumber = 0;
    /**
     * Follows format of Major.Minor.Patch-Note+Tweak
     *
     * Generated from protobuf field <code>string AppFirmwareVersion = 7;</code>
     */
    protected $AppFirmwareVersion = '';
    /**
     * mmm dd yyyy hh:mm:ss
     *
     * Generated from protobuf field <code>string AppBuildDateTime = 8;</code>
     */
    protected $AppBuildDateTime = '';
    /**
     * Product code of hardware platform, eg: AOH0001-007-06
     *
     * Generated from protobuf field <code>string HardwarePlatform = 10;</code>
     */
    protected $HardwarePlatform = '';
    /**
     * File System
     *
     * Generated from protobuf field <code>uint32 InternalFileSystemSize = 12;</code>
     */
    protected $InternalFileSystemSize = 0;
    /**
     * External FileSystem size for devices that can accept things like SD cards, USB drives etc
     *
     * Generated from protobuf field <code>uint32 ExternalFileSystemSize = 13;</code>
     */
    protected $ExternalFileSystemSize = 0;
    /**
     * Manufacturer MCU Information                                  
     *
     * Generated from protobuf field <code>uint64 MCUUID = 16;</code>
     */
    protected $MCUUID = 0;
    /**
     * on nRF52: processed from FICR
     *
     * Generated from protobuf field <code>uint64 MCUSocRevision = 17;</code>
     */
    protected $MCUSocRevision = 0;
    /**
     * reinterfaces the part number of the MCU
     *
     * Generated from protobuf field <code>uint64 MCUPartId = 18;</code>
     */
    protected $MCUPartId = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type \OS\PB\DeviceConfig $DeviceParameters
     *           Device Settings
     *     @type \OS\PB\InterfaceInfo[] $InterfaceInfo
     *     @type \OS\PB\DeviceRoutingConfig[] $Routing
     *     @type int $SerialNumber
     *           Factory programmed information
     *     @type string $AppFirmwareVersion
     *           Follows format of Major.Minor.Patch-Note+Tweak
     *     @type string $AppBuildDateTime
     *           mmm dd yyyy hh:mm:ss
     *     @type string $HardwarePlatform
     *           Product code of hardware platform, eg: AOH0001-007-06
     *     @type int $InternalFileSystemSize
     *           File System
     *     @type int $ExternalFileSystemSize
     *           External FileSystem size for devices that can accept things like SD cards, USB drives etc
     *     @type int|string $MCUUID
     *           Manufacturer MCU Information                                  
     *     @type int|string $MCUSocRevision
     *           on nRF52: processed from FICR
     *     @type int|string $MCUPartId
     *           reinterfaces the part number of the MCU
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * Device Settings
     *
     * Generated from protobuf field <code>.OS.PB.DeviceConfig DeviceParameters = 1;</code>
     * @return \OS\PB\DeviceConfig|null
     */
    public function getDeviceParameters()
    {
        return $this->DeviceParameters;
    }

    public function hasDeviceParameters()
    {
        return isset($this->DeviceParameters);
    }

    public function clearDeviceParameters()
    {
        unset($this->DeviceParameters);
    }

    /**
     * Device Settings
     *
     * Generated from protobuf field <code>.OS.PB.DeviceConfig DeviceParameters = 1;</code>
     * @param \OS\PB\DeviceConfig $var
     * @return $this
     */
    public function setDeviceParameters($var)
    {
        GPBUtil::checkMessage($var, \OS\PB\DeviceConfig::class);
        $this->DeviceParameters = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>repeated .OS.PB.InterfaceInfo InterfaceInfo = 2;</code>
     * @return RepeatedField<\OS\PB\InterfaceInfo>
     */
    public function getInterfaceInfo()
    {
        return $this->InterfaceInfo;
    }

    /**
     * Generated from protobuf field <code>repeated .OS.PB.InterfaceInfo InterfaceInfo = 2;</code>
     * @param \OS\PB\InterfaceInfo[] $var
     * @return $this
     */
    public function setInterfaceInfo($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::MESSAGE, \OS\PB\InterfaceInfo::class);
        $this->InterfaceInfo = $arr;

        return $this;
    }

    /**
     * Generated from protobuf field <code>repeated .OS.PB.DeviceRoutingConfig Routing = 3;</code>
     * @return RepeatedField<\OS\PB\DeviceRoutingConfig>
     */
    public function getRouting()
    {
        return $this->Routing;
    }

    /**
     * Generated from protobuf field <code>repeated .OS.PB.DeviceRoutingConfig Routing = 3;</code>
     * @param \OS\PB\DeviceRoutingConfig[] $var
     * @return $this
     */
    public function setRouting($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::MESSAGE, \OS\PB\DeviceRoutingConfig::class);
        $this->Routing = $arr;

        return $this;
    }

    /**
     * Factory programmed information
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 5;</code>
     * @return int
     */
    public function getSerialNumber()
    {
        return $this->SerialNumber;
    }

    /**
     * Factory programmed information
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setSerialNumber($var)
    {
        GPBUtil::checkUint32($var);
        $this->SerialNumber = $var;

        return $this;
    }

    /**
     * Follows format of Major.Minor.Patch-Note+Tweak
     *
     * Generated from protobuf field <code>string AppFirmwareVersion = 7;</code>
     * @return string
     */
    public function getAppFirmwareVersion()
    {
        return $this->AppFirmwareVersion;
    }

    /**
     * Follows format of Major.Minor.Patch-Note+Tweak
     *
     * Generated from protobuf field <code>string AppFirmwareVersion = 7;</code>
     * @param string $var
     * @return $this
     */
    public function setAppFirmwareVersion($var)
    {
        GPBUtil::checkString($var, True);
        $this->AppFirmwareVersion = $var;

        return $this;
    }

    /**
     * mmm dd yyyy hh:mm:ss
     *
     * Generated from protobuf field <code>string AppBuildDateTime = 8;</code>
     * @return string
     */
    public function getAppBuildDateTime()
    {
        return $this->AppBuildDateTime;
    }

    /**
     * mmm dd yyyy hh:mm:ss
     *
     * Generated from protobuf field <code>string AppBuildDateTime = 8;</code>
     * @param string $var
     * @return $this
     */
    public function setAppBuildDateTime($var)
    {
        GPBUtil::checkString($var, True);
        $this->AppBuildDateTime = $var;

        return $this;
    }

    /**
     * Product code of hardware platform, eg: AOH0001-007-06
     *
     * Generated from protobuf field <code>string HardwarePlatform = 10;</code>
     * @return string
     */
    public function getHardwarePlatform()
    {
        return $this->HardwarePlatform;
    }

    /**
     * Product code of hardware platform, eg: AOH0001-007-06
     *
     * Generated from protobuf field <code>string HardwarePlatform = 10;</code>
     * @param string $var
     * @return $this
     */
    public function setHardwarePlatform($var)
    {
        GPBUtil::checkString($var, True);
        $this->HardwarePlatform = $var;

        return $this;
    }

    /**
     * File System
     *
     * Generated from protobuf field <code>uint32 InternalFileSystemSize = 12;</code>
     * @return int
     */
    public function getInternalFileSystemSize()
    {
        return $this->InternalFileSystemSize;
    }

    /**
     * File System
     *
     * Generated from protobuf field <code>uint32 InternalFileSystemSize = 12;</code>
     * @param int $var
     * @return $this
     */
    public function setInternalFileSystemSize($var)
    {
        GPBUtil::checkUint32($var);
        $this->InternalFileSystemSize = $var;

        return $this;
    }

    /**
     * External FileSystem size for devices that can accept things like SD cards, USB drives etc
     *
     * Generated from protobuf field <code>uint32 ExternalFileSystemSize = 13;</code>
     * @return int
     */
    public function getExternalFileSystemSize()
    {
        return $this->ExternalFileSystemSize;
    }

    /**
     * External FileSystem size for devices that can accept things like SD cards, USB drives etc
     *
     * Generated from protobuf field <code>uint32 ExternalFileSystemSize = 13;</code>
     * @param int $var
     * @return $this
     */
    public function setExternalFileSystemSize($var)
    {
        GPBUtil::checkUint32($var);
        $this->ExternalFileSystemSize = $var;

        return $this;
    }

    /**
     * Manufacturer MCU Information                                  
     *
     * Generated from protobuf field <code>uint64 MCUUID = 16;</code>
     * @return int|string
     */
    public function getMCUUID()
    {
        return $this->MCUUID;
    }

    /**
     * Manufacturer MCU Information                                  
     *
     * Generated from protobuf field <code>uint64 MCUUID = 16;</code>
     * @param int|string $var
     * @return $this
     */
    public function setMCUUID($var)
    {
        GPBUtil::checkUint64($var);
        $this->MCUUID = $var;

        return $this;
    }

    /**
     * on nRF52: processed from FICR
     *
     * Generated from protobuf field <code>uint64 MCUSocRevision = 17;</code>
     * @return int|string
     */
    public function getMCUSocRevision()
    {
        return $this->MCUSocRevision;
    }

    /**
     * on nRF52: processed from FICR
     *
     * Generated from protobuf field <code>uint64 MCUSocRevision = 17;</code>
     * @param int|string $var
     * @return $this
     */
    public function setMCUSocRevision($var)
    {
        GPBUtil::checkUint64($var);
        $this->MCUSocRevision = $var;

        return $this;
    }

    /**
     * reinterfaces the part number of the MCU
     *
     * Generated from protobuf field <code>uint64 MCUPartId = 18;</code>
     * @return int|string
     */
    public function getMCUPartId()
    {
        return $this->MCUPartId;
    }

    /**
     * reinterfaces the part number of the MCU
     *
     * Generated from protobuf field <code>uint64 MCUPartId = 18;</code>
     * @param int|string $var
     * @return $this
     */
    public function setMCUPartId($var)
    {
        GPBUtil::checkUint64($var);
        $this->MCUPartId = $var;

        return $this;
    }

}

