<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.CodeHopRequest</code>
 */
class CodeHopRequest extends \Google\Protobuf\Internal\Message
{
    /**
     * If True, will stop on first codehop remote to reach the button presses.
     *
     * Generated from protobuf field <code>bool StopOnFirst = 1;</code>
     */
    protected $StopOnFirst = false;
    /**
     * Default: 3. Number of button presses before adding it to the response list. 
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 2;</code>
     */
    protected $ButtonPresses = 0;
    /**
     * Default: Red (1). Which buttons are permitted for enrollment
     *
     * Generated from protobuf field <code>uint64 ButtonsFilter = 3;</code>
     */
    protected $ButtonsFilter = 0;
    /**
     * Default: -50dBm. Minimum RSSI the remote must be for enrollment. 
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     */
    protected $RSSIMinimum = 0;
    /**
     * Default: False. If true, will send a CodeHopEnroll event each time the correct button is pushed
     *
     * Generated from protobuf field <code>bool SendEnrollEvents = 8;</code>
     */
    protected $SendEnrollEvents = false;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type bool $StopOnFirst
     *           If True, will stop on first codehop remote to reach the button presses.
     *     @type int $ButtonPresses
     *           Default: 3. Number of button presses before adding it to the response list. 
     *     @type int|string $ButtonsFilter
     *           Default: Red (1). Which buttons are permitted for enrollment
     *     @type int $RSSIMinimum
     *           Default: -50dBm. Minimum RSSI the remote must be for enrollment. 
     *     @type bool $SendEnrollEvents
     *           Default: False. If true, will send a CodeHopEnroll event each time the correct button is pushed
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Codehop::initOnce();
        parent::__construct($data);
    }

    /**
     * If True, will stop on first codehop remote to reach the button presses.
     *
     * Generated from protobuf field <code>bool StopOnFirst = 1;</code>
     * @return bool
     */
    public function getStopOnFirst()
    {
        return $this->StopOnFirst;
    }

    /**
     * If True, will stop on first codehop remote to reach the button presses.
     *
     * Generated from protobuf field <code>bool StopOnFirst = 1;</code>
     * @param bool $var
     * @return $this
     */
    public function setStopOnFirst($var)
    {
        GPBUtil::checkBool($var);
        $this->StopOnFirst = $var;

        return $this;
    }

    /**
     * Default: 3. Number of button presses before adding it to the response list. 
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 2;</code>
     * @return int
     */
    public function getButtonPresses()
    {
        return $this->ButtonPresses;
    }

    /**
     * Default: 3. Number of button presses before adding it to the response list. 
     *
     * Generated from protobuf field <code>uint32 ButtonPresses = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setButtonPresses($var)
    {
        GPBUtil::checkUint32($var);
        $this->ButtonPresses = $var;

        return $this;
    }

    /**
     * Default: Red (1). Which buttons are permitted for enrollment
     *
     * Generated from protobuf field <code>uint64 ButtonsFilter = 3;</code>
     * @return int|string
     */
    public function getButtonsFilter()
    {
        return $this->ButtonsFilter;
    }

    /**
     * Default: Red (1). Which buttons are permitted for enrollment
     *
     * Generated from protobuf field <code>uint64 ButtonsFilter = 3;</code>
     * @param int|string $var
     * @return $this
     */
    public function setButtonsFilter($var)
    {
        GPBUtil::checkUint64($var);
        $this->ButtonsFilter = $var;

        return $this;
    }

    /**
     * Default: -50dBm. Minimum RSSI the remote must be for enrollment. 
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     * @return int
     */
    public function getRSSIMinimum()
    {
        return $this->RSSIMinimum;
    }

    /**
     * Default: -50dBm. Minimum RSSI the remote must be for enrollment. 
     *
     * Generated from protobuf field <code>sint32 RSSIMinimum = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setRSSIMinimum($var)
    {
        GPBUtil::checkInt32($var);
        $this->RSSIMinimum = $var;

        return $this;
    }

    /**
     * Default: False. If true, will send a CodeHopEnroll event each time the correct button is pushed
     *
     * Generated from protobuf field <code>bool SendEnrollEvents = 8;</code>
     * @return bool
     */
    public function getSendEnrollEvents()
    {
        return $this->SendEnrollEvents;
    }

    /**
     * Default: False. If true, will send a CodeHopEnroll event each time the correct button is pushed
     *
     * Generated from protobuf field <code>bool SendEnrollEvents = 8;</code>
     * @param bool $var
     * @return $this
     */
    public function setSendEnrollEvents($var)
    {
        GPBUtil::checkBool($var);
        $this->SendEnrollEvents = $var;

        return $this;
    }

}

