<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceAction</code>
 */
class DeviceAction extends \Google\Protobuf\Internal\Message
{
    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceFormatMethod FormatMethod = 1;</code>
     */
    protected $FormatMethod = 0;
    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 2;</code>
     */
    protected $RestartMethod = 0;
    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceEraseMethod EraseMethod = 3;</code>
     */
    protected $EraseMethod = 0;
    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceExecuteProcess ExecuteProcess = 4;</code>
     */
    protected $ExecuteProcess = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $FormatMethod
     *           refer to enum above
     *     @type int $RestartMethod
     *           refer to enum above
     *     @type int $EraseMethod
     *           refer to enum above
     *     @type int $ExecuteProcess
     *           refer to enum above
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceFormatMethod FormatMethod = 1;</code>
     * @return int
     */
    public function getFormatMethod()
    {
        return $this->FormatMethod;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceFormatMethod FormatMethod = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setFormatMethod($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceFormatMethod::class);
        $this->FormatMethod = $var;

        return $this;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 2;</code>
     * @return int
     */
    public function getRestartMethod()
    {
        return $this->RestartMethod;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceRestartMethod RestartMethod = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setRestartMethod($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceRestartMethod::class);
        $this->RestartMethod = $var;

        return $this;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceEraseMethod EraseMethod = 3;</code>
     * @return int
     */
    public function getEraseMethod()
    {
        return $this->EraseMethod;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceEraseMethod EraseMethod = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setEraseMethod($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceEraseMethod::class);
        $this->EraseMethod = $var;

        return $this;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceExecuteProcess ExecuteProcess = 4;</code>
     * @return int
     */
    public function getExecuteProcess()
    {
        return $this->ExecuteProcess;
    }

    /**
     * refer to enum above
     *
     * Generated from protobuf field <code>.OS.PB.DeviceExecuteProcess ExecuteProcess = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setExecuteProcess($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceExecuteProcess::class);
        $this->ExecuteProcess = $var;

        return $this;
    }

}

