<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dfu.proto

namespace GPBMetadata;

class Dfu
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xBD\x09\x0A\x09dfu.proto\x12\x05OS.PB\"-\x0A\x09DFUAction\x12\x12\x0A\x0ABlockIndex\x18\x01 \x01(\x0D\x12\x0C\x0A\x04Data\x18\x03 \x01(\x0C\"l\x0A\x08DFUEvent\x12\x12\x0A\x0ABlockIndex\x18\x01 \x01(\x0D\x12\x13\x0A\x0BBlocksTotal\x18\x02 \x01(\x0D\x12\x12\x0A\x0ABlockCount\x18\x03 \x01(\x0D\x12\x12\x0A\x0APercentage\x18\x04 \x01(\x0D\x12\x0F\x0A\x07Message\x18\x05 \x01(\x09\"\xBA\x03\x0A\x0ADFURequest\x12\x18\x0A\x10HardwarePlatform\x18\x02 \x01(\x09\x12\x11\x0A\x09ImageSize\x18\x03 \x01(\x0D\x12\x11\x0A\x09ImageHash\x18\x04 \x01(\x0C\x12\x19\x0A\x11TransferBlockSize\x18\x05 \x01(\x0D\x12\x1B\x0A\x13TransferBlocksTotal\x18\x06 \x01(\x0D\x12\x16\x0A\x0EValidationTime\x18\x07 \x01(\x0D\x12<\x0A\x0EProgressOption\x18\x0A \x01(\x0E2\$.OS.PB.DFURequest.DFUProgressOptions\"\xDD\x01\x0A\x12DFUProgressOptions\x12\x1E\x0A\x1ADFUProgressOption_Disabled\x10\x00\x12&\x0A\"DFUProgressOption_StatusChangeOnly\x10\x01\x12'\x0A#DFUProgressOption_StatusAndPerBlock\x10\x02\x12)\x0A%DFUProgressOption_StatusAndPerPercent\x10\x03\x12+\x0A'DFUProgressOption_StatusAndPer10Percent\x10\x04\"\xC2\x04\x0A\x0BDFUResponse\x124\x0A\x08Response\x18\x01 \x01(\x0E2\".OS.PB.DFUResponse.DFUResponseType\x12\x18\x0A\x10ImageBlocksTotal\x18\x02 \x01(\x0D\x12\x19\x0A\x11ImageBlocksStatus\x18\x03 \x01(\x0C\x12\x19\x0A\x11BlocksTransferred\x18\x04 \x01(\x0D\"\xAC\x03\x0A\x0FDFUResponseType\x12\x16\x0A\x12DFUResponse_NotSet\x10\x00\x12\x17\x0A\x13DFUResponse_Success\x10\x01\x12\x1C\x0A\x18DFUResponse_NotInitiated\x10\x02\x12\x19\x0A\x15DFUResponse_Initiated\x10\x03\x12\x1B\x0A\x17DFUResponse_Downloading\x10\x04\x12\x19\x0A\x15DFUResponse_Verifying\x10\x05\x12\x1A\x0A\x16DFUResponse_Validating\x10\x07\x12\x19\x0A\x15DFUResponse_Completed\x10\x08\x12\x16\x0A\x12DFUResponse_Failed\x10\x09\x12\x1C\x0A\x18DFUResponse_SizeTooLarge\x10\x0A\x12\x1C\x0A\x18DFUResponse_InvalidValue\x10\x0B\x12(\x0A\$DFUResponse_HardwarePlatformMismatch\x10\x0C\x12 \x0A\x1CDFUResponse_AlreadyInitiated\x10\x0D\x12 \x0A\x1CDFUResponse_InitializeFailed\x10\x0EB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

