<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eventrules.proto

namespace GPBMetadata;

class Eventrules
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Event::initOnce();
        \GPBMetadata\Action::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xE2\x02\x0A\x10eventrules.proto\x12\x05OS.PB\x1A\x0Caction.proto\"\xBA\x01\x0A\x09EventRule\x12\x1B\x0A\x13DestinationDeviceId\x18\x01 \x01(\x04\x12(\x0A\x0BOnCondition\x18\x05 \x01(\x0B2\x13.OS.PB.EventMessage\x12'\x0A\x0AExceptWhen\x18\x0A \x03(\x0B2\x13.OS.PB.EventMessage\x12\x14\x0A\x0CBreakOnMatch\x18\x0D \x01(\x08\x12'\x0A\x09DoActions\x18\x0F \x03(\x0B2\x14.OS.PB.ActionMessage\"E\x0A\x0FEventRuleConfig\x12\x11\x0A\x09EventType\x18\x01 \x01(\x0D\x12\x1F\x0A\x05Rules\x18\x05 \x03(\x0B2\x10.OS.PB.EventRule\")\x0A\x15EventRulesEraseConfig\x12\x10\x0A\x08AllRules\x18\x01 \x01(\x08B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

