<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: log.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 ** 
 * \@brief   Sets the severity level on when a device is to report log strings for the server
 *
 * Generated from protobuf message <code>OS.PB.LogConfig</code>
 */
class LogConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.LogConfig.LogLevelType LogLevel = 1;</code>
     */
    protected $LogLevel = 0;
    /**
     * Time until reverting to default log level (Error), zero defaults to 1 day or 1440 minutes
     *
     * Generated from protobuf field <code>uint32 RevertTimeoutMinutes = 2;</code>
     */
    protected $RevertTimeoutMinutes = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $LogLevel
     *     @type int $RevertTimeoutMinutes
     *           Time until reverting to default log level (Error), zero defaults to 1 day or 1440 minutes
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Log::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.LogConfig.LogLevelType LogLevel = 1;</code>
     * @return int
     */
    public function getLogLevel()
    {
        return $this->LogLevel;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.LogConfig.LogLevelType LogLevel = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setLogLevel($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\LogConfig\LogLevelType::class);
        $this->LogLevel = $var;

        return $this;
    }

    /**
     * Time until reverting to default log level (Error), zero defaults to 1 day or 1440 minutes
     *
     * Generated from protobuf field <code>uint32 RevertTimeoutMinutes = 2;</code>
     * @return int
     */
    public function getRevertTimeoutMinutes()
    {
        return $this->RevertTimeoutMinutes;
    }

    /**
     * Time until reverting to default log level (Error), zero defaults to 1 day or 1440 minutes
     *
     * Generated from protobuf field <code>uint32 RevertTimeoutMinutes = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setRevertTimeoutMinutes($var)
    {
        GPBUtil::checkUint32($var);
        $this->RevertTimeoutMinutes = $var;

        return $this;
    }

}

