<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: anpr.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.ANPREvent</code>
 */
class ANPREvent extends \Google\Protobuf\Internal\Message
{
    /**
     * The Unique Address of the ANPR camera like the MAC Address
     *
     * Generated from protobuf field <code>bytes CameraId = 1;</code>
     */
    protected $CameraId = '';
    /**
     * The Sequence Number, if available, from the ANPR camera
     *
     * Generated from protobuf field <code>uint32 Sequence = 2;</code>
     */
    protected $Sequence = 0;
    /**
     * The UTC Timestamp reported by the ANPR camera
     *
     * Generated from protobuf field <code>uint32 TimeStamp = 3;</code>
     */
    protected $TimeStamp = 0;
    /**
     * The direction of the number plate coming in
     *
     * Generated from protobuf field <code>.OS.PB.ANPRDirection Direction = 4;</code>
     */
    protected $Direction = 0;
    /**
     * The number plate reported by the camera
     *
     * Generated from protobuf field <code>string NumberPlate = 5;</code>
     */
    protected $NumberPlate = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type string $CameraId
     *           The Unique Address of the ANPR camera like the MAC Address
     *     @type int $Sequence
     *           The Sequence Number, if available, from the ANPR camera
     *     @type int $TimeStamp
     *           The UTC Timestamp reported by the ANPR camera
     *     @type int $Direction
     *           The direction of the number plate coming in
     *     @type string $NumberPlate
     *           The number plate reported by the camera
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Anpr::initOnce();
        parent::__construct($data);
    }

    /**
     * The Unique Address of the ANPR camera like the MAC Address
     *
     * Generated from protobuf field <code>bytes CameraId = 1;</code>
     * @return string
     */
    public function getCameraId()
    {
        return $this->CameraId;
    }

    /**
     * The Unique Address of the ANPR camera like the MAC Address
     *
     * Generated from protobuf field <code>bytes CameraId = 1;</code>
     * @param string $var
     * @return $this
     */
    public function setCameraId($var)
    {
        GPBUtil::checkString($var, False);
        $this->CameraId = $var;

        return $this;
    }

    /**
     * The Sequence Number, if available, from the ANPR camera
     *
     * Generated from protobuf field <code>uint32 Sequence = 2;</code>
     * @return int
     */
    public function getSequence()
    {
        return $this->Sequence;
    }

    /**
     * The Sequence Number, if available, from the ANPR camera
     *
     * Generated from protobuf field <code>uint32 Sequence = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setSequence($var)
    {
        GPBUtil::checkUint32($var);
        $this->Sequence = $var;

        return $this;
    }

    /**
     * The UTC Timestamp reported by the ANPR camera
     *
     * Generated from protobuf field <code>uint32 TimeStamp = 3;</code>
     * @return int
     */
    public function getTimeStamp()
    {
        return $this->TimeStamp;
    }

    /**
     * The UTC Timestamp reported by the ANPR camera
     *
     * Generated from protobuf field <code>uint32 TimeStamp = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setTimeStamp($var)
    {
        GPBUtil::checkUint32($var);
        $this->TimeStamp = $var;

        return $this;
    }

    /**
     * The direction of the number plate coming in
     *
     * Generated from protobuf field <code>.OS.PB.ANPRDirection Direction = 4;</code>
     * @return int
     */
    public function getDirection()
    {
        return $this->Direction;
    }

    /**
     * The direction of the number plate coming in
     *
     * Generated from protobuf field <code>.OS.PB.ANPRDirection Direction = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setDirection($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\ANPRDirection::class);
        $this->Direction = $var;

        return $this;
    }

    /**
     * The number plate reported by the camera
     *
     * Generated from protobuf field <code>string NumberPlate = 5;</code>
     * @return string
     */
    public function getNumberPlate()
    {
        return $this->NumberPlate;
    }

    /**
     * The number plate reported by the camera
     *
     * Generated from protobuf field <code>string NumberPlate = 5;</code>
     * @param string $var
     * @return $this
     */
    public function setNumberPlate($var)
    {
        GPBUtil::checkString($var, True);
        $this->NumberPlate = $var;

        return $this;
    }

}

