<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: types.proto

namespace GPBMetadata;

class Types
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xF1\x01\x0A\x0Btypes.proto\x12\x05OS.PB*D\x0A\x06Toggle\x12\x11\x0A\x0DToggle_NotSet\x10\x00\x12\x13\x0A\x0FToggle_Disabled\x10\x01\x12\x12\x0A\x0EToggle_Enabled\x10\x02*E\x0A\x05State\x12\x10\x0A\x0CState_NotSet\x10\x00\x12\x15\x0A\x11State_Deactivated\x10\x01\x12\x13\x0A\x0FState_Activated\x10\x02*B\x0A\x06Result\x12\x11\x0A\x0DResult_NotSet\x10\x00\x12\x11\x0A\x0DResult_Failed\x10\x01\x12\x12\x0A\x0EResult_Success\x10\x02B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

