<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: metric.proto

namespace GPBMetadata;

class Metric
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Ble::initOnce();
        \GPBMetadata\Input::initOnce();
        \GPBMetadata\Codehop::initOnce();
        \GPBMetadata\Wiegand::initOnce();
        \GPBMetadata\Access::initOnce();
        \GPBMetadata\Relay::initOnce();
        \GPBMetadata\Ethernet::initOnce();
        \GPBMetadata\Rs485::initOnce();
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Modem::initOnce();
        \GPBMetadata\Health::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\x9A\x05\x0A\x0Cmetric.proto\x12\x05OS.PB\x1A\x0Binput.proto\x1A\x0Dcodehop.proto\x1A\x0Dwiegand.proto\x1A\x0Caccess.proto\x1A\x0Brelay.proto\x1A\x0Eethernet.proto\x1A\x0Brs485.proto\x1A\x0Cdevice.proto\x1A\x0Bmodem.proto\x1A\x0Chealth.proto\"\xEA\x03\x0A\x0DMetricMessage\x12\x16\x0A\x0EInterfaceIndex\x18\x01 \x01(\x0D\x12#\x0A\x05Relay\x18\x03 \x01(\x0B2\x12.OS.PB.RelayMetricH\x00\x12'\x0A\x07Wiegand\x18\x04 \x01(\x0B2\x14.OS.PB.WiegandMetricH\x00\x12#\x0A\x05Input\x18\x05 \x01(\x0B2\x12.OS.PB.InputMetricH\x00\x12'\x0A\x07CodeHop\x18\x06 \x01(\x0B2\x14.OS.PB.CodeHopMetricH\x00\x12#\x0A\x05RS485\x18\x08 \x01(\x0B2\x12.OS.PB.RS485MetricH\x00\x12\x1F\x0A\x03BLE\x18\x09 \x01(\x0B2\x10.OS.PB.BLEMetricH\x00\x12)\x0A\x08Ethernet\x18\x0B \x01(\x0B2\x15.OS.PB.EthernetMetricH\x00\x12#\x0A\x05Modem\x18\x0C \x01(\x0B2\x12.OS.PB.ModemMetricH\x00\x12%\x0A\x06Access\x18\x0D \x01(\x0B2\x13.OS.PB.AccessMetricH\x00\x12%\x0A\x06Device\x18\x0F \x01(\x0B2\x13.OS.PB.DeviceMetricH\x00\x123\x0A\x0DDeviceNetwork\x18\x10 \x01(\x0B2\x1A.OS.PB.DeviceNetworkMetricH\x00B\x0C\x0A\x0AMetricTypeB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

