<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace GPBMetadata;

class Codehop
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xE8\x0A\x0A\x0Dcodehop.proto\x12\x05OS.PB\"0\x0A\x0DCodeHopAction\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x04\x12\x0F\x0A\x07Counter\x18\x03 \x01(\x0D\"\x90\x01\x0A\x0CCodeHopEvent\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x04\x12\x0F\x0A\x07Buttons\x18\x02 \x01(\x04\x12\x0F\x0A\x07Counter\x18\x03 \x01(\x0D\x12\x12\x0A\x0AVoltageLow\x18\x04 \x01(\x08\x12\x0C\x0A\x04RSSI\x18\x05 \x01(\x11\x12\x15\x0A\x0DButtonPresses\x18\x08 \x01(\x0D\x12\x15\x0A\x0DStoredCounter\x18\x0A \x01(\x0D\"\xCA\x01\x0A\x0DCodeHopMetric\x12\x15\x0A\x0DReceivedCount\x18\x01 \x01(\x0D\x12\x13\x0A\x0BRSSIIgnored\x18\x02 \x01(\x0D\x12\x16\x0A\x0ECounterBlocked\x18\x03 \x01(\x0D\x12\x14\x0A\x0CDecryptFails\x18\x04 \x01(\x0D\x12\x17\x0A\x0FCounterDeSynced\x18\x05 \x01(\x0D\x12\x17\x0A\x0FCounterReSynced\x18\x06 \x01(\x0D\x12\x14\x0A\x0CCounterValid\x18\x07 \x01(\x0D\x12\x17\x0A\x0FCounterNotFound\x18\x08 \x01(\x0D\"\xBD\x02\x0A\x0DCodeHopConfig\x12/\x0A\x04Mode\x18\x01 \x01(\x0E2!.OS.PB.CodeHopConfig.CodeHopModes\x12!\x0A\x0ASendEvents\x18\x02 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x13\x0A\x0BRSSIMinimum\x18\x05 \x01(\x11\"\xC2\x01\x0A\x0CCodeHopModes\x12\x16\x0A\x12CodeHopMode_NotSet\x10\x00\x12\x18\x0A\x14CodeHopMode_Disabled\x10\x01\x12\x16\x0A\x12CodeHopMode_Sherlo\x10\x02\x12\x19\x0A\x15CodeHopMode_Centurion\x10\x03\x12\x16\x0A\x12CodeHopMode_Sentry\x10\x04\x12\x19\x0A\x15CodeHopMode_ETSystems\x10\x05\x12\x1A\x0A\x16CodeHopMode_NiceForYou\x10\x06\"\x82\x01\x0A\x0ECodeHopRequest\x12\x13\x0A\x0BStopOnFirst\x18\x01 \x01(\x08\x12\x15\x0A\x0DButtonPresses\x18\x02 \x01(\x0D\x12\x15\x0A\x0DButtonsFilter\x18\x03 \x01(\x04\x12\x13\x0A\x0BRSSIMinimum\x18\x05 \x01(\x11\x12\x18\x0A\x10SendEnrollEvents\x18\x08 \x01(\x08\"\x90\x02\x0A\x0FCodeHopResponse\x12=\x0A\x08Response\x18\x01 \x01(\x0E2+.OS.PB.CodeHopResponse.CodeHopResponseTypes\x12\x0E\x0A\x06Serial\x18\x02 \x01(\x04\x12\x15\x0A\x0DButtonPresses\x18\x03 \x01(\x0D\x12\x0C\x0A\x04RSSI\x18\x05 \x01(\x11\"\x88\x01\x0A\x14CodeHopResponseTypes\x12\x1A\x0A\x16CodeHopResponse_NotSet\x10\x00\x12\x1B\x0A\x17CodeHopResponse_Success\x10\x01\x12\x1B\x0A\x17CodeHopResponse_Unclear\x10\x02\x12\x1A\x0A\x16CodeHopResponse_Failed\x10\x03*\xD9\x01\x0A\x11CodeHopButtonMask\x12\x18\x0A\x14CodeHopButton_NotSet\x10\x00\x12\x15\x0A\x11CodeHopButton_Red\x10\x01\x12\x17\x0A\x13CodeHopButton_White\x10\x02\x12\x16\x0A\x12CodeHopButton_Blue\x10\x04\x12\x17\x0A\x13CodeHopButton_Green\x10\x08\x12\x17\x0A\x13CodeHopButton_Black\x10\x10\x12\x18\x0A\x14CodeHopButton_Yellow\x10 \x12\x16\x0A\x12CodeHopButton_Grey\x10@B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

