<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: filesystem.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.ListResult</code>
 */
class ListResult extends \Google\Protobuf\Internal\Message
{
    /**
     * Path of entry, applies to both files and directories
     *
     * Generated from protobuf field <code>string Path = 1;</code>
     */
    protected $Path = '';
    /**
     * If the Path is a directory, this will be True
     *
     * Generated from protobuf field <code>bool IsDirectory = 2;</code>
     */
    protected $IsDirectory = false;
    /**
     * If IsDirectory is False, then file size is returned here
     *
     * Generated from protobuf field <code>uint32 FileSize = 3;</code>
     */
    protected $FileSize = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type string $Path
     *           Path of entry, applies to both files and directories
     *     @type bool $IsDirectory
     *           If the Path is a directory, this will be True
     *     @type int $FileSize
     *           If IsDirectory is False, then file size is returned here
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Filesystem::initOnce();
        parent::__construct($data);
    }

    /**
     * Path of entry, applies to both files and directories
     *
     * Generated from protobuf field <code>string Path = 1;</code>
     * @return string
     */
    public function getPath()
    {
        return $this->Path;
    }

    /**
     * Path of entry, applies to both files and directories
     *
     * Generated from protobuf field <code>string Path = 1;</code>
     * @param string $var
     * @return $this
     */
    public function setPath($var)
    {
        GPBUtil::checkString($var, True);
        $this->Path = $var;

        return $this;
    }

    /**
     * If the Path is a directory, this will be True
     *
     * Generated from protobuf field <code>bool IsDirectory = 2;</code>
     * @return bool
     */
    public function getIsDirectory()
    {
        return $this->IsDirectory;
    }

    /**
     * If the Path is a directory, this will be True
     *
     * Generated from protobuf field <code>bool IsDirectory = 2;</code>
     * @param bool $var
     * @return $this
     */
    public function setIsDirectory($var)
    {
        GPBUtil::checkBool($var);
        $this->IsDirectory = $var;

        return $this;
    }

    /**
     * If IsDirectory is False, then file size is returned here
     *
     * Generated from protobuf field <code>uint32 FileSize = 3;</code>
     * @return int
     */
    public function getFileSize()
    {
        return $this->FileSize;
    }

    /**
     * If IsDirectory is False, then file size is returned here
     *
     * Generated from protobuf field <code>uint32 FileSize = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setFileSize($var)
    {
        GPBUtil::checkUint32($var);
        $this->FileSize = $var;

        return $this;
    }

}

