<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: osdp.proto

namespace GPBMetadata;

class Osdp
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xB9\x08\x0A\x0Aosdp.proto\x12\x05OS.PB\"\xF1\x01\x0A\x0AOSDPAction\x12\x0F\x0A\x07Address\x18\x02 \x01(\x0D\x12\x12\x0A\x0ADurationDs\x18\x03 \x01(\x0D\x12\x0E\x0A\x06ItemNo\x18\x04 \x01(\x0D\x12\$\x0A\x07OnColor\x18\x05 \x01(\x0E2\x13.OS.PB.OSDPLEDColor\x12\x14\x0A\x0COnDurationDs\x18\x06 \x01(\x0D\x12%\x0A\x08OffColor\x18\x07 \x01(\x0E2\x13.OS.PB.OSDPLEDColor\x12\x15\x0A\x0DOffDurationDs\x18\x08 \x01(\x0D\x12\x0C\x0A\x04Text\x18\x09 \x01(\x09\x12\x13\x0A\x0BRepetitions\x18\x0A \x01(\x0D\x12\x11\x0A\x09Permanent\x18\x0B \x01(\x08\"\xBC\x02\x0A\x09OSDPEvent\x12\x0F\x0A\x07Address\x18\x02 \x01(\x0D\x12\x10\x0A\x08ReaderNo\x18\x04 \x01(\x0D\x121\x0A\x0FReaderDirection\x18\x05 \x01(\x0E2\x18.OS.PB.OSDPDirectionType\x12\x13\x0A\x0BWiegandBits\x18\x06 \x01(\x0D\x12\x15\x0A\x0BUnspecified\x18\x08 \x01(\x0CH\x00\x12\x11\x0A\x07Wiegand\x18\x09 \x01(\x0CH\x00\x12\x0F\x0A\x05Ascii\x18\x0A \x01(\x09H\x00\x12\x11\x0A\x07PinCode\x18\x0B \x01(\x04H\x00\x12\x12\x0A\x0AVendorCode\x18\x14 \x01(\x0D\x12\x13\x0A\x0BModelNumber\x18\x15 \x01(\x0D\x12\x14\x0A\x0CModelVersion\x18\x16 \x01(\x0D\x12\x14\x0A\x0CSerialNumber\x18\x17 \x01(\x0D\x12\x17\x0A\x0FFirmwareVersion\x18\x18 \x01(\x0DB\x08\x0A\x06Format\"\x93\x02\x0A\x0AOSDPConfig\x12\x11\x0A\x09Addresses\x18\x01 \x03(\x0D\x12\x16\x0A\x0EOfflineTimeout\x18\x02 \x01(\x0D\x121\x0A\x0AKeypadMode\x18\x08 \x01(\x0E2\x1D.OS.PB.OSDPConfig.KeypadModes\x12\x14\x0A\x0CKeypadDigits\x18\x09 \x01(\x0D\x12\x1A\x0A\x12KeypadResetTimeout\x18\x0A \x01(\x0D\"u\x0A\x0BKeypadModes\x12\x15\x0A\x11KeypadMode_NotSet\x10\x00\x12\x17\x0A\x13KeypadMode_Disabled\x10\x01\x12\x16\x0A\x12KeypadMode_Enabled\x10\x02\x12\x1E\x0A\x1AKeypadMode_Enabled_AutoEnd\x10\x03*i\x0A\x0COSDPLEDColor\x12\x10\x0A\x0COSDPLED_None\x10\x00\x12\x0F\x0A\x0BOSDPLED_Red\x10\x01\x12\x11\x0A\x0DOSDPLED_Green\x10\x02\x12\x11\x0A\x0DOSDPLED_Amber\x10\x03\x12\x10\x0A\x0COSDPLED_Blue\x10\x04*d\x0A\x11OSDPDirectionType\x12\x18\x0A\x14OSDPDirection_NotSet\x10\x00\x12\x19\x0A\x15OSDPDirection_Forward\x10\x01\x12\x1A\x0A\x16OSDPDirection_Backward\x10\x02B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

