<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace OS\PB;

use UnexpectedValueException;

/**
 * https://www.iotforall.com/bluetooth-low-energy-central-vs-peripheral
 *
 * Protobuf type <code>OS.PB.BLERoleType</code>
 */
class BLERoleType
{
    /**
     * Generated from protobuf enum <code>BLERole_Peripheral = 0;</code>
     */
    const BLERole_Peripheral = 0;
    /**
     * Generated from protobuf enum <code>BLERole_Central = 1;</code>
     */
    const BLERole_Central = 1;

    private static $valueToName = [
        self::BLERole_Peripheral => 'BLERole_Peripheral',
        self::BLERole_Central => 'BLERole_Central',
    ];

    public static function name($value)
    {
        if (!isset(self::$valueToName[$value])) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no name defined for value %s', __CLASS__, $value));
        }
        return self::$valueToName[$value];
    }


    public static function value($name)
    {
        $const = __CLASS__ . '::' . strtoupper($name);
        if (!defined($const)) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no value defined for name %s', __CLASS__, $name));
        }
        return constant($const);
    }
}

