<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ethernet.proto

namespace GPBMetadata;

class Ethernet
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xCA\x04\x0A\x0Eethernet.proto\x12\x05OS.PB\"s\x0A\x0EEthernetConfig\x12\x14\x0A\x0CMDNSHostName\x18\x01 \x01(\x09\x12\x14\x0A\x0CMCastAddress\x18\x02 \x01(\x09\x125\x0A\x11OneSpace_Protobuf\x18\x06 \x01(\x0B2\x1A.OS.PB.DeviceNetworkConfig\"!\x0A\x0FEthernetRequest\x12\x0E\x0A\x06Config\x18\x01 \x01(\x08\"\xD1\x01\x0A\x10EthernetResponse\x12%\x0A\x06Config\x18\x01 \x01(\x0B2\x15.OS.PB.EthernetConfig\x12\x12\x0A\x0AMACAddress\x18\x03 \x01(\x0C\x12\x18\x0A\x10LocalIPv4Address\x18\x05 \x01(\x0C\x12\x17\x0A\x0FLocalSubnetMask\x18\x06 \x01(\x0C\x12\x18\x0A\x10LocalIPv6Address\x18\x07 \x01(\x0C\x12\x18\x0A\x10GatewayIPAddress\x18\x0A \x01(\x0C\x12\x1B\x0A\x13DHCPServerIPAddress\x18\x0B \x01(\x0C\"\xB8\x01\x0A\x0EEthernetMetric\x12\x18\x0A\x10BytesTransmitted\x18\x01 \x01(\x0D\x12\x15\x0A\x0DBytesReceived\x18\x02 \x01(\x0D\x12\x1E\x0A\x16BytesReceivedExclusive\x18\x03 \x01(\x0D\x12\x1A\x0A\x12PacketsTransmitted\x18\x07 \x01(\x0D\x12\x17\x0A\x0FPacketsReceived\x18\x08 \x01(\x0D\x12 \x0A\x18PacketsReceivedExclusive\x18\x09 \x01(\x0DB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

