<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: access.proto

namespace GPBMetadata;

class Access
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\x87!\x0A\x0Caccess.proto\x12\x05OS.PB\x1A\x0Btypes.proto\"\xE7\x01\x0A\x12AccessMethodConfig\x12\x11\x0A\x07CardTag\x18\x02 \x01(\x04H\x00\x12\x0F\x0A\x05Phone\x18\x03 \x01(\x04H\x00\x12\x11\x0A\x07CodeHop\x18\x04 \x01(\x04H\x00\x12\x12\x0A\x08Intercom\x18\x05 \x01(\x04H\x00\x12\x13\x0A\x09Biometric\x18\x07 \x01(\x04H\x00\x12\x15\x0A\x0BNumberPlate\x18\x09 \x01(\x09H\x00\x12\x11\x0A\x07PinCode\x18\x0A \x01(\x04H\x00\x12\x0E\x0A\x06UserId\x18\x0E \x01(\x04\x12\x11\x0A\x09RightsIds\x18\x0F \x03(\x04\x12\x16\x0A\x0EDaysOfWeekBits\x18\x10 \x01(\x04B\x0C\x0A\x0AMethodType\"\xBF\x01\x0A\x10AccessUserConfig\x12\x0A\x0A\x02Id\x18\x01 \x01(\x04\x12\x1C\x0A\x14FirstExitsThenEnters\x18\x05 \x01(\x08\x12\x1D\x0A\x15RollOverExitToNextDay\x18\x06 \x01(\x08\x12\x11\x0A\x09EntryUses\x18\x0A \x01(\x11\x12\x10\x0A\x08ExitUses\x18\x0B \x01(\x11\x12\x15\x0A\x0DStartDateTime\x18\x0D \x01(\x03\x12\x13\x0A\x0BEndDateTime\x18\x0E \x01(\x03\x12\x11\x0A\x09RightsIds\x18\x0F \x03(\x04\"c\x0A\x12AccessRightsConfig\x12\x0A\x0A\x02Id\x18\x01 \x01(\x04\x12\x16\x0A\x0EDaysOfWeekBits\x18\x02 \x01(\x0D\x12\x16\x0A\x0ETimesOfDayBits\x18\x03 \x01(\x04\x12\x11\x0A\x09ReaderIds\x18\x08 \x03(\x04\"\xBD\x02\x0A\x0CAccessReader\x12\x0A\x0A\x02Id\x18\x01 \x01(\x04\x12)\x0A\x09Interface\x18\x02 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceIndex\x18\x03 \x01(\x0D\x12-\x0A\x09Direction\x18\x04 \x01(\x0E2\x1A.OS.PB.AccessDirectionType\x12 \x0A\x09Perimeter\x18\x05 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x15\x0A\x0BOSDPAddress\x18\x0A \x01(\x0DH\x00\x12\x16\x0A\x0CANPRCameraId\x18\x0B \x01(\x0CH\x00\x12\x18\x0A\x0ECodeHopButtons\x18\x0C \x01(\x0DH\x00\x12\x16\x0A\x0EDaysOfWeekBits\x18\x10 \x01(\x04\x12\x16\x0A\x0ETimesOfDayBits\x18\x11 \x01(\x04B\x14\x0A\x12InterfaceFiltering\"\xB4\x03\x0A\x0BAccessEvent\x12#\x0A\x06Reader\x18\x01 \x01(\x0B2\x13.OS.PB.AccessReader\x12\x10\x0A\x08ReaderId\x18\x02 \x01(\x04\x123\x0A\x0FReaderDirection\x18\x03 \x01(\x0E2\x1A.OS.PB.AccessDirectionType\x12)\x0A\x06Method\x18\x04 \x01(\x0B2\x19.OS.PB.AccessMethodConfig\x12%\x0A\x04User\x18\x05 \x01(\x0B2\x17.OS.PB.AccessUserConfig\x12\x0E\x0A\x06UserId\x18\x06 \x01(\x04\x12)\x0A\x06Rights\x18\x07 \x01(\x0B2\x19.OS.PB.AccessRightsConfig\x12\x10\x0A\x08RightsId\x18\x08 \x01(\x04\x12\x17\x0A\x0FEntriesRedeemed\x18\x0A \x01(\x0D\x12\x15\x0A\x0DExitsRedeemed\x18\x0B \x01(\x0D\x12.\x0A\x0DButtonPressed\x18\x0C \x01(\x0E2\x17.OS.PB.AccessButtonType\x12\x10\x0A\x08Progress\x18\x0D \x01(\x0D\x12\x13\x0A\x0BTimeTakenMs\x18\x0F \x01(\x0D\x12\x13\x0A\x0BInvalidData\x18\x10 \x01(\x0C\"j\x0A\x13AccessDatabaseEvent\x12\x14\x0A\x0CReadersTotal\x18\x01 \x01(\x0D\x12\x14\x0A\x0CMethodsTotal\x18\x02 \x01(\x0D\x12\x13\x0A\x0BRightsTotal\x18\x03 \x01(\x0D\x12\x12\x0A\x0AUsersTotal\x18\x04 \x01(\x0D\"\xEC\x02\x0A\x0DAccessRequest\x126\x0A\x05Flags\x18\x07 \x01(\x0E2'.OS.PB.AccessRequest.AccessRequestFlags\x12#\x0A\x06Reader\x18\x01 \x01(\x0B2\x13.OS.PB.AccessReader\x12)\x0A\x06Method\x18\x04 \x01(\x0B2\x19.OS.PB.AccessMethodConfig\x12\x15\x0A\x0DLocalDateTime\x18\x05 \x01(\x03\x12\x10\x0A\x08Expected\x18\x0A \x01(\x0D\x12\x0F\x0A\x07Timeout\x18\x0B \x01(\x0D\"\x98\x01\x0A\x12AccessRequestFlags\x12\x1D\x0A\x19AccessRequestFlags_NotSet\x10\x00\x12\x1B\x0A\x17AccessEnrol_StopOnFirst\x10\x01\x12\x1C\x0A\x18AccessEnrol_SendProgress\x10\x02\x12(\x0A\$AccessEnrol_StopOnFirst_SendProgress\x10\x03\"\xB0\x01\x0A\x0EAccessResponse\x12\x1D\x0A\x06Result\x18\x07 \x01(\x0E2\x0D.OS.PB.Result\x12\x0F\x0A\x07Message\x18\x05 \x01(\x09\x12!\x0A\x05Event\x18\x01 \x01(\x0B2\x12.OS.PB.AccessEvent\x12 \x0A\x18DEPRECATEDRelayActivated\x18\x02 \x01(\x08\x12)\x0A\x06Method\x18\x0A \x01(\x0B2\x19.OS.PB.AccessMethodConfig\"\x8B\x01\x0A\x0CAccessAction\x12\x0E\x0A\x06UserId\x18\x01 \x01(\x04\x12\x17\x0A\x0FEntriesRedeemed\x18\x02 \x01(\x0D\x12\x15\x0A\x0DExitsRedeemed\x18\x03 \x01(\x0D\x12&\x0A\x0FOverrideControl\x18\x05 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x13\x0A\x0BEndDateTime\x18\x06 \x01(\x03\"r\x0A\x11AccessEraseAction\x12\x0F\x0A\x07Gateway\x18\x01 \x01(\x08\x12\x12\x0A\x0AAllMethods\x18\x02 \x01(\x08\x12\x10\x0A\x08AllUsers\x18\x03 \x01(\x08\x12\x11\x0A\x09AllRights\x18\x04 \x01(\x08\x12\x13\x0A\x0BRedemptions\x18\x05 \x01(\x08\"\xA4\x01\x0A\x17AccessConfirmationInput\x12)\x0A\x09Interface\x18\x02 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceIndex\x18\x03 \x01(\x0D\x12\x18\x0A\x0ELogicalAddress\x18\x0A \x01(\x0DH\x00\x12\x16\x0A\x0CANPRCameraId\x18\x0B \x01(\x0CH\x00B\x14\x0A\x12InterfaceFiltering\"\xE3\x02\x0A\x0CAccessConfig\x12\x1C\x0A\x05State\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x129\x0A\x11ConfirmationInput\x18\x03 \x01(\x0B2\x1E.OS.PB.AccessConfirmationInput\x12\$\x0A\x0DVerboseEvents\x18\x04 \x01(\x0E2\x0D.OS.PB.Toggle\x12\$\x0A\x07Readers\x18\x05 \x03(\x0B2\x13.OS.PB.AccessReader\x12*\x0A\x13CodeHopUnknownEvent\x18\x06 \x01(\x0E2\x0D.OS.PB.Toggle\x12\x15\x0A\x0DIntercomStart\x18\x08 \x01(\x04\x12\x13\x0A\x0BIntercomEnd\x18\x09 \x01(\x04\x12\x16\x0A\x0EBiometricStart\x18\x0A \x01(\x04\x12\x14\x0A\x0CBiometricEnd\x18\x0B \x01(\x04\x12\x14\x0A\x0CPinCodeStart\x18\x0C \x01(\x04\x12\x12\x0A\x0APinCodeEnd\x18\x0D \x01(\x04\"\xF5\x02\x0A\x0CAccessMetric\x12\x1B\x0A\x13ControlTimeTakenMin\x18\x02 \x01(\x0D\x12\x1B\x0A\x13ControlTimeTakenMax\x18\x03 \x01(\x0D\x12\x14\x0A\x0CMethodsTotal\x18\x05 \x01(\x0D\x12\x1B\x0A\x13MethodSelectTimeMax\x18\x06 \x01(\x0D\x12\x1B\x0A\x13MethodAppendTimeMax\x18\x07 \x01(\x0D\x12\x13\x0A\x0BRightsTotal\x18\x08 \x01(\x0D\x12\x1B\x0A\x13RightsSelectTimeMax\x18\x09 \x01(\x0D\x12\x1B\x0A\x13RightsAppendTimeMax\x18\x0A \x01(\x0D\x12\x12\x0A\x0AUsersTotal\x18\x0B \x01(\x0D\x12\x1A\x0A\x12UsersSelectTimeMax\x18\x0C \x01(\x0D\x12\x1A\x0A\x12UsersAppendTimeMax\x18\x0D \x01(\x0D\x12\x1F\x0A\x17UserRedeemSelectTimeMax\x18\x0E \x01(\x0D\x12\x1F\x0A\x17UserRedeemAppendTimeMax\x18\x0F \x01(\x0D*\xA7\x02\x0A\x14AccessDaysOfWeekBits\x12\x1C\x0A\x18AccessDaysOfWeek_AllDays\x10\x00\x12\x1B\x0A\x17AccessDaysOfWeek_Monday\x10\x01\x12\x1C\x0A\x18AccessDaysOfWeek_Tuesday\x10\x02\x12\x1E\x0A\x1AAccessDaysOfWeek_Wednesday\x10\x04\x12\x1D\x0A\x19AccessDaysOfWeek_Thursday\x10\x08\x12\x1B\x0A\x17AccessDaysOfWeek_Friday\x10\x10\x12\x1D\x0A\x19AccessDaysOfWeek_Saturday\x10 \x12\x1B\x0A\x17AccessDaysOfWeek_Sunday\x10@\x12\x1E\x0A\x19AccessDaysOfWeek_Holidays\x10\x80\x01*4\x0A\x14AccessTimesOfDayBits\x12\x1C\x0A\x18AccessTimesOfDay_AnyTime\x10\x00*\x80\x01\x0A\x13AccessDirectionType\x12\x1A\x0A\x16AccessDirection_NotSet\x10\x00\x12\x19\x0A\x15AccessDirection_Entry\x10\x01\x12\x18\x0A\x14AccessDirection_Exit\x10\x02\x12\x18\x0A\x14AccessDirection_Both\x10\x03*\xD1\x01\x0A\x10AccessMethodType\x12\x1D\x0A\x19AccessMethod_UnknownOrAny\x10\x00\x12\x18\x0A\x14AccessMethod_CardTag\x10\x02\x12\x16\x0A\x12AccessMethod_Phone\x10\x03\x12\x18\x0A\x14AccessMethod_CodeHop\x10\x04\x12\x1A\x0A\x16AccessMethod_Biometric\x10\x07\x12\x1C\x0A\x18AccessMethod_NumberPlate\x10\x09\x12\x18\x0A\x14AccessMethod_PinCode\x10\x0A*\xD0\x01\x0A\x10AccessButtonType\x12\x17\x0A\x13AccessButton_NotSet\x10\x00\x12\x14\x0A\x10AccessButton_Red\x10\x01\x12\x16\x0A\x12AccessButton_White\x10\x02\x12\x15\x0A\x11AccessButton_Blue\x10\x04\x12\x16\x0A\x12AccessButton_Green\x10\x08\x12\x16\x0A\x12AccessButton_Black\x10\x10\x12\x17\x0A\x13AccessButton_Yellow\x10 \x12\x15\x0A\x11AccessButton_Grey\x10@*-\x0A\x0FAccessMethodUID\x12\x1A\x0A\x16AccessMethodUID_NotSet\x10\x00*'\x0A\x0CAccessUserId\x12\x17\x0A\x13AccessUserId_NotSet\x10\x00*+\x0A\x0EAccessRightsId\x12\x19\x0A\x15AccessRightsId_NotSet\x10\x00*+\x0A\x0EAccessReaderId\x12\x19\x0A\x15AccessReaderId_NotSet\x10\x00B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

