<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: codehop.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.CodeHopAction</code>
 */
class CodeHopAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>uint64 Serial = 1;</code>
     */
    protected $Serial = 0;
    /**
     * Sets the counter value expected for a CodeHop remote, setting 0 removes the remote from the CodeHop database
     *
     * Generated from protobuf field <code>uint32 Counter = 3;</code>
     */
    protected $Counter = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $Serial
     *     @type int $Counter
     *           Sets the counter value expected for a CodeHop remote, setting 0 removes the remote from the CodeHop database
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Codehop::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>uint64 Serial = 1;</code>
     * @return int|string
     */
    public function getSerial()
    {
        return $this->Serial;
    }

    /**
     * Generated from protobuf field <code>uint64 Serial = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setSerial($var)
    {
        GPBUtil::checkUint64($var);
        $this->Serial = $var;

        return $this;
    }

    /**
     * Sets the counter value expected for a CodeHop remote, setting 0 removes the remote from the CodeHop database
     *
     * Generated from protobuf field <code>uint32 Counter = 3;</code>
     * @return int
     */
    public function getCounter()
    {
        return $this->Counter;
    }

    /**
     * Sets the counter value expected for a CodeHop remote, setting 0 removes the remote from the CodeHop database
     *
     * Generated from protobuf field <code>uint32 Counter = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setCounter($var)
    {
        GPBUtil::checkUint32($var);
        $this->Counter = $var;

        return $this;
    }

}

