<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: modem.proto

namespace GPBMetadata;

class Modem
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xFE\x0D\x0A\x0Bmodem.proto\x12\x05OS.PB\"D\x0A\x0BModemConfig\x125\x0A\x11OneSpace_Protobuf\x18\x06 \x01(\x0B2\x1A.OS.PB.DeviceNetworkConfig\"\x8E\x01\x0A\x0AModemEvent\x12\$\x0A\x07SIMSlot\x18\x05 \x01(\x0E2\x13.OS.PB.ModemSIMSlot\x12\x0D\x0A\x05ICCID\x18\x06 \x01(\x09\x12\x0C\x0A\x04IMSI\x18\x07 \x01(\x09\x12\x0E\x0A\x06MCCMNC\x18\x08 \x01(\x0D\x12\x0B\x0A\x03LAC\x18\x09 \x01(\x0D\x12\x0E\x0A\x06CellId\x18\x0A \x01(\x0D\x12\x10\x0A\x08Operator\x18\x0B \x01(\x09\"\x1E\x0A\x0CModemRequest\x12\x0E\x0A\x06Config\x18\x01 \x01(\x08\"\xFE\x0A\x0A\x0DModemResponse\x12\"\x0A\x06Config\x18\x01 \x01(\x0B2\x12.OS.PB.ModemConfig\x12\x14\x0A\x0CManufacturer\x18\x02 \x01(\x09\x12\x0D\x0A\x05Model\x18\x03 \x01(\x09\x12\x10\x0A\x08Revision\x18\x04 \x01(\x09\x12\x0C\x0A\x04IMEI\x18\x05 \x01(\x09\x12\x14\x0A\x0CSerialNumber\x18\x06 \x01(\x09\x12,\x0A\x0FSelectedSIMSlot\x18\x0A \x01(\x0E2\x13.OS.PB.ModemSIMSlot\x12\x11\x0A\x09SIM1_IMSI\x18\x0B \x01(\x09\x12\x12\x0A\x0ASIM1_ICCID\x18\x0C \x01(\x09\x12\x1D\x0A\x15SIM1_SubscriberNumber\x18\x0D \x01(\x09\x12\x11\x0A\x09SIM2_IMSI\x18\x0E \x01(\x09\x12\x12\x0A\x0ASIM2_ICCID\x18\x0F \x01(\x09\x12\x1D\x0A\x15SIM2_SubscriberNumber\x18\x10 \x01(\x09\x12B\x0A\x0DNetworkStatus\x18\x14 \x01(\x0E2+.OS.PB.ModemResponse.ModemNetworkStatusType\x12B\x0A\x0DNetworkAccess\x18\x15 \x01(\x0E2+.OS.PB.ModemResponse.ModemNetworkAccessType\x12\x0E\x0A\x06CellId\x18\x16 \x01(\x0D\x12\x18\x0A\x10LocationAreaCode\x18\x17 \x01(\x0D\x12\x0C\x0A\x04RSSI\x18\x18 \x01(\x11\"\x94\x04\x0A\x16ModemNetworkStatusType\x12\x1D\x0A\x19ModemNetworkStatus_NotSet\x10\x00\x12)\x0A%ModemNetworkStatus_NoReg_notSearching\x10\x01\x12&\x0A\"ModemNetworkStatus_Registered_home\x10\x02\x12&\x0A\"ModemNetworkStatus_NoReg_searching\x10\x03\x12#\x0A\x1FModemNetworkStatus_NoReg_denied\x10\x04\x12\x1E\x0A\x1AModemNetworkStatus_Unknown\x10\x05\x12&\x0A\"ModemNetworkStatus_Registered_Roam\x10\x06\x12-\x0A)ModemNetworkStatus_Registered_HomeSmsOnly\x10\x07\x12-\x0A)ModemNetworkStatus_Registered_RoamSmsOnly\x10\x08\x12/\x0A+ModemNetworkStatus_Registered_EmergencyOnly\x10\x09\x121\x0A-ModemNetworkStatus_Registered_HomeCSFBNotPref\x10\x0A\x121\x0A-ModemNetworkStatus_Registered_RoamCSFBNotPref\x10\x0B\"\xDC\x02\x0A\x16ModemNetworkAccessType\x12\x1D\x0A\x19ModemNetworkAccess_NotSet\x10\x00\x12\x1A\x0A\x16ModemNetworkAccess_GSM\x10\x01\x12!\x0A\x1DModemNetworkAccess_GSMCompact\x10\x02\x12\x1C\x0A\x18ModemNetworkAccess_UTRAN\x10\x03\x12&\x0A\"ModemNetworkAccess_Modem_withEGPRS\x10\x04\x12&\x0A\"ModemNetworkAccess_UTRAN_withHSDPA\x10\x05\x12&\x0A\"ModemNetworkAccess_UTRAN_withHSUPA\x10\x06\x12.\x0A*ModemNetworkAccess_UTRAN_withHSDPAandHSUPA\x10\x07\x12\x1E\x0A\x1AModemNetworkAccess_E_UTRAN\x10\x08\"\x0D\x0A\x0BModemMetric*U\x0A\x0CModemSIMSlot\x12\x17\x0A\x13ModemSIMSlot_NotSet\x10\x00\x12\x15\x0A\x11ModemSIMSlot_SIM1\x10\x01\x12\x15\x0A\x11ModemSIMSlot_SIM2\x10\x02B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

