<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: access.proto

namespace OS\PB;

use UnexpectedValueException;

/**
 * \@brief   Decides the direction of this Access Gateway
 *
 * Protobuf type <code>OS.PB.AccessDirectionType</code>
 */
class AccessDirectionType
{
    /**
     * Generated from protobuf enum <code>AccessDirection_NotSet = 0;</code>
     */
    const AccessDirection_NotSet = 0;
    /**
     * Generated from protobuf enum <code>AccessDirection_Entry = 1;</code>
     */
    const AccessDirection_Entry = 1;
    /**
     * Generated from protobuf enum <code>AccessDirection_Exit = 2;</code>
     */
    const AccessDirection_Exit = 2;
    /**
     * Generated from protobuf enum <code>AccessDirection_Both = 3;</code>
     */
    const AccessDirection_Both = 3;

    private static $valueToName = [
        self::AccessDirection_NotSet => 'AccessDirection_NotSet',
        self::AccessDirection_Entry => 'AccessDirection_Entry',
        self::AccessDirection_Exit => 'AccessDirection_Exit',
        self::AccessDirection_Both => 'AccessDirection_Both',
    ];

    public static function name($value)
    {
        if (!isset(self::$valueToName[$value])) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no name defined for value %s', __CLASS__, $value));
        }
        return self::$valueToName[$value];
    }


    public static function value($name)
    {
        $const = __CLASS__ . '::' . strtoupper($name);
        if (!defined($const)) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no value defined for name %s', __CLASS__, $name));
        }
        return constant($const);
    }
}

