<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceMetric</code>
 */
class DeviceMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * General Metrics
     *
     * Generated from protobuf field <code>uint32 UpTime = 1;</code>
     */
    protected $UpTime = 0;
    /**
     * The amount of free space available on /lfs1
     *
     * Generated from protobuf field <code>uint32 InternalFreeSpace = 2;</code>
     */
    protected $InternalFreeSpace = 0;
    /**
     * Current Device Status
     *
     * Generated from protobuf field <code>.OS.PB.DeviceStatus Status = 3;</code>
     */
    protected $Status = 0;
    /**
     * Device Logging Stats
     *
     * Generated from protobuf field <code>uint32 ErrorsCount = 12;</code>
     */
    protected $ErrorsCount = 0;
    /**
     * Number of times a warnings log has appeared
     *
     * Generated from protobuf field <code>uint32 WarningsCount = 13;</code>
     */
    protected $WarningsCount = 0;
    /**
     * Number of times an info log has appeared
     *
     * Generated from protobuf field <code>uint32 InfoCount = 14;</code>
     */
    protected $InfoCount = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $UpTime
     *           General Metrics
     *     @type int $InternalFreeSpace
     *           The amount of free space available on /lfs1
     *     @type int $Status
     *           Current Device Status
     *     @type int $ErrorsCount
     *           Device Logging Stats
     *     @type int $WarningsCount
     *           Number of times a warnings log has appeared
     *     @type int $InfoCount
     *           Number of times an info log has appeared
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * General Metrics
     *
     * Generated from protobuf field <code>uint32 UpTime = 1;</code>
     * @return int
     */
    public function getUpTime()
    {
        return $this->UpTime;
    }

    /**
     * General Metrics
     *
     * Generated from protobuf field <code>uint32 UpTime = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setUpTime($var)
    {
        GPBUtil::checkUint32($var);
        $this->UpTime = $var;

        return $this;
    }

    /**
     * The amount of free space available on /lfs1
     *
     * Generated from protobuf field <code>uint32 InternalFreeSpace = 2;</code>
     * @return int
     */
    public function getInternalFreeSpace()
    {
        return $this->InternalFreeSpace;
    }

    /**
     * The amount of free space available on /lfs1
     *
     * Generated from protobuf field <code>uint32 InternalFreeSpace = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setInternalFreeSpace($var)
    {
        GPBUtil::checkUint32($var);
        $this->InternalFreeSpace = $var;

        return $this;
    }

    /**
     * Current Device Status
     *
     * Generated from protobuf field <code>.OS.PB.DeviceStatus Status = 3;</code>
     * @return int
     */
    public function getStatus()
    {
        return $this->Status;
    }

    /**
     * Current Device Status
     *
     * Generated from protobuf field <code>.OS.PB.DeviceStatus Status = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setStatus($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceStatus::class);
        $this->Status = $var;

        return $this;
    }

    /**
     * Device Logging Stats
     *
     * Generated from protobuf field <code>uint32 ErrorsCount = 12;</code>
     * @return int
     */
    public function getErrorsCount()
    {
        return $this->ErrorsCount;
    }

    /**
     * Device Logging Stats
     *
     * Generated from protobuf field <code>uint32 ErrorsCount = 12;</code>
     * @param int $var
     * @return $this
     */
    public function setErrorsCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->ErrorsCount = $var;

        return $this;
    }

    /**
     * Number of times a warnings log has appeared
     *
     * Generated from protobuf field <code>uint32 WarningsCount = 13;</code>
     * @return int
     */
    public function getWarningsCount()
    {
        return $this->WarningsCount;
    }

    /**
     * Number of times a warnings log has appeared
     *
     * Generated from protobuf field <code>uint32 WarningsCount = 13;</code>
     * @param int $var
     * @return $this
     */
    public function setWarningsCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->WarningsCount = $var;

        return $this;
    }

    /**
     * Number of times an info log has appeared
     *
     * Generated from protobuf field <code>uint32 InfoCount = 14;</code>
     * @return int
     */
    public function getInfoCount()
    {
        return $this->InfoCount;
    }

    /**
     * Number of times an info log has appeared
     *
     * Generated from protobuf field <code>uint32 InfoCount = 14;</code>
     * @param int $var
     * @return $this
     */
    public function setInfoCount($var)
    {
        GPBUtil::checkUint32($var);
        $this->InfoCount = $var;

        return $this;
    }

}

