<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.DeviceNetworkMetric</code>
 */
class DeviceNetworkMetric extends \Google\Protobuf\Internal\Message
{
    /**
     * Routing and their Connection (Route) stats
     *
     * Generated from protobuf field <code>uint32 RoutingConfigsTotal = 1;</code>
     */
    protected $RoutingConfigsTotal = 0;
    /**
     * Current connections offline with other Gateways
     *
     * Generated from protobuf field <code>uint32 OfflineConnectionTotal = 2;</code>
     */
    protected $OfflineConnectionTotal = 0;
    /**
     * Network handling of dropped messages
     *
     * Generated from protobuf field <code>uint32 DroppedPropagatedMessages = 5;</code>
     */
    protected $DroppedPropagatedMessages = 0;
    /**
     * Ignored packet that have a redelivery counter and previously received with last received sequence number
     *
     * Generated from protobuf field <code>uint32 IgnoredRedeliveredPackets = 6;</code>
     */
    protected $IgnoredRedeliveredPackets = 0;
    /**
     * Ignored ACK of packets that sequence does not match trasmitted data packet
     *
     * Generated from protobuf field <code>uint32 BadACKSequenceNumbers = 7;</code>
     */
    protected $BadACKSequenceNumbers = 0;
    /**
     * Network handling of packets NACKed
     *
     * Generated from protobuf field <code>uint32 NACKedPackets = 8;</code>
     */
    protected $NACKedPackets = 0;
    /**
     * Queue Stats
     *
     * Generated from protobuf field <code>repeated .OS.PB.DeviceQueueMetric Queues = 15;</code>
     */
    private $Queues;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $RoutingConfigsTotal
     *           Routing and their Connection (Route) stats
     *     @type int $OfflineConnectionTotal
     *           Current connections offline with other Gateways
     *     @type int $DroppedPropagatedMessages
     *           Network handling of dropped messages
     *     @type int $IgnoredRedeliveredPackets
     *           Ignored packet that have a redelivery counter and previously received with last received sequence number
     *     @type int $BadACKSequenceNumbers
     *           Ignored ACK of packets that sequence does not match trasmitted data packet
     *     @type int $NACKedPackets
     *           Network handling of packets NACKed
     *     @type \OS\PB\DeviceQueueMetric[] $Queues
     *           Queue Stats
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Device::initOnce();
        parent::__construct($data);
    }

    /**
     * Routing and their Connection (Route) stats
     *
     * Generated from protobuf field <code>uint32 RoutingConfigsTotal = 1;</code>
     * @return int
     */
    public function getRoutingConfigsTotal()
    {
        return $this->RoutingConfigsTotal;
    }

    /**
     * Routing and their Connection (Route) stats
     *
     * Generated from protobuf field <code>uint32 RoutingConfigsTotal = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setRoutingConfigsTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->RoutingConfigsTotal = $var;

        return $this;
    }

    /**
     * Current connections offline with other Gateways
     *
     * Generated from protobuf field <code>uint32 OfflineConnectionTotal = 2;</code>
     * @return int
     */
    public function getOfflineConnectionTotal()
    {
        return $this->OfflineConnectionTotal;
    }

    /**
     * Current connections offline with other Gateways
     *
     * Generated from protobuf field <code>uint32 OfflineConnectionTotal = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setOfflineConnectionTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->OfflineConnectionTotal = $var;

        return $this;
    }

    /**
     * Network handling of dropped messages
     *
     * Generated from protobuf field <code>uint32 DroppedPropagatedMessages = 5;</code>
     * @return int
     */
    public function getDroppedPropagatedMessages()
    {
        return $this->DroppedPropagatedMessages;
    }

    /**
     * Network handling of dropped messages
     *
     * Generated from protobuf field <code>uint32 DroppedPropagatedMessages = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setDroppedPropagatedMessages($var)
    {
        GPBUtil::checkUint32($var);
        $this->DroppedPropagatedMessages = $var;

        return $this;
    }

    /**
     * Ignored packet that have a redelivery counter and previously received with last received sequence number
     *
     * Generated from protobuf field <code>uint32 IgnoredRedeliveredPackets = 6;</code>
     * @return int
     */
    public function getIgnoredRedeliveredPackets()
    {
        return $this->IgnoredRedeliveredPackets;
    }

    /**
     * Ignored packet that have a redelivery counter and previously received with last received sequence number
     *
     * Generated from protobuf field <code>uint32 IgnoredRedeliveredPackets = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setIgnoredRedeliveredPackets($var)
    {
        GPBUtil::checkUint32($var);
        $this->IgnoredRedeliveredPackets = $var;

        return $this;
    }

    /**
     * Ignored ACK of packets that sequence does not match trasmitted data packet
     *
     * Generated from protobuf field <code>uint32 BadACKSequenceNumbers = 7;</code>
     * @return int
     */
    public function getBadACKSequenceNumbers()
    {
        return $this->BadACKSequenceNumbers;
    }

    /**
     * Ignored ACK of packets that sequence does not match trasmitted data packet
     *
     * Generated from protobuf field <code>uint32 BadACKSequenceNumbers = 7;</code>
     * @param int $var
     * @return $this
     */
    public function setBadACKSequenceNumbers($var)
    {
        GPBUtil::checkUint32($var);
        $this->BadACKSequenceNumbers = $var;

        return $this;
    }

    /**
     * Network handling of packets NACKed
     *
     * Generated from protobuf field <code>uint32 NACKedPackets = 8;</code>
     * @return int
     */
    public function getNACKedPackets()
    {
        return $this->NACKedPackets;
    }

    /**
     * Network handling of packets NACKed
     *
     * Generated from protobuf field <code>uint32 NACKedPackets = 8;</code>
     * @param int $var
     * @return $this
     */
    public function setNACKedPackets($var)
    {
        GPBUtil::checkUint32($var);
        $this->NACKedPackets = $var;

        return $this;
    }

    /**
     * Queue Stats
     *
     * Generated from protobuf field <code>repeated .OS.PB.DeviceQueueMetric Queues = 15;</code>
     * @return RepeatedField<\OS\PB\DeviceQueueMetric>
     */
    public function getQueues()
    {
        return $this->Queues;
    }

    /**
     * Queue Stats
     *
     * Generated from protobuf field <code>repeated .OS.PB.DeviceQueueMetric Queues = 15;</code>
     * @param \OS\PB\DeviceQueueMetric[] $var
     * @return $this
     */
    public function setQueues($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::MESSAGE, \OS\PB\DeviceQueueMetric::class);
        $this->Queues = $arr;

        return $this;
    }

}

