<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: access.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.AccessDatabaseEvent</code>
 */
class AccessDatabaseEvent extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>uint32 ReadersTotal = 1;</code>
     */
    protected $ReadersTotal = 0;
    /**
     * Generated from protobuf field <code>uint32 MethodsTotal = 2;</code>
     */
    protected $MethodsTotal = 0;
    /**
     * Generated from protobuf field <code>uint32 RightsTotal = 3;</code>
     */
    protected $RightsTotal = 0;
    /**
     * Generated from protobuf field <code>uint32 UsersTotal = 4;</code>
     */
    protected $UsersTotal = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $ReadersTotal
     *     @type int $MethodsTotal
     *     @type int $RightsTotal
     *     @type int $UsersTotal
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Access::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>uint32 ReadersTotal = 1;</code>
     * @return int
     */
    public function getReadersTotal()
    {
        return $this->ReadersTotal;
    }

    /**
     * Generated from protobuf field <code>uint32 ReadersTotal = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setReadersTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->ReadersTotal = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 MethodsTotal = 2;</code>
     * @return int
     */
    public function getMethodsTotal()
    {
        return $this->MethodsTotal;
    }

    /**
     * Generated from protobuf field <code>uint32 MethodsTotal = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setMethodsTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->MethodsTotal = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 RightsTotal = 3;</code>
     * @return int
     */
    public function getRightsTotal()
    {
        return $this->RightsTotal;
    }

    /**
     * Generated from protobuf field <code>uint32 RightsTotal = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setRightsTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->RightsTotal = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 UsersTotal = 4;</code>
     * @return int
     */
    public function getUsersTotal()
    {
        return $this->UsersTotal;
    }

    /**
     * Generated from protobuf field <code>uint32 UsersTotal = 4;</code>
     * @param int $var
     * @return $this
     */
    public function setUsersTotal($var)
    {
        GPBUtil::checkUint32($var);
        $this->UsersTotal = $var;

        return $this;
    }

}

