<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ble.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.BLEBeSecureEvent</code>
 */
class BLEBeSecureEvent extends \Google\Protobuf\Internal\Message
{
    /**
     * The interface type on which this event occured, BLE or BLELongRange
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 1;</code>
     */
    protected $Interface = 0;
    /**
     * The index on the interface
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 2;</code>
     */
    protected $InterfaceIndex = 0;
    /**
     * The BLE Address of the device that sent this packet
     *
     * Generated from protobuf field <code>bytes DeviceAddress = 6;</code>
     */
    protected $DeviceAddress = '';
    /**
     * BeSecure 32bit serial number
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 10;</code>
     */
    protected $SerialNumber = 0;
    /**
     * BeSecure Fcode, typically 0x27
     *
     * Generated from protobuf field <code>uint32 FunctionCode = 11;</code>
     */
    protected $FunctionCode = 0;
    /**
     * BeSecure Payload bytes
     *
     * Generated from protobuf field <code>bytes Payload = 12;</code>
     */
    protected $Payload = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Interface
     *           The interface type on which this event occured, BLE or BLELongRange
     *     @type int $InterfaceIndex
     *           The index on the interface
     *     @type string $DeviceAddress
     *           The BLE Address of the device that sent this packet
     *     @type int $SerialNumber
     *           BeSecure 32bit serial number
     *     @type int $FunctionCode
     *           BeSecure Fcode, typically 0x27
     *     @type string $Payload
     *           BeSecure Payload bytes
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Ble::initOnce();
        parent::__construct($data);
    }

    /**
     * The interface type on which this event occured, BLE or BLELongRange
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 1;</code>
     * @return int
     */
    public function getInterface()
    {
        return $this->Interface;
    }

    /**
     * The interface type on which this event occured, BLE or BLELongRange
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setInterface($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceInterface::class);
        $this->Interface = $var;

        return $this;
    }

    /**
     * The index on the interface
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 2;</code>
     * @return int
     */
    public function getInterfaceIndex()
    {
        return $this->InterfaceIndex;
    }

    /**
     * The index on the interface
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setInterfaceIndex($var)
    {
        GPBUtil::checkUint32($var);
        $this->InterfaceIndex = $var;

        return $this;
    }

    /**
     * The BLE Address of the device that sent this packet
     *
     * Generated from protobuf field <code>bytes DeviceAddress = 6;</code>
     * @return string
     */
    public function getDeviceAddress()
    {
        return $this->DeviceAddress;
    }

    /**
     * The BLE Address of the device that sent this packet
     *
     * Generated from protobuf field <code>bytes DeviceAddress = 6;</code>
     * @param string $var
     * @return $this
     */
    public function setDeviceAddress($var)
    {
        GPBUtil::checkString($var, False);
        $this->DeviceAddress = $var;

        return $this;
    }

    /**
     * BeSecure 32bit serial number
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 10;</code>
     * @return int
     */
    public function getSerialNumber()
    {
        return $this->SerialNumber;
    }

    /**
     * BeSecure 32bit serial number
     *
     * Generated from protobuf field <code>uint32 SerialNumber = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setSerialNumber($var)
    {
        GPBUtil::checkUint32($var);
        $this->SerialNumber = $var;

        return $this;
    }

    /**
     * BeSecure Fcode, typically 0x27
     *
     * Generated from protobuf field <code>uint32 FunctionCode = 11;</code>
     * @return int
     */
    public function getFunctionCode()
    {
        return $this->FunctionCode;
    }

    /**
     * BeSecure Fcode, typically 0x27
     *
     * Generated from protobuf field <code>uint32 FunctionCode = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setFunctionCode($var)
    {
        GPBUtil::checkUint32($var);
        $this->FunctionCode = $var;

        return $this;
    }

    /**
     * BeSecure Payload bytes
     *
     * Generated from protobuf field <code>bytes Payload = 12;</code>
     * @return string
     */
    public function getPayload()
    {
        return $this->Payload;
    }

    /**
     * BeSecure Payload bytes
     *
     * Generated from protobuf field <code>bytes Payload = 12;</code>
     * @param string $var
     * @return $this
     */
    public function setPayload($var)
    {
        GPBUtil::checkString($var, False);
        $this->Payload = $var;

        return $this;
    }

}

